return <<'END';
0000	001f	<control>
0020		SPACE
0021		EXCLAMATION MARK
0022		QUOTATION MARK
0023		NUMBER SIGN
0024		DOLLAR SIGN
0025		PERCENT SIGN
0026		AMPERSAND
0027		APOSTROPHE
0028		LEFT PARENTHESIS
0029		RIGHT PARENTHESIS
002a		ASTERISK
002b		PLUS SIGN
002c		COMMA
002d		HYPHEN-MINUS
002e		FULL STOP
002f		SOLIDUS
0030		DIGIT ZERO
0031		DIGIT ONE
0032		DIGIT TWO
0033		DIGIT THREE
0034		DIGIT FOUR
0035		DIGIT FIVE
0036		DIGIT SIX
0037		DIGIT SEVEN
0038		DIGIT EIGHT
0039		DIGIT NINE
003a		COLON
003b		SEMICOLON
003c		LESS-THAN SIGN
003d		EQUALS SIGN
003e		GREATER-THAN SIGN
003f		QUESTION MARK
0040		COMMERCIAL AT
0041		LATIN CAPITAL LETTER A
0042		LATIN CAPITAL LETTER B
0043		LATIN CAPITAL LETTER C
0044		LATIN CAPITAL LETTER D
0045		LATIN CAPITAL LETTER E
0046		LATIN CAPITAL LETTER F
0047		LATIN CAPITAL LETTER G
0048		LATIN CAPITAL LETTER H
0049		LATIN CAPITAL LETTER I
004a		LATIN CAPITAL LETTER J
004b		LATIN CAPITAL LETTER K
004c		LATIN CAPITAL LETTER L
004d		LATIN CAPITAL LETTER M
004e		LATIN CAPITAL LETTER N
004f		LATIN CAPITAL LETTER O
0050		LATIN CAPITAL LETTER P
0051		LATIN CAPITAL LETTER Q
0052		LATIN CAPITAL LETTER R
0053		LATIN CAPITAL LETTER S
0054		LATIN CAPITAL LETTER T
0055		LATIN CAPITAL LETTER U
0056		LATIN CAPITAL LETTER V
0057		LATIN CAPITAL LETTER W
0058		LATIN CAPITAL LETTER X
0059		LATIN CAPITAL LETTER Y
005a		LATIN CAPITAL LETTER Z
005b		LEFT SQUARE BRACKET
005c		REVERSE SOLIDUS
005d		RIGHT SQUARE BRACKET
005e		CIRCUMFLEX ACCENT
005f		LOW LINE
0060		GRAVE ACCENT
0061		LATIN SMALL LETTER A
0062		LATIN SMALL LETTER B
0063		LATIN SMALL LETTER C
0064		LATIN SMALL LETTER D
0065		LATIN SMALL LETTER E
0066		LATIN SMALL LETTER F
0067		LATIN SMALL LETTER G
0068		LATIN SMALL LETTER H
0069		LATIN SMALL LETTER I
006a		LATIN SMALL LETTER J
006b		LATIN SMALL LETTER K
006c		LATIN SMALL LETTER L
006d		LATIN SMALL LETTER M
006e		LATIN SMALL LETTER N
006f		LATIN SMALL LETTER O
0070		LATIN SMALL LETTER P
0071		LATIN SMALL LETTER Q
0072		LATIN SMALL LETTER R
0073		LATIN SMALL LETTER S
0074		LATIN SMALL LETTER T
0075		LATIN SMALL LETTER U
0076		LATIN SMALL LETTER V
0077		LATIN SMALL LETTER W
0078		LATIN SMALL LETTER X
0079		LATIN SMALL LETTER Y
007a		LATIN SMALL LETTER Z
007b		LEFT CURLY BRACKET
007c		VERTICAL LINE
007d		RIGHT CURLY BRACKET
007e		TILDE
007f	009f	<control>
00a0		NO-BREAK SPACE
00a1		INVERTED EXCLAMATION MARK
00a2		CENT SIGN
00a3		POUND SIGN
00a4		CURRENCY SIGN
00a5		YEN SIGN
00a6		BROKEN BAR
00a7		SECTION SIGN
00a8		DIAERESIS
00a9		COPYRIGHT SIGN
00aa		FEMININE ORDINAL INDICATOR
00ab		LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
00ac		NOT SIGN
00ad		SOFT HYPHEN
00ae		REGISTERED SIGN
00af		MACRON
00b0		DEGREE SIGN
00b1		PLUS-MINUS SIGN
00b2		SUPERSCRIPT TWO
00b3		SUPERSCRIPT THREE
00b4		ACUTE ACCENT
00b5		MICRO SIGN
00b6		PILCROW SIGN
00b7		MIDDLE DOT
00b8		CEDILLA
00b9		SUPERSCRIPT ONE
00ba		MASCULINE ORDINAL INDICATOR
00bb		RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
00bc		VULGAR FRACTION ONE QUARTER
00bd		VULGAR FRACTION ONE HALF
00be		VULGAR FRACTION THREE QUARTERS
00bf		INVERTED QUESTION MARK
00c0		LATIN CAPITAL LETTER A WITH GRAVE
00c1		LATIN CAPITAL LETTER A WITH ACUTE
00c2		LATIN CAPITAL LETTER A WITH CIRCUMFLEX
00c3		LATIN CAPITAL LETTER A WITH TILDE
00c4		LATIN CAPITAL LETTER A WITH DIAERESIS
00c5		LATIN CAPITAL LETTER A WITH RING ABOVE
00c6		LATIN CAPITAL LETTER AE
00c7		LATIN CAPITAL LETTER C WITH CEDILLA
00c8		LATIN CAPITAL LETTER E WITH GRAVE
00c9		LATIN CAPITAL LETTER E WITH ACUTE
00ca		LATIN CAPITAL LETTER E WITH CIRCUMFLEX
00cb		LATIN CAPITAL LETTER E WITH DIAERESIS
00cc		LATIN CAPITAL LETTER I WITH GRAVE
00cd		LATIN CAPITAL LETTER I WITH ACUTE
00ce		LATIN CAPITAL LETTER I WITH CIRCUMFLEX
00cf		LATIN CAPITAL LETTER I WITH DIAERESIS
00d0		LATIN CAPITAL LETTER ETH
00d1		LATIN CAPITAL LETTER N WITH TILDE
00d2		LATIN CAPITAL LETTER O WITH GRAVE
00d3		LATIN CAPITAL LETTER O WITH ACUTE
00d4		LATIN CAPITAL LETTER O WITH CIRCUMFLEX
00d5		LATIN CAPITAL LETTER O WITH TILDE
00d6		LATIN CAPITAL LETTER O WITH DIAERESIS
00d7		MULTIPLICATION SIGN
00d8		LATIN CAPITAL LETTER O WITH STROKE
00d9		LATIN CAPITAL LETTER U WITH GRAVE
00da		LATIN CAPITAL LETTER U WITH ACUTE
00db		LATIN CAPITAL LETTER U WITH CIRCUMFLEX
00dc		LATIN CAPITAL LETTER U WITH DIAERESIS
00dd		LATIN CAPITAL LETTER Y WITH ACUTE
00de		LATIN CAPITAL LETTER THORN
00df		LATIN SMALL LETTER SHARP S
00e0		LATIN SMALL LETTER A WITH GRAVE
00e1		LATIN SMALL LETTER A WITH ACUTE
00e2		LATIN SMALL LETTER A WITH CIRCUMFLEX
00e3		LATIN SMALL LETTER A WITH TILDE
00e4		LATIN SMALL LETTER A WITH DIAERESIS
00e5		LATIN SMALL LETTER A WITH RING ABOVE
00e6		LATIN SMALL LETTER AE
00e7		LATIN SMALL LETTER C WITH CEDILLA
00e8		LATIN SMALL LETTER E WITH GRAVE
00e9		LATIN SMALL LETTER E WITH ACUTE
00ea		LATIN SMALL LETTER E WITH CIRCUMFLEX
00eb		LATIN SMALL LETTER E WITH DIAERESIS
00ec		LATIN SMALL LETTER I WITH GRAVE
00ed		LATIN SMALL LETTER I WITH ACUTE
00ee		LATIN SMALL LETTER I WITH CIRCUMFLEX
00ef		LATIN SMALL LETTER I WITH DIAERESIS
00f0		LATIN SMALL LETTER ETH
00f1		LATIN SMALL LETTER N WITH TILDE
00f2		LATIN SMALL LETTER O WITH GRAVE
00f3		LATIN SMALL LETTER O WITH ACUTE
00f4		LATIN SMALL LETTER O WITH CIRCUMFLEX
00f5		LATIN SMALL LETTER O WITH TILDE
00f6		LATIN SMALL LETTER O WITH DIAERESIS
00f7		DIVISION SIGN
00f8		LATIN SMALL LETTER O WITH STROKE
00f9		LATIN SMALL LETTER U WITH GRAVE
00fa		LATIN SMALL LETTER U WITH ACUTE
00fb		LATIN SMALL LETTER U WITH CIRCUMFLEX
00fc		LATIN SMALL LETTER U WITH DIAERESIS
00fd		LATIN SMALL LETTER Y WITH ACUTE
00fe		LATIN SMALL LETTER THORN
00ff		LATIN SMALL LETTER Y WITH DIAERESIS
0100		LATIN CAPITAL LETTER A WITH MACRON
0101		LATIN SMALL LETTER A WITH MACRON
0102		LATIN CAPITAL LETTER A WITH BREVE
0103		LATIN SMALL LETTER A WITH BREVE
0104		LATIN CAPITAL LETTER A WITH OGONEK
0105		LATIN SMALL LETTER A WITH OGONEK
0106		LATIN CAPITAL LETTER C WITH ACUTE
0107		LATIN SMALL LETTER C WITH ACUTE
0108		LATIN CAPITAL LETTER C WITH CIRCUMFLEX
0109		LATIN SMALL LETTER C WITH CIRCUMFLEX
010a		LATIN CAPITAL LETTER C WITH DOT ABOVE
010b		LATIN SMALL LETTER C WITH DOT ABOVE
010c		LATIN CAPITAL LETTER C WITH CARON
010d		LATIN SMALL LETTER C WITH CARON
010e		LATIN CAPITAL LETTER D WITH CARON
010f		LATIN SMALL LETTER D WITH CARON
0110		LATIN CAPITAL LETTER D WITH STROKE
0111		LATIN SMALL LETTER D WITH STROKE
0112		LATIN CAPITAL LETTER E WITH MACRON
0113		LATIN SMALL LETTER E WITH MACRON
0114		LATIN CAPITAL LETTER E WITH BREVE
0115		LATIN SMALL LETTER E WITH BREVE
0116		LATIN CAPITAL LETTER E WITH DOT ABOVE
0117		LATIN SMALL LETTER E WITH DOT ABOVE
0118		LATIN CAPITAL LETTER E WITH OGONEK
0119		LATIN SMALL LETTER E WITH OGONEK
011a		LATIN CAPITAL LETTER E WITH CARON
011b		LATIN SMALL LETTER E WITH CARON
011c		LATIN CAPITAL LETTER G WITH CIRCUMFLEX
011d		LATIN SMALL LETTER G WITH CIRCUMFLEX
011e		LATIN CAPITAL LETTER G WITH BREVE
011f		LATIN SMALL LETTER G WITH BREVE
0120		LATIN CAPITAL LETTER G WITH DOT ABOVE
0121		LATIN SMALL LETTER G WITH DOT ABOVE
0122		LATIN CAPITAL LETTER G WITH CEDILLA
0123		LATIN SMALL LETTER G WITH CEDILLA
0124		LATIN CAPITAL LETTER H WITH CIRCUMFLEX
0125		LATIN SMALL LETTER H WITH CIRCUMFLEX
0126		LATIN CAPITAL LETTER H WITH STROKE
0127		LATIN SMALL LETTER H WITH STROKE
0128		LATIN CAPITAL LETTER I WITH TILDE
0129		LATIN SMALL LETTER I WITH TILDE
012a		LATIN CAPITAL LETTER I WITH MACRON
012b		LATIN SMALL LETTER I WITH MACRON
012c		LATIN CAPITAL LETTER I WITH BREVE
012d		LATIN SMALL LETTER I WITH BREVE
012e		LATIN CAPITAL LETTER I WITH OGONEK
012f		LATIN SMALL LETTER I WITH OGONEK
0130		LATIN CAPITAL LETTER I WITH DOT ABOVE
0131		LATIN SMALL LETTER DOTLESS I
0132		LATIN CAPITAL LIGATURE IJ
0133		LATIN SMALL LIGATURE IJ
0134		LATIN CAPITAL LETTER J WITH CIRCUMFLEX
0135		LATIN SMALL LETTER J WITH CIRCUMFLEX
0136		LATIN CAPITAL LETTER K WITH CEDILLA
0137		LATIN SMALL LETTER K WITH CEDILLA
0138		LATIN SMALL LETTER KRA
0139		LATIN CAPITAL LETTER L WITH ACUTE
013a		LATIN SMALL LETTER L WITH ACUTE
013b		LATIN CAPITAL LETTER L WITH CEDILLA
013c		LATIN SMALL LETTER L WITH CEDILLA
013d		LATIN CAPITAL LETTER L WITH CARON
013e		LATIN SMALL LETTER L WITH CARON
013f		LATIN CAPITAL LETTER L WITH MIDDLE DOT
0140		LATIN SMALL LETTER L WITH MIDDLE DOT
0141		LATIN CAPITAL LETTER L WITH STROKE
0142		LATIN SMALL LETTER L WITH STROKE
0143		LATIN CAPITAL LETTER N WITH ACUTE
0144		LATIN SMALL LETTER N WITH ACUTE
0145		LATIN CAPITAL LETTER N WITH CEDILLA
0146		LATIN SMALL LETTER N WITH CEDILLA
0147		LATIN CAPITAL LETTER N WITH CARON
0148		LATIN SMALL LETTER N WITH CARON
0149		LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
014a		LATIN CAPITAL LETTER ENG
014b		LATIN SMALL LETTER ENG
014c		LATIN CAPITAL LETTER O WITH MACRON
014d		LATIN SMALL LETTER O WITH MACRON
014e		LATIN CAPITAL LETTER O WITH BREVE
014f		LATIN SMALL LETTER O WITH BREVE
0150		LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
0151		LATIN SMALL LETTER O WITH DOUBLE ACUTE
0152		LATIN CAPITAL LIGATURE OE
0153		LATIN SMALL LIGATURE OE
0154		LATIN CAPITAL LETTER R WITH ACUTE
0155		LATIN SMALL LETTER R WITH ACUTE
0156		LATIN CAPITAL LETTER R WITH CEDILLA
0157		LATIN SMALL LETTER R WITH CEDILLA
0158		LATIN CAPITAL LETTER R WITH CARON
0159		LATIN SMALL LETTER R WITH CARON
015a		LATIN CAPITAL LETTER S WITH ACUTE
015b		LATIN SMALL LETTER S WITH ACUTE
015c		LATIN CAPITAL LETTER S WITH CIRCUMFLEX
015d		LATIN SMALL LETTER S WITH CIRCUMFLEX
015e		LATIN CAPITAL LETTER S WITH CEDILLA
015f		LATIN SMALL LETTER S WITH CEDILLA
0160		LATIN CAPITAL LETTER S WITH CARON
0161		LATIN SMALL LETTER S WITH CARON
0162		LATIN CAPITAL LETTER T WITH CEDILLA
0163		LATIN SMALL LETTER T WITH CEDILLA
0164		LATIN CAPITAL LETTER T WITH CARON
0165		LATIN SMALL LETTER T WITH CARON
0166		LATIN CAPITAL LETTER T WITH STROKE
0167		LATIN SMALL LETTER T WITH STROKE
0168		LATIN CAPITAL LETTER U WITH TILDE
0169		LATIN SMALL LETTER U WITH TILDE
016a		LATIN CAPITAL LETTER U WITH MACRON
016b		LATIN SMALL LETTER U WITH MACRON
016c		LATIN CAPITAL LETTER U WITH BREVE
016d		LATIN SMALL LETTER U WITH BREVE
016e		LATIN CAPITAL LETTER U WITH RING ABOVE
016f		LATIN SMALL LETTER U WITH RING ABOVE
0170		LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
0171		LATIN SMALL LETTER U WITH DOUBLE ACUTE
0172		LATIN CAPITAL LETTER U WITH OGONEK
0173		LATIN SMALL LETTER U WITH OGONEK
0174		LATIN CAPITAL LETTER W WITH CIRCUMFLEX
0175		LATIN SMALL LETTER W WITH CIRCUMFLEX
0176		LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
0177		LATIN SMALL LETTER Y WITH CIRCUMFLEX
0178		LATIN CAPITAL LETTER Y WITH DIAERESIS
0179		LATIN CAPITAL LETTER Z WITH ACUTE
017a		LATIN SMALL LETTER Z WITH ACUTE
017b		LATIN CAPITAL LETTER Z WITH DOT ABOVE
017c		LATIN SMALL LETTER Z WITH DOT ABOVE
017d		LATIN CAPITAL LETTER Z WITH CARON
017e		LATIN SMALL LETTER Z WITH CARON
017f		LATIN SMALL LETTER LONG S
0180		LATIN SMALL LETTER B WITH STROKE
0181		LATIN CAPITAL LETTER B WITH HOOK
0182		LATIN CAPITAL LETTER B WITH TOPBAR
0183		LATIN SMALL LETTER B WITH TOPBAR
0184		LATIN CAPITAL LETTER TONE SIX
0185		LATIN SMALL LETTER TONE SIX
0186		LATIN CAPITAL LETTER OPEN O
0187		LATIN CAPITAL LETTER C WITH HOOK
0188		LATIN SMALL LETTER C WITH HOOK
0189		LATIN CAPITAL LETTER AFRICAN D
018a		LATIN CAPITAL LETTER D WITH HOOK
018b		LATIN CAPITAL LETTER D WITH TOPBAR
018c		LATIN SMALL LETTER D WITH TOPBAR
018d		LATIN SMALL LETTER TURNED DELTA
018e		LATIN CAPITAL LETTER REVERSED E
018f		LATIN CAPITAL LETTER SCHWA
0190		LATIN CAPITAL LETTER OPEN E
0191		LATIN CAPITAL LETTER F WITH HOOK
0192		LATIN SMALL LETTER F WITH HOOK
0193		LATIN CAPITAL LETTER G WITH HOOK
0194		LATIN CAPITAL LETTER GAMMA
0195		LATIN SMALL LETTER HV
0196		LATIN CAPITAL LETTER IOTA
0197		LATIN CAPITAL LETTER I WITH STROKE
0198		LATIN CAPITAL LETTER K WITH HOOK
0199		LATIN SMALL LETTER K WITH HOOK
019a		LATIN SMALL LETTER L WITH BAR
019b		LATIN SMALL LETTER LAMBDA WITH STROKE
019c		LATIN CAPITAL LETTER TURNED M
019d		LATIN CAPITAL LETTER N WITH LEFT HOOK
019e		LATIN SMALL LETTER N WITH LONG RIGHT LEG
019f		LATIN CAPITAL LETTER O WITH MIDDLE TILDE
01a0		LATIN CAPITAL LETTER O WITH HORN
01a1		LATIN SMALL LETTER O WITH HORN
01a2		LATIN CAPITAL LETTER OI
01a3		LATIN SMALL LETTER OI
01a4		LATIN CAPITAL LETTER P WITH HOOK
01a5		LATIN SMALL LETTER P WITH HOOK
01a6		LATIN LETTER YR
01a7		LATIN CAPITAL LETTER TONE TWO
01a8		LATIN SMALL LETTER TONE TWO
01a9		LATIN CAPITAL LETTER ESH
01aa		LATIN LETTER REVERSED ESH LOOP
01ab		LATIN SMALL LETTER T WITH PALATAL HOOK
01ac		LATIN CAPITAL LETTER T WITH HOOK
01ad		LATIN SMALL LETTER T WITH HOOK
01ae		LATIN CAPITAL LETTER T WITH RETROFLEX HOOK
01af		LATIN CAPITAL LETTER U WITH HORN
01b0		LATIN SMALL LETTER U WITH HORN
01b1		LATIN CAPITAL LETTER UPSILON
01b2		LATIN CAPITAL LETTER V WITH HOOK
01b3		LATIN CAPITAL LETTER Y WITH HOOK
01b4		LATIN SMALL LETTER Y WITH HOOK
01b5		LATIN CAPITAL LETTER Z WITH STROKE
01b6		LATIN SMALL LETTER Z WITH STROKE
01b7		LATIN CAPITAL LETTER EZH
01b8		LATIN CAPITAL LETTER EZH REVERSED
01b9		LATIN SMALL LETTER EZH REVERSED
01ba		LATIN SMALL LETTER EZH WITH TAIL
01bb		LATIN LETTER TWO WITH STROKE
01bc		LATIN CAPITAL LETTER TONE FIVE
01bd		LATIN SMALL LETTER TONE FIVE
01be		LATIN LETTER INVERTED GLOTTAL STOP WITH STROKE
01bf		LATIN LETTER WYNN
01c0		LATIN LETTER DENTAL CLICK
01c1		LATIN LETTER LATERAL CLICK
01c2		LATIN LETTER ALVEOLAR CLICK
01c3		LATIN LETTER RETROFLEX CLICK
01c4		LATIN CAPITAL LETTER DZ WITH CARON
01c5		LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON
01c6		LATIN SMALL LETTER DZ WITH CARON
01c7		LATIN CAPITAL LETTER LJ
01c8		LATIN CAPITAL LETTER L WITH SMALL LETTER J
01c9		LATIN SMALL LETTER LJ
01ca		LATIN CAPITAL LETTER NJ
01cb		LATIN CAPITAL LETTER N WITH SMALL LETTER J
01cc		LATIN SMALL LETTER NJ
01cd		LATIN CAPITAL LETTER A WITH CARON
01ce		LATIN SMALL LETTER A WITH CARON
01cf		LATIN CAPITAL LETTER I WITH CARON
01d0		LATIN SMALL LETTER I WITH CARON
01d1		LATIN CAPITAL LETTER O WITH CARON
01d2		LATIN SMALL LETTER O WITH CARON
01d3		LATIN CAPITAL LETTER U WITH CARON
01d4		LATIN SMALL LETTER U WITH CARON
01d5		LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01d6		LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01d7		LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01d8		LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01d9		LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
01da		LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01db		LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01dc		LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01dd		LATIN SMALL LETTER TURNED E
01de		LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
01df		LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01e0		LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON
01e1		LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON
01e2		LATIN CAPITAL LETTER AE WITH MACRON
01e3		LATIN SMALL LETTER AE WITH MACRON
01e4		LATIN CAPITAL LETTER G WITH STROKE
01e5		LATIN SMALL LETTER G WITH STROKE
01e6		LATIN CAPITAL LETTER G WITH CARON
01e7		LATIN SMALL LETTER G WITH CARON
01e8		LATIN CAPITAL LETTER K WITH CARON
01e9		LATIN SMALL LETTER K WITH CARON
01ea		LATIN CAPITAL LETTER O WITH OGONEK
01eb		LATIN SMALL LETTER O WITH OGONEK
01ec		LATIN CAPITAL LETTER O WITH OGONEK AND MACRON
01ed		LATIN SMALL LETTER O WITH OGONEK AND MACRON
01ee		LATIN CAPITAL LETTER EZH WITH CARON
01ef		LATIN SMALL LETTER EZH WITH CARON
01f0		LATIN SMALL LETTER J WITH CARON
01f1		LATIN CAPITAL LETTER DZ
01f2		LATIN CAPITAL LETTER D WITH SMALL LETTER Z
01f3		LATIN SMALL LETTER DZ
01f4		LATIN CAPITAL LETTER G WITH ACUTE
01f5		LATIN SMALL LETTER G WITH ACUTE
01fa		LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
01fb		LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
01fc		LATIN CAPITAL LETTER AE WITH ACUTE
01fd		LATIN SMALL LETTER AE WITH ACUTE
01fe		LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
01ff		LATIN SMALL LETTER O WITH STROKE AND ACUTE
0200		LATIN CAPITAL LETTER A WITH DOUBLE GRAVE
0201		LATIN SMALL LETTER A WITH DOUBLE GRAVE
0202		LATIN CAPITAL LETTER A WITH INVERTED BREVE
0203		LATIN SMALL LETTER A WITH INVERTED BREVE
0204		LATIN CAPITAL LETTER E WITH DOUBLE GRAVE
0205		LATIN SMALL LETTER E WITH DOUBLE GRAVE
0206		LATIN CAPITAL LETTER E WITH INVERTED BREVE
0207		LATIN SMALL LETTER E WITH INVERTED BREVE
0208		LATIN CAPITAL LETTER I WITH DOUBLE GRAVE
0209		LATIN SMALL LETTER I WITH DOUBLE GRAVE
020a		LATIN CAPITAL LETTER I WITH INVERTED BREVE
020b		LATIN SMALL LETTER I WITH INVERTED BREVE
020c		LATIN CAPITAL LETTER O WITH DOUBLE GRAVE
020d		LATIN SMALL LETTER O WITH DOUBLE GRAVE
020e		LATIN CAPITAL LETTER O WITH INVERTED BREVE
020f		LATIN SMALL LETTER O WITH INVERTED BREVE
0210		LATIN CAPITAL LETTER R WITH DOUBLE GRAVE
0211		LATIN SMALL LETTER R WITH DOUBLE GRAVE
0212		LATIN CAPITAL LETTER R WITH INVERTED BREVE
0213		LATIN SMALL LETTER R WITH INVERTED BREVE
0214		LATIN CAPITAL LETTER U WITH DOUBLE GRAVE
0215		LATIN SMALL LETTER U WITH DOUBLE GRAVE
0216		LATIN CAPITAL LETTER U WITH INVERTED BREVE
0217		LATIN SMALL LETTER U WITH INVERTED BREVE
0250		LATIN SMALL LETTER TURNED A
0251		LATIN SMALL LETTER ALPHA
0252		LATIN SMALL LETTER TURNED ALPHA
0253		LATIN SMALL LETTER B WITH HOOK
0254		LATIN SMALL LETTER OPEN O
0255		LATIN SMALL LETTER C WITH CURL
0256		LATIN SMALL LETTER D WITH TAIL
0257		LATIN SMALL LETTER D WITH HOOK
0258		LATIN SMALL LETTER REVERSED E
0259		LATIN SMALL LETTER SCHWA
025a		LATIN SMALL LETTER SCHWA WITH HOOK
025b		LATIN SMALL LETTER OPEN E
025c		LATIN SMALL LETTER REVERSED OPEN E
025d		LATIN SMALL LETTER REVERSED OPEN E WITH HOOK
025e		LATIN SMALL LETTER CLOSED REVERSED OPEN E
025f		LATIN SMALL LETTER DOTLESS J WITH STROKE
0260		LATIN SMALL LETTER G WITH HOOK
0261		LATIN SMALL LETTER SCRIPT G
0262		LATIN LETTER SMALL CAPITAL G
0263		LATIN SMALL LETTER GAMMA
0264		LATIN SMALL LETTER RAMS HORN
0265		LATIN SMALL LETTER TURNED H
0266		LATIN SMALL LETTER H WITH HOOK
0267		LATIN SMALL LETTER HENG WITH HOOK
0268		LATIN SMALL LETTER I WITH STROKE
0269		LATIN SMALL LETTER IOTA
026a		LATIN LETTER SMALL CAPITAL I
026b		LATIN SMALL LETTER L WITH MIDDLE TILDE
026c		LATIN SMALL LETTER L WITH BELT
026d		LATIN SMALL LETTER L WITH RETROFLEX HOOK
026e		LATIN SMALL LETTER LEZH
026f		LATIN SMALL LETTER TURNED M
0270		LATIN SMALL LETTER TURNED M WITH LONG LEG
0271		LATIN SMALL LETTER M WITH HOOK
0272		LATIN SMALL LETTER N WITH LEFT HOOK
0273		LATIN SMALL LETTER N WITH RETROFLEX HOOK
0274		LATIN LETTER SMALL CAPITAL N
0275		LATIN SMALL LETTER BARRED O
0276		LATIN LETTER SMALL CAPITAL OE
0277		LATIN SMALL LETTER CLOSED OMEGA
0278		LATIN SMALL LETTER PHI
0279		LATIN SMALL LETTER TURNED R
027a		LATIN SMALL LETTER TURNED R WITH LONG LEG
027b		LATIN SMALL LETTER TURNED R WITH HOOK
027c		LATIN SMALL LETTER R WITH LONG LEG
027d		LATIN SMALL LETTER R WITH TAIL
027e		LATIN SMALL LETTER R WITH FISHHOOK
027f		LATIN SMALL LETTER REVERSED R WITH FISHHOOK
0280		LATIN LETTER SMALL CAPITAL R
0281		LATIN LETTER SMALL CAPITAL INVERTED R
0282		LATIN SMALL LETTER S WITH HOOK
0283		LATIN SMALL LETTER ESH
0284		LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK
0285		LATIN SMALL LETTER SQUAT REVERSED ESH
0286		LATIN SMALL LETTER ESH WITH CURL
0287		LATIN SMALL LETTER TURNED T
0288		LATIN SMALL LETTER T WITH RETROFLEX HOOK
0289		LATIN SMALL LETTER U BAR
028a		LATIN SMALL LETTER UPSILON
028b		LATIN SMALL LETTER V WITH HOOK
028c		LATIN SMALL LETTER TURNED V
028d		LATIN SMALL LETTER TURNED W
028e		LATIN SMALL LETTER TURNED Y
028f		LATIN LETTER SMALL CAPITAL Y
0290		LATIN SMALL LETTER Z WITH RETROFLEX HOOK
0291		LATIN SMALL LETTER Z WITH CURL
0292		LATIN SMALL LETTER EZH
0293		LATIN SMALL LETTER EZH WITH CURL
0294		LATIN LETTER GLOTTAL STOP
0295		LATIN LETTER PHARYNGEAL VOICED FRICATIVE
0296		LATIN LETTER INVERTED GLOTTAL STOP
0297		LATIN LETTER STRETCHED C
0298		LATIN LETTER BILABIAL CLICK
0299		LATIN LETTER SMALL CAPITAL B
029a		LATIN SMALL LETTER CLOSED OPEN E
029b		LATIN LETTER SMALL CAPITAL G WITH HOOK
029c		LATIN LETTER SMALL CAPITAL H
029d		LATIN SMALL LETTER J WITH CROSSED-TAIL
029e		LATIN SMALL LETTER TURNED K
029f		LATIN LETTER SMALL CAPITAL L
02a0		LATIN SMALL LETTER Q WITH HOOK
02a1		LATIN LETTER GLOTTAL STOP WITH STROKE
02a2		LATIN LETTER REVERSED GLOTTAL STOP WITH STROKE
02a3		LATIN SMALL LETTER DZ DIGRAPH
02a4		LATIN SMALL LETTER DEZH DIGRAPH
02a5		LATIN SMALL LETTER DZ DIGRAPH WITH CURL
02a6		LATIN SMALL LETTER TS DIGRAPH
02a7		LATIN SMALL LETTER TESH DIGRAPH
02a8		LATIN SMALL LETTER TC DIGRAPH WITH CURL
02b0		MODIFIER LETTER SMALL H
02b1		MODIFIER LETTER SMALL H WITH HOOK
02b2		MODIFIER LETTER SMALL J
02b3		MODIFIER LETTER SMALL R
02b4		MODIFIER LETTER SMALL TURNED R
02b5		MODIFIER LETTER SMALL TURNED R WITH HOOK
02b6		MODIFIER LETTER SMALL CAPITAL INVERTED R
02b7		MODIFIER LETTER SMALL W
02b8		MODIFIER LETTER SMALL Y
02b9		MODIFIER LETTER PRIME
02ba		MODIFIER LETTER DOUBLE PRIME
02bb		MODIFIER LETTER TURNED COMMA
02bc		MODIFIER LETTER APOSTROPHE
02bd		MODIFIER LETTER REVERSED COMMA
02be		MODIFIER LETTER RIGHT HALF RING
02bf		MODIFIER LETTER LEFT HALF RING
02c0		MODIFIER LETTER GLOTTAL STOP
02c1		MODIFIER LETTER REVERSED GLOTTAL STOP
02c2		MODIFIER LETTER LEFT ARROWHEAD
02c3		MODIFIER LETTER RIGHT ARROWHEAD
02c4		MODIFIER LETTER UP ARROWHEAD
02c5		MODIFIER LETTER DOWN ARROWHEAD
02c6		MODIFIER LETTER CIRCUMFLEX ACCENT
02c7		CARON
02c8		MODIFIER LETTER VERTICAL LINE
02c9		MODIFIER LETTER MACRON
02ca		MODIFIER LETTER ACUTE ACCENT
02cb		MODIFIER LETTER GRAVE ACCENT
02cc		MODIFIER LETTER LOW VERTICAL LINE
02cd		MODIFIER LETTER LOW MACRON
02ce		MODIFIER LETTER LOW GRAVE ACCENT
02cf		MODIFIER LETTER LOW ACUTE ACCENT
02d0		MODIFIER LETTER TRIANGULAR COLON
02d1		MODIFIER LETTER HALF TRIANGULAR COLON
02d2		MODIFIER LETTER CENTRED RIGHT HALF RING
02d3		MODIFIER LETTER CENTRED LEFT HALF RING
02d4		MODIFIER LETTER UP TACK
02d5		MODIFIER LETTER DOWN TACK
02d6		MODIFIER LETTER PLUS SIGN
02d7		MODIFIER LETTER MINUS SIGN
02d8		BREVE
02d9		DOT ABOVE
02da		RING ABOVE
02db		OGONEK
02dc		SMALL TILDE
02dd		DOUBLE ACUTE ACCENT
02de		MODIFIER LETTER RHOTIC HOOK
02e0		MODIFIER LETTER SMALL GAMMA
02e1		MODIFIER LETTER SMALL L
02e2		MODIFIER LETTER SMALL S
02e3		MODIFIER LETTER SMALL X
02e4		MODIFIER LETTER SMALL REVERSED GLOTTAL STOP
02e5		MODIFIER LETTER EXTRA-HIGH TONE BAR
02e6		MODIFIER LETTER HIGH TONE BAR
02e7		MODIFIER LETTER MID TONE BAR
02e8		MODIFIER LETTER LOW TONE BAR
02e9		MODIFIER LETTER EXTRA-LOW TONE BAR
0300		COMBINING GRAVE ACCENT
0301		COMBINING ACUTE ACCENT
0302		COMBINING CIRCUMFLEX ACCENT
0303		COMBINING TILDE
0304		COMBINING MACRON
0305		COMBINING OVERLINE
0306		COMBINING BREVE
0307		COMBINING DOT ABOVE
0308		COMBINING DIAERESIS
0309		COMBINING HOOK ABOVE
030a		COMBINING RING ABOVE
030b		COMBINING DOUBLE ACUTE ACCENT
030c		COMBINING CARON
030d		COMBINING VERTICAL LINE ABOVE
030e		COMBINING DOUBLE VERTICAL LINE ABOVE
030f		COMBINING DOUBLE GRAVE ACCENT
0310		COMBINING CANDRABINDU
0311		COMBINING INVERTED BREVE
0312		COMBINING TURNED COMMA ABOVE
0313		COMBINING COMMA ABOVE
0314		COMBINING REVERSED COMMA ABOVE
0315		COMBINING COMMA ABOVE RIGHT
0316		COMBINING GRAVE ACCENT BELOW
0317		COMBINING ACUTE ACCENT BELOW
0318		COMBINING LEFT TACK BELOW
0319		COMBINING RIGHT TACK BELOW
031a		COMBINING LEFT ANGLE ABOVE
031b		COMBINING HORN
031c		COMBINING LEFT HALF RING BELOW
031d		COMBINING UP TACK BELOW
031e		COMBINING DOWN TACK BELOW
031f		COMBINING PLUS SIGN BELOW
0320		COMBINING MINUS SIGN BELOW
0321		COMBINING PALATALIZED HOOK BELOW
0322		COMBINING RETROFLEX HOOK BELOW
0323		COMBINING DOT BELOW
0324		COMBINING DIAERESIS BELOW
0325		COMBINING RING BELOW
0326		COMBINING COMMA BELOW
0327		COMBINING CEDILLA
0328		COMBINING OGONEK
0329		COMBINING VERTICAL LINE BELOW
032a		COMBINING BRIDGE BELOW
032b		COMBINING INVERTED DOUBLE ARCH BELOW
032c		COMBINING CARON BELOW
032d		COMBINING CIRCUMFLEX ACCENT BELOW
032e		COMBINING BREVE BELOW
032f		COMBINING INVERTED BREVE BELOW
0330		COMBINING TILDE BELOW
0331		COMBINING MACRON BELOW
0332		COMBINING LOW LINE
0333		COMBINING DOUBLE LOW LINE
0334		COMBINING TILDE OVERLAY
0335		COMBINING SHORT STROKE OVERLAY
0336		COMBINING LONG STROKE OVERLAY
0337		COMBINING SHORT SOLIDUS OVERLAY
0338		COMBINING LONG SOLIDUS OVERLAY
0339		COMBINING RIGHT HALF RING BELOW
033a		COMBINING INVERTED BRIDGE BELOW
033b		COMBINING SQUARE BELOW
033c		COMBINING SEAGULL BELOW
033d		COMBINING X ABOVE
033e		COMBINING VERTICAL TILDE
033f		COMBINING DOUBLE OVERLINE
0340		COMBINING GRAVE TONE MARK
0341		COMBINING ACUTE TONE MARK
0342		COMBINING GREEK PERISPOMENI
0343		COMBINING GREEK KORONIS
0344		COMBINING GREEK DIALYTIKA TONOS
0345		COMBINING GREEK YPOGEGRAMMENI
0360		COMBINING DOUBLE TILDE
0361		COMBINING DOUBLE INVERTED BREVE
0374		GREEK NUMERAL SIGN
0375		GREEK LOWER NUMERAL SIGN
037a		GREEK YPOGEGRAMMENI
037e		GREEK QUESTION MARK
0384		GREEK TONOS
0385		GREEK DIALYTIKA TONOS
0386		GREEK CAPITAL LETTER ALPHA WITH TONOS
0387		GREEK ANO TELEIA
0388		GREEK CAPITAL LETTER EPSILON WITH TONOS
0389		GREEK CAPITAL LETTER ETA WITH TONOS
038a		GREEK CAPITAL LETTER IOTA WITH TONOS
038c		GREEK CAPITAL LETTER OMICRON WITH TONOS
038e		GREEK CAPITAL LETTER UPSILON WITH TONOS
038f		GREEK CAPITAL LETTER OMEGA WITH TONOS
0390		GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS
0391		GREEK CAPITAL LETTER ALPHA
0392		GREEK CAPITAL LETTER BETA
0393		GREEK CAPITAL LETTER GAMMA
0394		GREEK CAPITAL LETTER DELTA
0395		GREEK CAPITAL LETTER EPSILON
0396		GREEK CAPITAL LETTER ZETA
0397		GREEK CAPITAL LETTER ETA
0398		GREEK CAPITAL LETTER THETA
0399		GREEK CAPITAL LETTER IOTA
039a		GREEK CAPITAL LETTER KAPPA
039b		GREEK CAPITAL LETTER LAMDA
039c		GREEK CAPITAL LETTER MU
039d		GREEK CAPITAL LETTER NU
039e		GREEK CAPITAL LETTER XI
039f		GREEK CAPITAL LETTER OMICRON
03a0		GREEK CAPITAL LETTER PI
03a1		GREEK CAPITAL LETTER RHO
03a3		GREEK CAPITAL LETTER SIGMA
03a4		GREEK CAPITAL LETTER TAU
03a5		GREEK CAPITAL LETTER UPSILON
03a6		GREEK CAPITAL LETTER PHI
03a7		GREEK CAPITAL LETTER CHI
03a8		GREEK CAPITAL LETTER PSI
03a9		GREEK CAPITAL LETTER OMEGA
03aa		GREEK CAPITAL LETTER IOTA WITH DIALYTIKA
03ab		GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA
03ac		GREEK SMALL LETTER ALPHA WITH TONOS
03ad		GREEK SMALL LETTER EPSILON WITH TONOS
03ae		GREEK SMALL LETTER ETA WITH TONOS
03af		GREEK SMALL LETTER IOTA WITH TONOS
03b0		GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS
03b1		GREEK SMALL LETTER ALPHA
03b2		GREEK SMALL LETTER BETA
03b3		GREEK SMALL LETTER GAMMA
03b4		GREEK SMALL LETTER DELTA
03b5		GREEK SMALL LETTER EPSILON
03b6		GREEK SMALL LETTER ZETA
03b7		GREEK SMALL LETTER ETA
03b8		GREEK SMALL LETTER THETA
03b9		GREEK SMALL LETTER IOTA
03ba		GREEK SMALL LETTER KAPPA
03bb		GREEK SMALL LETTER LAMDA
03bc		GREEK SMALL LETTER MU
03bd		GREEK SMALL LETTER NU
03be		GREEK SMALL LETTER XI
03bf		GREEK SMALL LETTER OMICRON
03c0		GREEK SMALL LETTER PI
03c1		GREEK SMALL LETTER RHO
03c2		GREEK SMALL LETTER FINAL SIGMA
03c3		GREEK SMALL LETTER SIGMA
03c4		GREEK SMALL LETTER TAU
03c5		GREEK SMALL LETTER UPSILON
03c6		GREEK SMALL LETTER PHI
03c7		GREEK SMALL LETTER CHI
03c8		GREEK SMALL LETTER PSI
03c9		GREEK SMALL LETTER OMEGA
03ca		GREEK SMALL LETTER IOTA WITH DIALYTIKA
03cb		GREEK SMALL LETTER UPSILON WITH DIALYTIKA
03cc		GREEK SMALL LETTER OMICRON WITH TONOS
03cd		GREEK SMALL LETTER UPSILON WITH TONOS
03ce		GREEK SMALL LETTER OMEGA WITH TONOS
03d0		GREEK BETA SYMBOL
03d1		GREEK THETA SYMBOL
03d2		GREEK UPSILON WITH HOOK SYMBOL
03d3		GREEK UPSILON WITH ACUTE AND HOOK SYMBOL
03d4		GREEK UPSILON WITH DIAERESIS AND HOOK SYMBOL
03d5		GREEK PHI SYMBOL
03d6		GREEK PI SYMBOL
03da		GREEK LETTER STIGMA
03dc		GREEK LETTER DIGAMMA
03de		GREEK LETTER KOPPA
03e0		GREEK LETTER SAMPI
03e2		COPTIC CAPITAL LETTER SHEI
03e3		COPTIC SMALL LETTER SHEI
03e4		COPTIC CAPITAL LETTER FEI
03e5		COPTIC SMALL LETTER FEI
03e6		COPTIC CAPITAL LETTER KHEI
03e7		COPTIC SMALL LETTER KHEI
03e8		COPTIC CAPITAL LETTER HORI
03e9		COPTIC SMALL LETTER HORI
03ea		COPTIC CAPITAL LETTER GANGIA
03eb		COPTIC SMALL LETTER GANGIA
03ec		COPTIC CAPITAL LETTER SHIMA
03ed		COPTIC SMALL LETTER SHIMA
03ee		COPTIC CAPITAL LETTER DEI
03ef		COPTIC SMALL LETTER DEI
03f0		GREEK KAPPA SYMBOL
03f1		GREEK RHO SYMBOL
03f2		GREEK LUNATE SIGMA SYMBOL
03f3		GREEK LETTER YOT
0401		CYRILLIC CAPITAL LETTER IO
0402		CYRILLIC CAPITAL LETTER DJE
0403		CYRILLIC CAPITAL LETTER GJE
0404		CYRILLIC CAPITAL LETTER UKRAINIAN IE
0405		CYRILLIC CAPITAL LETTER DZE
0406		CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
0407		CYRILLIC CAPITAL LETTER YI
0408		CYRILLIC CAPITAL LETTER JE
0409		CYRILLIC CAPITAL LETTER LJE
040a		CYRILLIC CAPITAL LETTER NJE
040b		CYRILLIC CAPITAL LETTER TSHE
040c		CYRILLIC CAPITAL LETTER KJE
040e		CYRILLIC CAPITAL LETTER SHORT U
040f		CYRILLIC CAPITAL LETTER DZHE
0410		CYRILLIC CAPITAL LETTER A
0411		CYRILLIC CAPITAL LETTER BE
0412		CYRILLIC CAPITAL LETTER VE
0413		CYRILLIC CAPITAL LETTER GHE
0414		CYRILLIC CAPITAL LETTER DE
0415		CYRILLIC CAPITAL LETTER IE
0416		CYRILLIC CAPITAL LETTER ZHE
0417		CYRILLIC CAPITAL LETTER ZE
0418		CYRILLIC CAPITAL LETTER I
0419		CYRILLIC CAPITAL LETTER SHORT I
041a		CYRILLIC CAPITAL LETTER KA
041b		CYRILLIC CAPITAL LETTER EL
041c		CYRILLIC CAPITAL LETTER EM
041d		CYRILLIC CAPITAL LETTER EN
041e		CYRILLIC CAPITAL LETTER O
041f		CYRILLIC CAPITAL LETTER PE
0420		CYRILLIC CAPITAL LETTER ER
0421		CYRILLIC CAPITAL LETTER ES
0422		CYRILLIC CAPITAL LETTER TE
0423		CYRILLIC CAPITAL LETTER U
0424		CYRILLIC CAPITAL LETTER EF
0425		CYRILLIC CAPITAL LETTER HA
0426		CYRILLIC CAPITAL LETTER TSE
0427		CYRILLIC CAPITAL LETTER CHE
0428		CYRILLIC CAPITAL LETTER SHA
0429		CYRILLIC CAPITAL LETTER SHCHA
042a		CYRILLIC CAPITAL LETTER HARD SIGN
042b		CYRILLIC CAPITAL LETTER YERU
042c		CYRILLIC CAPITAL LETTER SOFT SIGN
042d		CYRILLIC CAPITAL LETTER E
042e		CYRILLIC CAPITAL LETTER YU
042f		CYRILLIC CAPITAL LETTER YA
0430		CYRILLIC SMALL LETTER A
0431		CYRILLIC SMALL LETTER BE
0432		CYRILLIC SMALL LETTER VE
0433		CYRILLIC SMALL LETTER GHE
0434		CYRILLIC SMALL LETTER DE
0435		CYRILLIC SMALL LETTER IE
0436		CYRILLIC SMALL LETTER ZHE
0437		CYRILLIC SMALL LETTER ZE
0438		CYRILLIC SMALL LETTER I
0439		CYRILLIC SMALL LETTER SHORT I
043a		CYRILLIC SMALL LETTER KA
043b		CYRILLIC SMALL LETTER EL
043c		CYRILLIC SMALL LETTER EM
043d		CYRILLIC SMALL LETTER EN
043e		CYRILLIC SMALL LETTER O
043f		CYRILLIC SMALL LETTER PE
0440		CYRILLIC SMALL LETTER ER
0441		CYRILLIC SMALL LETTER ES
0442		CYRILLIC SMALL LETTER TE
0443		CYRILLIC SMALL LETTER U
0444		CYRILLIC SMALL LETTER EF
0445		CYRILLIC SMALL LETTER HA
0446		CYRILLIC SMALL LETTER TSE
0447		CYRILLIC SMALL LETTER CHE
0448		CYRILLIC SMALL LETTER SHA
0449		CYRILLIC SMALL LETTER SHCHA
044a		CYRILLIC SMALL LETTER HARD SIGN
044b		CYRILLIC SMALL LETTER YERU
044c		CYRILLIC SMALL LETTER SOFT SIGN
044d		CYRILLIC SMALL LETTER E
044e		CYRILLIC SMALL LETTER YU
044f		CYRILLIC SMALL LETTER YA
0451		CYRILLIC SMALL LETTER IO
0452		CYRILLIC SMALL LETTER DJE
0453		CYRILLIC SMALL LETTER GJE
0454		CYRILLIC SMALL LETTER UKRAINIAN IE
0455		CYRILLIC SMALL LETTER DZE
0456		CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
0457		CYRILLIC SMALL LETTER YI
0458		CYRILLIC SMALL LETTER JE
0459		CYRILLIC SMALL LETTER LJE
045a		CYRILLIC SMALL LETTER NJE
045b		CYRILLIC SMALL LETTER TSHE
045c		CYRILLIC SMALL LETTER KJE
045e		CYRILLIC SMALL LETTER SHORT U
045f		CYRILLIC SMALL LETTER DZHE
0460		CYRILLIC CAPITAL LETTER OMEGA
0461		CYRILLIC SMALL LETTER OMEGA
0462		CYRILLIC CAPITAL LETTER YAT
0463		CYRILLIC SMALL LETTER YAT
0464		CYRILLIC CAPITAL LETTER IOTIFIED E
0465		CYRILLIC SMALL LETTER IOTIFIED E
0466		CYRILLIC CAPITAL LETTER LITTLE YUS
0467		CYRILLIC SMALL LETTER LITTLE YUS
0468		CYRILLIC CAPITAL LETTER IOTIFIED LITTLE YUS
0469		CYRILLIC SMALL LETTER IOTIFIED LITTLE YUS
046a		CYRILLIC CAPITAL LETTER BIG YUS
046b		CYRILLIC SMALL LETTER BIG YUS
046c		CYRILLIC CAPITAL LETTER IOTIFIED BIG YUS
046d		CYRILLIC SMALL LETTER IOTIFIED BIG YUS
046e		CYRILLIC CAPITAL LETTER KSI
046f		CYRILLIC SMALL LETTER KSI
0470		CYRILLIC CAPITAL LETTER PSI
0471		CYRILLIC SMALL LETTER PSI
0472		CYRILLIC CAPITAL LETTER FITA
0473		CYRILLIC SMALL LETTER FITA
0474		CYRILLIC CAPITAL LETTER IZHITSA
0475		CYRILLIC SMALL LETTER IZHITSA
0476		CYRILLIC CAPITAL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT
0477		CYRILLIC SMALL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT
0478		CYRILLIC CAPITAL LETTER UK
0479		CYRILLIC SMALL LETTER UK
047a		CYRILLIC CAPITAL LETTER ROUND OMEGA
047b		CYRILLIC SMALL LETTER ROUND OMEGA
047c		CYRILLIC CAPITAL LETTER OMEGA WITH TITLO
047d		CYRILLIC SMALL LETTER OMEGA WITH TITLO
047e		CYRILLIC CAPITAL LETTER OT
047f		CYRILLIC SMALL LETTER OT
0480		CYRILLIC CAPITAL LETTER KOPPA
0481		CYRILLIC SMALL LETTER KOPPA
0482		CYRILLIC THOUSANDS SIGN
0483		COMBINING CYRILLIC TITLO
0484		COMBINING CYRILLIC PALATALIZATION
0485		COMBINING CYRILLIC DASIA PNEUMATA
0486		COMBINING CYRILLIC PSILI PNEUMATA
0490		CYRILLIC CAPITAL LETTER GHE WITH UPTURN
0491		CYRILLIC SMALL LETTER GHE WITH UPTURN
0492		CYRILLIC CAPITAL LETTER GHE WITH STROKE
0493		CYRILLIC SMALL LETTER GHE WITH STROKE
0494		CYRILLIC CAPITAL LETTER GHE WITH MIDDLE HOOK
0495		CYRILLIC SMALL LETTER GHE WITH MIDDLE HOOK
0496		CYRILLIC CAPITAL LETTER ZHE WITH DESCENDER
0497		CYRILLIC SMALL LETTER ZHE WITH DESCENDER
0498		CYRILLIC CAPITAL LETTER ZE WITH DESCENDER
0499		CYRILLIC SMALL LETTER ZE WITH DESCENDER
049a		CYRILLIC CAPITAL LETTER KA WITH DESCENDER
049b		CYRILLIC SMALL LETTER KA WITH DESCENDER
049c		CYRILLIC CAPITAL LETTER KA WITH VERTICAL STROKE
049d		CYRILLIC SMALL LETTER KA WITH VERTICAL STROKE
049e		CYRILLIC CAPITAL LETTER KA WITH STROKE
049f		CYRILLIC SMALL LETTER KA WITH STROKE
04a0		CYRILLIC CAPITAL LETTER BASHKIR KA
04a1		CYRILLIC SMALL LETTER BASHKIR KA
04a2		CYRILLIC CAPITAL LETTER EN WITH DESCENDER
04a3		CYRILLIC SMALL LETTER EN WITH DESCENDER
04a4		CYRILLIC CAPITAL LIGATURE EN GHE
04a5		CYRILLIC SMALL LIGATURE EN GHE
04a6		CYRILLIC CAPITAL LETTER PE WITH MIDDLE HOOK
04a7		CYRILLIC SMALL LETTER PE WITH MIDDLE HOOK
04a8		CYRILLIC CAPITAL LETTER ABKHASIAN HA
04a9		CYRILLIC SMALL LETTER ABKHASIAN HA
04aa		CYRILLIC CAPITAL LETTER ES WITH DESCENDER
04ab		CYRILLIC SMALL LETTER ES WITH DESCENDER
04ac		CYRILLIC CAPITAL LETTER TE WITH DESCENDER
04ad		CYRILLIC SMALL LETTER TE WITH DESCENDER
04ae		CYRILLIC CAPITAL LETTER STRAIGHT U
04af		CYRILLIC SMALL LETTER STRAIGHT U
04b0		CYRILLIC CAPITAL LETTER STRAIGHT U WITH STROKE
04b1		CYRILLIC SMALL LETTER STRAIGHT U WITH STROKE
04b2		CYRILLIC CAPITAL LETTER HA WITH DESCENDER
04b3		CYRILLIC SMALL LETTER HA WITH DESCENDER
04b4		CYRILLIC CAPITAL LIGATURE TE TSE
04b5		CYRILLIC SMALL LIGATURE TE TSE
04b6		CYRILLIC CAPITAL LETTER CHE WITH DESCENDER
04b7		CYRILLIC SMALL LETTER CHE WITH DESCENDER
04b8		CYRILLIC CAPITAL LETTER CHE WITH VERTICAL STROKE
04b9		CYRILLIC SMALL LETTER CHE WITH VERTICAL STROKE
04ba		CYRILLIC CAPITAL LETTER SHHA
04bb		CYRILLIC SMALL LETTER SHHA
04bc		CYRILLIC CAPITAL LETTER ABKHASIAN CHE
04bd		CYRILLIC SMALL LETTER ABKHASIAN CHE
04be		CYRILLIC CAPITAL LETTER ABKHASIAN CHE WITH DESCENDER
04bf		CYRILLIC SMALL LETTER ABKHASIAN CHE WITH DESCENDER
04c0		CYRILLIC LETTER PALOCHKA
04c1		CYRILLIC CAPITAL LETTER ZHE WITH BREVE
04c2		CYRILLIC SMALL LETTER ZHE WITH BREVE
04c3		CYRILLIC CAPITAL LETTER KA WITH HOOK
04c4		CYRILLIC SMALL LETTER KA WITH HOOK
04c7		CYRILLIC CAPITAL LETTER EN WITH HOOK
04c8		CYRILLIC SMALL LETTER EN WITH HOOK
04cb		CYRILLIC CAPITAL LETTER KHAKASSIAN CHE
04cc		CYRILLIC SMALL LETTER KHAKASSIAN CHE
04d0		CYRILLIC CAPITAL LETTER A WITH BREVE
04d1		CYRILLIC SMALL LETTER A WITH BREVE
04d2		CYRILLIC CAPITAL LETTER A WITH DIAERESIS
04d3		CYRILLIC SMALL LETTER A WITH DIAERESIS
04d4		CYRILLIC CAPITAL LIGATURE A IE
04d5		CYRILLIC SMALL LIGATURE A IE
04d6		CYRILLIC CAPITAL LETTER IE WITH BREVE
04d7		CYRILLIC SMALL LETTER IE WITH BREVE
04d8		CYRILLIC CAPITAL LETTER SCHWA
04d9		CYRILLIC SMALL LETTER SCHWA
04da		CYRILLIC CAPITAL LETTER SCHWA WITH DIAERESIS
04db		CYRILLIC SMALL LETTER SCHWA WITH DIAERESIS
04dc		CYRILLIC CAPITAL LETTER ZHE WITH DIAERESIS
04dd		CYRILLIC SMALL LETTER ZHE WITH DIAERESIS
04de		CYRILLIC CAPITAL LETTER ZE WITH DIAERESIS
04df		CYRILLIC SMALL LETTER ZE WITH DIAERESIS
04e0		CYRILLIC CAPITAL LETTER ABKHASIAN DZE
04e1		CYRILLIC SMALL LETTER ABKHASIAN DZE
04e2		CYRILLIC CAPITAL LETTER I WITH MACRON
04e3		CYRILLIC SMALL LETTER I WITH MACRON
04e4		CYRILLIC CAPITAL LETTER I WITH DIAERESIS
04e5		CYRILLIC SMALL LETTER I WITH DIAERESIS
04e6		CYRILLIC CAPITAL LETTER O WITH DIAERESIS
04e7		CYRILLIC SMALL LETTER O WITH DIAERESIS
04e8		CYRILLIC CAPITAL LETTER BARRED O
04e9		CYRILLIC SMALL LETTER BARRED O
04ea		CYRILLIC CAPITAL LETTER BARRED O WITH DIAERESIS
04eb		CYRILLIC SMALL LETTER BARRED O WITH DIAERESIS
04ee		CYRILLIC CAPITAL LETTER U WITH MACRON
04ef		CYRILLIC SMALL LETTER U WITH MACRON
04f0		CYRILLIC CAPITAL LETTER U WITH DIAERESIS
04f1		CYRILLIC SMALL LETTER U WITH DIAERESIS
04f2		CYRILLIC CAPITAL LETTER U WITH DOUBLE ACUTE
04f3		CYRILLIC SMALL LETTER U WITH DOUBLE ACUTE
04f4		CYRILLIC CAPITAL LETTER CHE WITH DIAERESIS
04f5		CYRILLIC SMALL LETTER CHE WITH DIAERESIS
04f8		CYRILLIC CAPITAL LETTER YERU WITH DIAERESIS
04f9		CYRILLIC SMALL LETTER YERU WITH DIAERESIS
0531		ARMENIAN CAPITAL LETTER AYB
0532		ARMENIAN CAPITAL LETTER BEN
0533		ARMENIAN CAPITAL LETTER GIM
0534		ARMENIAN CAPITAL LETTER DA
0535		ARMENIAN CAPITAL LETTER ECH
0536		ARMENIAN CAPITAL LETTER ZA
0537		ARMENIAN CAPITAL LETTER EH
0538		ARMENIAN CAPITAL LETTER ET
0539		ARMENIAN CAPITAL LETTER TO
053a		ARMENIAN CAPITAL LETTER ZHE
053b		ARMENIAN CAPITAL LETTER INI
053c		ARMENIAN CAPITAL LETTER LIWN
053d		ARMENIAN CAPITAL LETTER XEH
053e		ARMENIAN CAPITAL LETTER CA
053f		ARMENIAN CAPITAL LETTER KEN
0540		ARMENIAN CAPITAL LETTER HO
0541		ARMENIAN CAPITAL LETTER JA
0542		ARMENIAN CAPITAL LETTER GHAD
0543		ARMENIAN CAPITAL LETTER CHEH
0544		ARMENIAN CAPITAL LETTER MEN
0545		ARMENIAN CAPITAL LETTER YI
0546		ARMENIAN CAPITAL LETTER NOW
0547		ARMENIAN CAPITAL LETTER SHA
0548		ARMENIAN CAPITAL LETTER VO
0549		ARMENIAN CAPITAL LETTER CHA
054a		ARMENIAN CAPITAL LETTER PEH
054b		ARMENIAN CAPITAL LETTER JHEH
054c		ARMENIAN CAPITAL LETTER RA
054d		ARMENIAN CAPITAL LETTER SEH
054e		ARMENIAN CAPITAL LETTER VEW
054f		ARMENIAN CAPITAL LETTER TIWN
0550		ARMENIAN CAPITAL LETTER REH
0551		ARMENIAN CAPITAL LETTER CO
0552		ARMENIAN CAPITAL LETTER YIWN
0553		ARMENIAN CAPITAL LETTER PIWR
0554		ARMENIAN CAPITAL LETTER KEH
0555		ARMENIAN CAPITAL LETTER OH
0556		ARMENIAN CAPITAL LETTER FEH
0559		ARMENIAN MODIFIER LETTER LEFT HALF RING
055a		ARMENIAN APOSTROPHE
055b		ARMENIAN EMPHASIS MARK
055c		ARMENIAN EXCLAMATION MARK
055d		ARMENIAN COMMA
055e		ARMENIAN QUESTION MARK
055f		ARMENIAN ABBREVIATION MARK
0561		ARMENIAN SMALL LETTER AYB
0562		ARMENIAN SMALL LETTER BEN
0563		ARMENIAN SMALL LETTER GIM
0564		ARMENIAN SMALL LETTER DA
0565		ARMENIAN SMALL LETTER ECH
0566		ARMENIAN SMALL LETTER ZA
0567		ARMENIAN SMALL LETTER EH
0568		ARMENIAN SMALL LETTER ET
0569		ARMENIAN SMALL LETTER TO
056a		ARMENIAN SMALL LETTER ZHE
056b		ARMENIAN SMALL LETTER INI
056c		ARMENIAN SMALL LETTER LIWN
056d		ARMENIAN SMALL LETTER XEH
056e		ARMENIAN SMALL LETTER CA
056f		ARMENIAN SMALL LETTER KEN
0570		ARMENIAN SMALL LETTER HO
0571		ARMENIAN SMALL LETTER JA
0572		ARMENIAN SMALL LETTER GHAD
0573		ARMENIAN SMALL LETTER CHEH
0574		ARMENIAN SMALL LETTER MEN
0575		ARMENIAN SMALL LETTER YI
0576		ARMENIAN SMALL LETTER NOW
0577		ARMENIAN SMALL LETTER SHA
0578		ARMENIAN SMALL LETTER VO
0579		ARMENIAN SMALL LETTER CHA
057a		ARMENIAN SMALL LETTER PEH
057b		ARMENIAN SMALL LETTER JHEH
057c		ARMENIAN SMALL LETTER RA
057d		ARMENIAN SMALL LETTER SEH
057e		ARMENIAN SMALL LETTER VEW
057f		ARMENIAN SMALL LETTER TIWN
0580		ARMENIAN SMALL LETTER REH
0581		ARMENIAN SMALL LETTER CO
0582		ARMENIAN SMALL LETTER YIWN
0583		ARMENIAN SMALL LETTER PIWR
0584		ARMENIAN SMALL LETTER KEH
0585		ARMENIAN SMALL LETTER OH
0586		ARMENIAN SMALL LETTER FEH
0587		ARMENIAN SMALL LIGATURE ECH YIWN
0589		ARMENIAN FULL STOP
0591		HEBREW ACCENT ETNAHTA
0592		HEBREW ACCENT SEGOL
0593		HEBREW ACCENT SHALSHELET
0594		HEBREW ACCENT ZAQEF QATAN
0595		HEBREW ACCENT ZAQEF GADOL
0596		HEBREW ACCENT TIPEHA
0597		HEBREW ACCENT REVIA
0598		HEBREW ACCENT ZARQA
0599		HEBREW ACCENT PASHTA
059a		HEBREW ACCENT YETIV
059b		HEBREW ACCENT TEVIR
059c		HEBREW ACCENT GERESH
059d		HEBREW ACCENT GERESH MUQDAM
059e		HEBREW ACCENT GERSHAYIM
059f		HEBREW ACCENT QARNEY PARA
05a0		HEBREW ACCENT TELISHA GEDOLA
05a1		HEBREW ACCENT PAZER
05a3		HEBREW ACCENT MUNAH
05a4		HEBREW ACCENT MAHAPAKH
05a5		HEBREW ACCENT MERKHA
05a6		HEBREW ACCENT MERKHA KEFULA
05a7		HEBREW ACCENT DARGA
05a8		HEBREW ACCENT QADMA
05a9		HEBREW ACCENT TELISHA QETANA
05aa		HEBREW ACCENT YERAH BEN YOMO
05ab		HEBREW ACCENT OLE
05ac		HEBREW ACCENT ILUY
05ad		HEBREW ACCENT DEHI
05ae		HEBREW ACCENT ZINOR
05af		HEBREW MARK MASORA CIRCLE
05b0		HEBREW POINT SHEVA
05b1		HEBREW POINT HATAF SEGOL
05b2		HEBREW POINT HATAF PATAH
05b3		HEBREW POINT HATAF QAMATS
05b4		HEBREW POINT HIRIQ
05b5		HEBREW POINT TSERE
05b6		HEBREW POINT SEGOL
05b7		HEBREW POINT PATAH
05b8		HEBREW POINT QAMATS
05b9		HEBREW POINT HOLAM
05bb		HEBREW POINT QUBUTS
05bc		HEBREW POINT DAGESH OR MAPIQ
05bd		HEBREW POINT METEG
05be		HEBREW PUNCTUATION MAQAF
05bf		HEBREW POINT RAFE
05c0		HEBREW PUNCTUATION PASEQ
05c1		HEBREW POINT SHIN DOT
05c2		HEBREW POINT SIN DOT
05c3		HEBREW PUNCTUATION SOF PASUQ
05c4		HEBREW MARK UPPER DOT
05d0		HEBREW LETTER ALEF
05d1		HEBREW LETTER BET
05d2		HEBREW LETTER GIMEL
05d3		HEBREW LETTER DALET
05d4		HEBREW LETTER HE
05d5		HEBREW LETTER VAV
05d6		HEBREW LETTER ZAYIN
05d7		HEBREW LETTER HET
05d8		HEBREW LETTER TET
05d9		HEBREW LETTER YOD
05da		HEBREW LETTER FINAL KAF
05db		HEBREW LETTER KAF
05dc		HEBREW LETTER LAMED
05dd		HEBREW LETTER FINAL MEM
05de		HEBREW LETTER MEM
05df		HEBREW LETTER FINAL NUN
05e0		HEBREW LETTER NUN
05e1		HEBREW LETTER SAMEKH
05e2		HEBREW LETTER AYIN
05e3		HEBREW LETTER FINAL PE
05e4		HEBREW LETTER PE
05e5		HEBREW LETTER FINAL TSADI
05e6		HEBREW LETTER TSADI
05e7		HEBREW LETTER QOF
05e8		HEBREW LETTER RESH
05e9		HEBREW LETTER SHIN
05ea		HEBREW LETTER TAV
05f0		HEBREW LIGATURE YIDDISH DOUBLE VAV
05f1		HEBREW LIGATURE YIDDISH VAV YOD
05f2		HEBREW LIGATURE YIDDISH DOUBLE YOD
05f3		HEBREW PUNCTUATION GERESH
05f4		HEBREW PUNCTUATION GERSHAYIM
060c		ARABIC COMMA
061b		ARABIC SEMICOLON
061f		ARABIC QUESTION MARK
0621		ARABIC LETTER HAMZA
0622		ARABIC LETTER ALEF WITH MADDA ABOVE
0623		ARABIC LETTER ALEF WITH HAMZA ABOVE
0624		ARABIC LETTER WAW WITH HAMZA ABOVE
0625		ARABIC LETTER ALEF WITH HAMZA BELOW
0626		ARABIC LETTER YEH WITH HAMZA ABOVE
0627		ARABIC LETTER ALEF
0628		ARABIC LETTER BEH
0629		ARABIC LETTER TEH MARBUTA
062a		ARABIC LETTER TEH
062b		ARABIC LETTER THEH
062c		ARABIC LETTER JEEM
062d		ARABIC LETTER HAH
062e		ARABIC LETTER KHAH
062f		ARABIC LETTER DAL
0630		ARABIC LETTER THAL
0631		ARABIC LETTER REH
0632		ARABIC LETTER ZAIN
0633		ARABIC LETTER SEEN
0634		ARABIC LETTER SHEEN
0635		ARABIC LETTER SAD
0636		ARABIC LETTER DAD
0637		ARABIC LETTER TAH
0638		ARABIC LETTER ZAH
0639		ARABIC LETTER AIN
063a		ARABIC LETTER GHAIN
0640		ARABIC TATWEEL
0641		ARABIC LETTER FEH
0642		ARABIC LETTER QAF
0643		ARABIC LETTER KAF
0644		ARABIC LETTER LAM
0645		ARABIC LETTER MEEM
0646		ARABIC LETTER NOON
0647		ARABIC LETTER HEH
0648		ARABIC LETTER WAW
0649		ARABIC LETTER ALEF MAKSURA
064a		ARABIC LETTER YEH
064b		ARABIC FATHATAN
064c		ARABIC DAMMATAN
064d		ARABIC KASRATAN
064e		ARABIC FATHA
064f		ARABIC DAMMA
0650		ARABIC KASRA
0651		ARABIC SHADDA
0652		ARABIC SUKUN
0660		ARABIC-INDIC DIGIT ZERO
0661		ARABIC-INDIC DIGIT ONE
0662		ARABIC-INDIC DIGIT TWO
0663		ARABIC-INDIC DIGIT THREE
0664		ARABIC-INDIC DIGIT FOUR
0665		ARABIC-INDIC DIGIT FIVE
0666		ARABIC-INDIC DIGIT SIX
0667		ARABIC-INDIC DIGIT SEVEN
0668		ARABIC-INDIC DIGIT EIGHT
0669		ARABIC-INDIC DIGIT NINE
066a		ARABIC PERCENT SIGN
066b		ARABIC DECIMAL SEPARATOR
066c		ARABIC THOUSANDS SEPARATOR
066d		ARABIC FIVE POINTED STAR
0670		ARABIC LETTER SUPERSCRIPT ALEF
0671		ARABIC LETTER ALEF WASLA
0672		ARABIC LETTER ALEF WITH WAVY HAMZA ABOVE
0673		ARABIC LETTER ALEF WITH WAVY HAMZA BELOW
0674		ARABIC LETTER HIGH HAMZA
0675		ARABIC LETTER HIGH HAMZA ALEF
0676		ARABIC LETTER HIGH HAMZA WAW
0677		ARABIC LETTER U WITH HAMZA ABOVE
0678		ARABIC LETTER HIGH HAMZA YEH
0679		ARABIC LETTER TTEH
067a		ARABIC LETTER TTEHEH
067b		ARABIC LETTER BEEH
067c		ARABIC LETTER TEH WITH RING
067d		ARABIC LETTER TEH WITH THREE DOTS ABOVE DOWNWARDS
067e		ARABIC LETTER PEH
067f		ARABIC LETTER TEHEH
0680		ARABIC LETTER BEHEH
0681		ARABIC LETTER HAH WITH HAMZA ABOVE
0682		ARABIC LETTER HAH WITH TWO DOTS VERTICAL ABOVE
0683		ARABIC LETTER NYEH
0684		ARABIC LETTER DYEH
0685		ARABIC LETTER HAH WITH THREE DOTS ABOVE
0686		ARABIC LETTER TCHEH
0687		ARABIC LETTER TCHEHEH
0688		ARABIC LETTER DDAL
0689		ARABIC LETTER DAL WITH RING
068a		ARABIC LETTER DAL WITH DOT BELOW
068b		ARABIC LETTER DAL WITH DOT BELOW AND SMALL TAH
068c		ARABIC LETTER DAHAL
068d		ARABIC LETTER DDAHAL
068e		ARABIC LETTER DUL
068f		ARABIC LETTER DAL WITH THREE DOTS ABOVE DOWNWARDS
0690		ARABIC LETTER DAL WITH FOUR DOTS ABOVE
0691		ARABIC LETTER RREH
0692		ARABIC LETTER REH WITH SMALL V
0693		ARABIC LETTER REH WITH RING
0694		ARABIC LETTER REH WITH DOT BELOW
0695		ARABIC LETTER REH WITH SMALL V BELOW
0696		ARABIC LETTER REH WITH DOT BELOW AND DOT ABOVE
0697		ARABIC LETTER REH WITH TWO DOTS ABOVE
0698		ARABIC LETTER JEH
0699		ARABIC LETTER REH WITH FOUR DOTS ABOVE
069a		ARABIC LETTER SEEN WITH DOT BELOW AND DOT ABOVE
069b		ARABIC LETTER SEEN WITH THREE DOTS BELOW
069c		ARABIC LETTER SEEN WITH THREE DOTS BELOW AND THREE DOTS ABOVE
069d		ARABIC LETTER SAD WITH TWO DOTS BELOW
069e		ARABIC LETTER SAD WITH THREE DOTS ABOVE
069f		ARABIC LETTER TAH WITH THREE DOTS ABOVE
06a0		ARABIC LETTER AIN WITH THREE DOTS ABOVE
06a1		ARABIC LETTER DOTLESS FEH
06a2		ARABIC LETTER FEH WITH DOT MOVED BELOW
06a3		ARABIC LETTER FEH WITH DOT BELOW
06a4		ARABIC LETTER VEH
06a5		ARABIC LETTER FEH WITH THREE DOTS BELOW
06a6		ARABIC LETTER PEHEH
06a7		ARABIC LETTER QAF WITH DOT ABOVE
06a8		ARABIC LETTER QAF WITH THREE DOTS ABOVE
06a9		ARABIC LETTER KEHEH
06aa		ARABIC LETTER SWASH KAF
06ab		ARABIC LETTER KAF WITH RING
06ac		ARABIC LETTER KAF WITH DOT ABOVE
06ad		ARABIC LETTER NG
06ae		ARABIC LETTER KAF WITH THREE DOTS BELOW
06af		ARABIC LETTER GAF
06b0		ARABIC LETTER GAF WITH RING
06b1		ARABIC LETTER NGOEH
06b2		ARABIC LETTER GAF WITH TWO DOTS BELOW
06b3		ARABIC LETTER GUEH
06b4		ARABIC LETTER GAF WITH THREE DOTS ABOVE
06b5		ARABIC LETTER LAM WITH SMALL V
06b6		ARABIC LETTER LAM WITH DOT ABOVE
06b7		ARABIC LETTER LAM WITH THREE DOTS ABOVE
06ba		ARABIC LETTER NOON GHUNNA
06bb		ARABIC LETTER RNOON
06bc		ARABIC LETTER NOON WITH RING
06bd		ARABIC LETTER NOON WITH THREE DOTS ABOVE
06be		ARABIC LETTER HEH DOACHASHMEE
06c0		ARABIC LETTER HEH WITH YEH ABOVE
06c1		ARABIC LETTER HEH GOAL
06c2		ARABIC LETTER HEH GOAL WITH HAMZA ABOVE
06c3		ARABIC LETTER TEH MARBUTA GOAL
06c4		ARABIC LETTER WAW WITH RING
06c5		ARABIC LETTER KIRGHIZ OE
06c6		ARABIC LETTER OE
06c7		ARABIC LETTER U
06c8		ARABIC LETTER YU
06c9		ARABIC LETTER KIRGHIZ YU
06ca		ARABIC LETTER WAW WITH TWO DOTS ABOVE
06cb		ARABIC LETTER VE
06cc		ARABIC LETTER FARSI YEH
06cd		ARABIC LETTER YEH WITH TAIL
06ce		ARABIC LETTER YEH WITH SMALL V
06d0		ARABIC LETTER E
06d1		ARABIC LETTER YEH WITH THREE DOTS BELOW
06d2		ARABIC LETTER YEH BARREE
06d3		ARABIC LETTER YEH BARREE WITH HAMZA ABOVE
06d4		ARABIC FULL STOP
06d5		ARABIC LETTER AE
06d6		ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA
06d7		ARABIC SMALL HIGH LIGATURE QAF WITH LAM WITH ALEF MAKSURA
06d8		ARABIC SMALL HIGH MEEM INITIAL FORM
06d9		ARABIC SMALL HIGH LAM ALEF
06da		ARABIC SMALL HIGH JEEM
06db		ARABIC SMALL HIGH THREE DOTS
06dc		ARABIC SMALL HIGH SEEN
06dd		ARABIC END OF AYAH
06de		ARABIC START OF RUB EL HIZB
06df		ARABIC SMALL HIGH ROUNDED ZERO
06e0		ARABIC SMALL HIGH UPRIGHT RECTANGULAR ZERO
06e1		ARABIC SMALL HIGH DOTLESS HEAD OF KHAH
06e2		ARABIC SMALL HIGH MEEM ISOLATED FORM
06e3		ARABIC SMALL LOW SEEN
06e4		ARABIC SMALL HIGH MADDA
06e5		ARABIC SMALL WAW
06e6		ARABIC SMALL YEH
06e7		ARABIC SMALL HIGH YEH
06e8		ARABIC SMALL HIGH NOON
06e9		ARABIC PLACE OF SAJDAH
06ea		ARABIC EMPTY CENTRE LOW STOP
06eb		ARABIC EMPTY CENTRE HIGH STOP
06ec		ARABIC ROUNDED HIGH STOP WITH FILLED CENTRE
06ed		ARABIC SMALL LOW MEEM
06f0		EXTENDED ARABIC-INDIC DIGIT ZERO
06f1		EXTENDED ARABIC-INDIC DIGIT ONE
06f2		EXTENDED ARABIC-INDIC DIGIT TWO
06f3		EXTENDED ARABIC-INDIC DIGIT THREE
06f4		EXTENDED ARABIC-INDIC DIGIT FOUR
06f5		EXTENDED ARABIC-INDIC DIGIT FIVE
06f6		EXTENDED ARABIC-INDIC DIGIT SIX
06f7		EXTENDED ARABIC-INDIC DIGIT SEVEN
06f8		EXTENDED ARABIC-INDIC DIGIT EIGHT
06f9		EXTENDED ARABIC-INDIC DIGIT NINE
0901		DEVANAGARI SIGN CANDRABINDU
0902		DEVANAGARI SIGN ANUSVARA
0903		DEVANAGARI SIGN VISARGA
0905		DEVANAGARI LETTER A
0906		DEVANAGARI LETTER AA
0907		DEVANAGARI LETTER I
0908		DEVANAGARI LETTER II
0909		DEVANAGARI LETTER U
090a		DEVANAGARI LETTER UU
090b		DEVANAGARI LETTER VOCALIC R
090c		DEVANAGARI LETTER VOCALIC L
090d		DEVANAGARI LETTER CANDRA E
090e		DEVANAGARI LETTER SHORT E
090f		DEVANAGARI LETTER E
0910		DEVANAGARI LETTER AI
0911		DEVANAGARI LETTER CANDRA O
0912		DEVANAGARI LETTER SHORT O
0913		DEVANAGARI LETTER O
0914		DEVANAGARI LETTER AU
0915		DEVANAGARI LETTER KA
0916		DEVANAGARI LETTER KHA
0917		DEVANAGARI LETTER GA
0918		DEVANAGARI LETTER GHA
0919		DEVANAGARI LETTER NGA
091a		DEVANAGARI LETTER CA
091b		DEVANAGARI LETTER CHA
091c		DEVANAGARI LETTER JA
091d		DEVANAGARI LETTER JHA
091e		DEVANAGARI LETTER NYA
091f		DEVANAGARI LETTER TTA
0920		DEVANAGARI LETTER TTHA
0921		DEVANAGARI LETTER DDA
0922		DEVANAGARI LETTER DDHA
0923		DEVANAGARI LETTER NNA
0924		DEVANAGARI LETTER TA
0925		DEVANAGARI LETTER THA
0926		DEVANAGARI LETTER DA
0927		DEVANAGARI LETTER DHA
0928		DEVANAGARI LETTER NA
0929		DEVANAGARI LETTER NNNA
092a		DEVANAGARI LETTER PA
092b		DEVANAGARI LETTER PHA
092c		DEVANAGARI LETTER BA
092d		DEVANAGARI LETTER BHA
092e		DEVANAGARI LETTER MA
092f		DEVANAGARI LETTER YA
0930		DEVANAGARI LETTER RA
0931		DEVANAGARI LETTER RRA
0932		DEVANAGARI LETTER LA
0933		DEVANAGARI LETTER LLA
0934		DEVANAGARI LETTER LLLA
0935		DEVANAGARI LETTER VA
0936		DEVANAGARI LETTER SHA
0937		DEVANAGARI LETTER SSA
0938		DEVANAGARI LETTER SA
0939		DEVANAGARI LETTER HA
093c		DEVANAGARI SIGN NUKTA
093d		DEVANAGARI SIGN AVAGRAHA
093e		DEVANAGARI VOWEL SIGN AA
093f		DEVANAGARI VOWEL SIGN I
0940		DEVANAGARI VOWEL SIGN II
0941		DEVANAGARI VOWEL SIGN U
0942		DEVANAGARI VOWEL SIGN UU
0943		DEVANAGARI VOWEL SIGN VOCALIC R
0944		DEVANAGARI VOWEL SIGN VOCALIC RR
0945		DEVANAGARI VOWEL SIGN CANDRA E
0946		DEVANAGARI VOWEL SIGN SHORT E
0947		DEVANAGARI VOWEL SIGN E
0948		DEVANAGARI VOWEL SIGN AI
0949		DEVANAGARI VOWEL SIGN CANDRA O
094a		DEVANAGARI VOWEL SIGN SHORT O
094b		DEVANAGARI VOWEL SIGN O
094c		DEVANAGARI VOWEL SIGN AU
094d		DEVANAGARI SIGN VIRAMA
0950		DEVANAGARI OM
0951		DEVANAGARI STRESS SIGN UDATTA
0952		DEVANAGARI STRESS SIGN ANUDATTA
0953		DEVANAGARI GRAVE ACCENT
0954		DEVANAGARI ACUTE ACCENT
0958		DEVANAGARI LETTER QA
0959		DEVANAGARI LETTER KHHA
095a		DEVANAGARI LETTER GHHA
095b		DEVANAGARI LETTER ZA
095c		DEVANAGARI LETTER DDDHA
095d		DEVANAGARI LETTER RHA
095e		DEVANAGARI LETTER FA
095f		DEVANAGARI LETTER YYA
0960		DEVANAGARI LETTER VOCALIC RR
0961		DEVANAGARI LETTER VOCALIC LL
0962		DEVANAGARI VOWEL SIGN VOCALIC L
0963		DEVANAGARI VOWEL SIGN VOCALIC LL
0964		DEVANAGARI DANDA
0965		DEVANAGARI DOUBLE DANDA
0966		DEVANAGARI DIGIT ZERO
0967		DEVANAGARI DIGIT ONE
0968		DEVANAGARI DIGIT TWO
0969		DEVANAGARI DIGIT THREE
096a		DEVANAGARI DIGIT FOUR
096b		DEVANAGARI DIGIT FIVE
096c		DEVANAGARI DIGIT SIX
096d		DEVANAGARI DIGIT SEVEN
096e		DEVANAGARI DIGIT EIGHT
096f		DEVANAGARI DIGIT NINE
0970		DEVANAGARI ABBREVIATION SIGN
0981		BENGALI SIGN CANDRABINDU
0982		BENGALI SIGN ANUSVARA
0983		BENGALI SIGN VISARGA
0985		BENGALI LETTER A
0986		BENGALI LETTER AA
0987		BENGALI LETTER I
0988		BENGALI LETTER II
0989		BENGALI LETTER U
098a		BENGALI LETTER UU
098b		BENGALI LETTER VOCALIC R
098c		BENGALI LETTER VOCALIC L
098f		BENGALI LETTER E
0990		BENGALI LETTER AI
0993		BENGALI LETTER O
0994		BENGALI LETTER AU
0995		BENGALI LETTER KA
0996		BENGALI LETTER KHA
0997		BENGALI LETTER GA
0998		BENGALI LETTER GHA
0999		BENGALI LETTER NGA
099a		BENGALI LETTER CA
099b		BENGALI LETTER CHA
099c		BENGALI LETTER JA
099d		BENGALI LETTER JHA
099e		BENGALI LETTER NYA
099f		BENGALI LETTER TTA
09a0		BENGALI LETTER TTHA
09a1		BENGALI LETTER DDA
09a2		BENGALI LETTER DDHA
09a3		BENGALI LETTER NNA
09a4		BENGALI LETTER TA
09a5		BENGALI LETTER THA
09a6		BENGALI LETTER DA
09a7		BENGALI LETTER DHA
09a8		BENGALI LETTER NA
09aa		BENGALI LETTER PA
09ab		BENGALI LETTER PHA
09ac		BENGALI LETTER BA
09ad		BENGALI LETTER BHA
09ae		BENGALI LETTER MA
09af		BENGALI LETTER YA
09b0		BENGALI LETTER RA
09b2		BENGALI LETTER LA
09b6		BENGALI LETTER SHA
09b7		BENGALI LETTER SSA
09b8		BENGALI LETTER SA
09b9		BENGALI LETTER HA
09bc		BENGALI SIGN NUKTA
09be		BENGALI VOWEL SIGN AA
09bf		BENGALI VOWEL SIGN I
09c0		BENGALI VOWEL SIGN II
09c1		BENGALI VOWEL SIGN U
09c2		BENGALI VOWEL SIGN UU
09c3		BENGALI VOWEL SIGN VOCALIC R
09c4		BENGALI VOWEL SIGN VOCALIC RR
09c7		BENGALI VOWEL SIGN E
09c8		BENGALI VOWEL SIGN AI
09cb		BENGALI VOWEL SIGN O
09cc		BENGALI VOWEL SIGN AU
09cd		BENGALI SIGN VIRAMA
09d7		BENGALI AU LENGTH MARK
09dc		BENGALI LETTER RRA
09dd		BENGALI LETTER RHA
09df		BENGALI LETTER YYA
09e0		BENGALI LETTER VOCALIC RR
09e1		BENGALI LETTER VOCALIC LL
09e2		BENGALI VOWEL SIGN VOCALIC L
09e3		BENGALI VOWEL SIGN VOCALIC LL
09e6		BENGALI DIGIT ZERO
09e7		BENGALI DIGIT ONE
09e8		BENGALI DIGIT TWO
09e9		BENGALI DIGIT THREE
09ea		BENGALI DIGIT FOUR
09eb		BENGALI DIGIT FIVE
09ec		BENGALI DIGIT SIX
09ed		BENGALI DIGIT SEVEN
09ee		BENGALI DIGIT EIGHT
09ef		BENGALI DIGIT NINE
09f0		BENGALI LETTER RA WITH MIDDLE DIAGONAL
09f1		BENGALI LETTER RA WITH LOWER DIAGONAL
09f2		BENGALI RUPEE MARK
09f3		BENGALI RUPEE SIGN
09f4		BENGALI CURRENCY NUMERATOR ONE
09f5		BENGALI CURRENCY NUMERATOR TWO
09f6		BENGALI CURRENCY NUMERATOR THREE
09f7		BENGALI CURRENCY NUMERATOR FOUR
09f8		BENGALI CURRENCY NUMERATOR ONE LESS THAN THE DENOMINATOR
09f9		BENGALI CURRENCY DENOMINATOR SIXTEEN
09fa		BENGALI ISSHAR
0a02		GURMUKHI SIGN BINDI
0a05		GURMUKHI LETTER A
0a06		GURMUKHI LETTER AA
0a07		GURMUKHI LETTER I
0a08		GURMUKHI LETTER II
0a09		GURMUKHI LETTER U
0a0a		GURMUKHI LETTER UU
0a0f		GURMUKHI LETTER EE
0a10		GURMUKHI LETTER AI
0a13		GURMUKHI LETTER OO
0a14		GURMUKHI LETTER AU
0a15		GURMUKHI LETTER KA
0a16		GURMUKHI LETTER KHA
0a17		GURMUKHI LETTER GA
0a18		GURMUKHI LETTER GHA
0a19		GURMUKHI LETTER NGA
0a1a		GURMUKHI LETTER CA
0a1b		GURMUKHI LETTER CHA
0a1c		GURMUKHI LETTER JA
0a1d		GURMUKHI LETTER JHA
0a1e		GURMUKHI LETTER NYA
0a1f		GURMUKHI LETTER TTA
0a20		GURMUKHI LETTER TTHA
0a21		GURMUKHI LETTER DDA
0a22		GURMUKHI LETTER DDHA
0a23		GURMUKHI LETTER NNA
0a24		GURMUKHI LETTER TA
0a25		GURMUKHI LETTER THA
0a26		GURMUKHI LETTER DA
0a27		GURMUKHI LETTER DHA
0a28		GURMUKHI LETTER NA
0a2a		GURMUKHI LETTER PA
0a2b		GURMUKHI LETTER PHA
0a2c		GURMUKHI LETTER BA
0a2d		GURMUKHI LETTER BHA
0a2e		GURMUKHI LETTER MA
0a2f		GURMUKHI LETTER YA
0a30		GURMUKHI LETTER RA
0a32		GURMUKHI LETTER LA
0a33		GURMUKHI LETTER LLA
0a35		GURMUKHI LETTER VA
0a36		GURMUKHI LETTER SHA
0a38		GURMUKHI LETTER SA
0a39		GURMUKHI LETTER HA
0a3c		GURMUKHI SIGN NUKTA
0a3e		GURMUKHI VOWEL SIGN AA
0a3f		GURMUKHI VOWEL SIGN I
0a40		GURMUKHI VOWEL SIGN II
0a41		GURMUKHI VOWEL SIGN U
0a42		GURMUKHI VOWEL SIGN UU
0a47		GURMUKHI VOWEL SIGN EE
0a48		GURMUKHI VOWEL SIGN AI
0a4b		GURMUKHI VOWEL SIGN OO
0a4c		GURMUKHI VOWEL SIGN AU
0a4d		GURMUKHI SIGN VIRAMA
0a59		GURMUKHI LETTER KHHA
0a5a		GURMUKHI LETTER GHHA
0a5b		GURMUKHI LETTER ZA
0a5c		GURMUKHI LETTER RRA
0a5e		GURMUKHI LETTER FA
0a66		GURMUKHI DIGIT ZERO
0a67		GURMUKHI DIGIT ONE
0a68		GURMUKHI DIGIT TWO
0a69		GURMUKHI DIGIT THREE
0a6a		GURMUKHI DIGIT FOUR
0a6b		GURMUKHI DIGIT FIVE
0a6c		GURMUKHI DIGIT SIX
0a6d		GURMUKHI DIGIT SEVEN
0a6e		GURMUKHI DIGIT EIGHT
0a6f		GURMUKHI DIGIT NINE
0a70		GURMUKHI TIPPI
0a71		GURMUKHI ADDAK
0a72		GURMUKHI IRI
0a73		GURMUKHI URA
0a74		GURMUKHI EK ONKAR
0a81		GUJARATI SIGN CANDRABINDU
0a82		GUJARATI SIGN ANUSVARA
0a83		GUJARATI SIGN VISARGA
0a85		GUJARATI LETTER A
0a86		GUJARATI LETTER AA
0a87		GUJARATI LETTER I
0a88		GUJARATI LETTER II
0a89		GUJARATI LETTER U
0a8a		GUJARATI LETTER UU
0a8b		GUJARATI LETTER VOCALIC R
0a8d		GUJARATI VOWEL CANDRA E
0a8f		GUJARATI LETTER E
0a90		GUJARATI LETTER AI
0a91		GUJARATI VOWEL CANDRA O
0a93		GUJARATI LETTER O
0a94		GUJARATI LETTER AU
0a95		GUJARATI LETTER KA
0a96		GUJARATI LETTER KHA
0a97		GUJARATI LETTER GA
0a98		GUJARATI LETTER GHA
0a99		GUJARATI LETTER NGA
0a9a		GUJARATI LETTER CA
0a9b		GUJARATI LETTER CHA
0a9c		GUJARATI LETTER JA
0a9d		GUJARATI LETTER JHA
0a9e		GUJARATI LETTER NYA
0a9f		GUJARATI LETTER TTA
0aa0		GUJARATI LETTER TTHA
0aa1		GUJARATI LETTER DDA
0aa2		GUJARATI LETTER DDHA
0aa3		GUJARATI LETTER NNA
0aa4		GUJARATI LETTER TA
0aa5		GUJARATI LETTER THA
0aa6		GUJARATI LETTER DA
0aa7		GUJARATI LETTER DHA
0aa8		GUJARATI LETTER NA
0aaa		GUJARATI LETTER PA
0aab		GUJARATI LETTER PHA
0aac		GUJARATI LETTER BA
0aad		GUJARATI LETTER BHA
0aae		GUJARATI LETTER MA
0aaf		GUJARATI LETTER YA
0ab0		GUJARATI LETTER RA
0ab2		GUJARATI LETTER LA
0ab3		GUJARATI LETTER LLA
0ab5		GUJARATI LETTER VA
0ab6		GUJARATI LETTER SHA
0ab7		GUJARATI LETTER SSA
0ab8		GUJARATI LETTER SA
0ab9		GUJARATI LETTER HA
0abc		GUJARATI SIGN NUKTA
0abd		GUJARATI SIGN AVAGRAHA
0abe		GUJARATI VOWEL SIGN AA
0abf		GUJARATI VOWEL SIGN I
0ac0		GUJARATI VOWEL SIGN II
0ac1		GUJARATI VOWEL SIGN U
0ac2		GUJARATI VOWEL SIGN UU
0ac3		GUJARATI VOWEL SIGN VOCALIC R
0ac4		GUJARATI VOWEL SIGN VOCALIC RR
0ac5		GUJARATI VOWEL SIGN CANDRA E
0ac7		GUJARATI VOWEL SIGN E
0ac8		GUJARATI VOWEL SIGN AI
0ac9		GUJARATI VOWEL SIGN CANDRA O
0acb		GUJARATI VOWEL SIGN O
0acc		GUJARATI VOWEL SIGN AU
0acd		GUJARATI SIGN VIRAMA
0ad0		GUJARATI OM
0ae0		GUJARATI LETTER VOCALIC RR
0ae6		GUJARATI DIGIT ZERO
0ae7		GUJARATI DIGIT ONE
0ae8		GUJARATI DIGIT TWO
0ae9		GUJARATI DIGIT THREE
0aea		GUJARATI DIGIT FOUR
0aeb		GUJARATI DIGIT FIVE
0aec		GUJARATI DIGIT SIX
0aed		GUJARATI DIGIT SEVEN
0aee		GUJARATI DIGIT EIGHT
0aef		GUJARATI DIGIT NINE
0b01		ORIYA SIGN CANDRABINDU
0b02		ORIYA SIGN ANUSVARA
0b03		ORIYA SIGN VISARGA
0b05		ORIYA LETTER A
0b06		ORIYA LETTER AA
0b07		ORIYA LETTER I
0b08		ORIYA LETTER II
0b09		ORIYA LETTER U
0b0a		ORIYA LETTER UU
0b0b		ORIYA LETTER VOCALIC R
0b0c		ORIYA LETTER VOCALIC L
0b0f		ORIYA LETTER E
0b10		ORIYA LETTER AI
0b13		ORIYA LETTER O
0b14		ORIYA LETTER AU
0b15		ORIYA LETTER KA
0b16		ORIYA LETTER KHA
0b17		ORIYA LETTER GA
0b18		ORIYA LETTER GHA
0b19		ORIYA LETTER NGA
0b1a		ORIYA LETTER CA
0b1b		ORIYA LETTER CHA
0b1c		ORIYA LETTER JA
0b1d		ORIYA LETTER JHA
0b1e		ORIYA LETTER NYA
0b1f		ORIYA LETTER TTA
0b20		ORIYA LETTER TTHA
0b21		ORIYA LETTER DDA
0b22		ORIYA LETTER DDHA
0b23		ORIYA LETTER NNA
0b24		ORIYA LETTER TA
0b25		ORIYA LETTER THA
0b26		ORIYA LETTER DA
0b27		ORIYA LETTER DHA
0b28		ORIYA LETTER NA
0b2a		ORIYA LETTER PA
0b2b		ORIYA LETTER PHA
0b2c		ORIYA LETTER BA
0b2d		ORIYA LETTER BHA
0b2e		ORIYA LETTER MA
0b2f		ORIYA LETTER YA
0b30		ORIYA LETTER RA
0b32		ORIYA LETTER LA
0b33		ORIYA LETTER LLA
0b36		ORIYA LETTER SHA
0b37		ORIYA LETTER SSA
0b38		ORIYA LETTER SA
0b39		ORIYA LETTER HA
0b3c		ORIYA SIGN NUKTA
0b3d		ORIYA SIGN AVAGRAHA
0b3e		ORIYA VOWEL SIGN AA
0b3f		ORIYA VOWEL SIGN I
0b40		ORIYA VOWEL SIGN II
0b41		ORIYA VOWEL SIGN U
0b42		ORIYA VOWEL SIGN UU
0b43		ORIYA VOWEL SIGN VOCALIC R
0b47		ORIYA VOWEL SIGN E
0b48		ORIYA VOWEL SIGN AI
0b4b		ORIYA VOWEL SIGN O
0b4c		ORIYA VOWEL SIGN AU
0b4d		ORIYA SIGN VIRAMA
0b56		ORIYA AI LENGTH MARK
0b57		ORIYA AU LENGTH MARK
0b5c		ORIYA LETTER RRA
0b5d		ORIYA LETTER RHA
0b5f		ORIYA LETTER YYA
0b60		ORIYA LETTER VOCALIC RR
0b61		ORIYA LETTER VOCALIC LL
0b66		ORIYA DIGIT ZERO
0b67		ORIYA DIGIT ONE
0b68		ORIYA DIGIT TWO
0b69		ORIYA DIGIT THREE
0b6a		ORIYA DIGIT FOUR
0b6b		ORIYA DIGIT FIVE
0b6c		ORIYA DIGIT SIX
0b6d		ORIYA DIGIT SEVEN
0b6e		ORIYA DIGIT EIGHT
0b6f		ORIYA DIGIT NINE
0b70		ORIYA ISSHAR
0b82		TAMIL SIGN ANUSVARA
0b83		TAMIL SIGN VISARGA
0b85		TAMIL LETTER A
0b86		TAMIL LETTER AA
0b87		TAMIL LETTER I
0b88		TAMIL LETTER II
0b89		TAMIL LETTER U
0b8a		TAMIL LETTER UU
0b8e		TAMIL LETTER E
0b8f		TAMIL LETTER EE
0b90		TAMIL LETTER AI
0b92		TAMIL LETTER O
0b93		TAMIL LETTER OO
0b94		TAMIL LETTER AU
0b95		TAMIL LETTER KA
0b99		TAMIL LETTER NGA
0b9a		TAMIL LETTER CA
0b9c		TAMIL LETTER JA
0b9e		TAMIL LETTER NYA
0b9f		TAMIL LETTER TTA
0ba3		TAMIL LETTER NNA
0ba4		TAMIL LETTER TA
0ba8		TAMIL LETTER NA
0ba9		TAMIL LETTER NNNA
0baa		TAMIL LETTER PA
0bae		TAMIL LETTER MA
0baf		TAMIL LETTER YA
0bb0		TAMIL LETTER RA
0bb1		TAMIL LETTER RRA
0bb2		TAMIL LETTER LA
0bb3		TAMIL LETTER LLA
0bb4		TAMIL LETTER LLLA
0bb5		TAMIL LETTER VA
0bb7		TAMIL LETTER SSA
0bb8		TAMIL LETTER SA
0bb9		TAMIL LETTER HA
0bbe		TAMIL VOWEL SIGN AA
0bbf		TAMIL VOWEL SIGN I
0bc0		TAMIL VOWEL SIGN II
0bc1		TAMIL VOWEL SIGN U
0bc2		TAMIL VOWEL SIGN UU
0bc6		TAMIL VOWEL SIGN E
0bc7		TAMIL VOWEL SIGN EE
0bc8		TAMIL VOWEL SIGN AI
0bca		TAMIL VOWEL SIGN O
0bcb		TAMIL VOWEL SIGN OO
0bcc		TAMIL VOWEL SIGN AU
0bcd		TAMIL SIGN VIRAMA
0bd7		TAMIL AU LENGTH MARK
0be7		TAMIL DIGIT ONE
0be8		TAMIL DIGIT TWO
0be9		TAMIL DIGIT THREE
0bea		TAMIL DIGIT FOUR
0beb		TAMIL DIGIT FIVE
0bec		TAMIL DIGIT SIX
0bed		TAMIL DIGIT SEVEN
0bee		TAMIL DIGIT EIGHT
0bef		TAMIL DIGIT NINE
0bf0		TAMIL NUMBER TEN
0bf1		TAMIL NUMBER ONE HUNDRED
0bf2		TAMIL NUMBER ONE THOUSAND
0c01		TELUGU SIGN CANDRABINDU
0c02		TELUGU SIGN ANUSVARA
0c03		TELUGU SIGN VISARGA
0c05		TELUGU LETTER A
0c06		TELUGU LETTER AA
0c07		TELUGU LETTER I
0c08		TELUGU LETTER II
0c09		TELUGU LETTER U
0c0a		TELUGU LETTER UU
0c0b		TELUGU LETTER VOCALIC R
0c0c		TELUGU LETTER VOCALIC L
0c0e		TELUGU LETTER E
0c0f		TELUGU LETTER EE
0c10		TELUGU LETTER AI
0c12		TELUGU LETTER O
0c13		TELUGU LETTER OO
0c14		TELUGU LETTER AU
0c15		TELUGU LETTER KA
0c16		TELUGU LETTER KHA
0c17		TELUGU LETTER GA
0c18		TELUGU LETTER GHA
0c19		TELUGU LETTER NGA
0c1a		TELUGU LETTER CA
0c1b		TELUGU LETTER CHA
0c1c		TELUGU LETTER JA
0c1d		TELUGU LETTER JHA
0c1e		TELUGU LETTER NYA
0c1f		TELUGU LETTER TTA
0c20		TELUGU LETTER TTHA
0c21		TELUGU LETTER DDA
0c22		TELUGU LETTER DDHA
0c23		TELUGU LETTER NNA
0c24		TELUGU LETTER TA
0c25		TELUGU LETTER THA
0c26		TELUGU LETTER DA
0c27		TELUGU LETTER DHA
0c28		TELUGU LETTER NA
0c2a		TELUGU LETTER PA
0c2b		TELUGU LETTER PHA
0c2c		TELUGU LETTER BA
0c2d		TELUGU LETTER BHA
0c2e		TELUGU LETTER MA
0c2f		TELUGU LETTER YA
0c30		TELUGU LETTER RA
0c31		TELUGU LETTER RRA
0c32		TELUGU LETTER LA
0c33		TELUGU LETTER LLA
0c35		TELUGU LETTER VA
0c36		TELUGU LETTER SHA
0c37		TELUGU LETTER SSA
0c38		TELUGU LETTER SA
0c39		TELUGU LETTER HA
0c3e		TELUGU VOWEL SIGN AA
0c3f		TELUGU VOWEL SIGN I
0c40		TELUGU VOWEL SIGN II
0c41		TELUGU VOWEL SIGN U
0c42		TELUGU VOWEL SIGN UU
0c43		TELUGU VOWEL SIGN VOCALIC R
0c44		TELUGU VOWEL SIGN VOCALIC RR
0c46		TELUGU VOWEL SIGN E
0c47		TELUGU VOWEL SIGN EE
0c48		TELUGU VOWEL SIGN AI
0c4a		TELUGU VOWEL SIGN O
0c4b		TELUGU VOWEL SIGN OO
0c4c		TELUGU VOWEL SIGN AU
0c4d		TELUGU SIGN VIRAMA
0c55		TELUGU LENGTH MARK
0c56		TELUGU AI LENGTH MARK
0c60		TELUGU LETTER VOCALIC RR
0c61		TELUGU LETTER VOCALIC LL
0c66		TELUGU DIGIT ZERO
0c67		TELUGU DIGIT ONE
0c68		TELUGU DIGIT TWO
0c69		TELUGU DIGIT THREE
0c6a		TELUGU DIGIT FOUR
0c6b		TELUGU DIGIT FIVE
0c6c		TELUGU DIGIT SIX
0c6d		TELUGU DIGIT SEVEN
0c6e		TELUGU DIGIT EIGHT
0c6f		TELUGU DIGIT NINE
0c82		KANNADA SIGN ANUSVARA
0c83		KANNADA SIGN VISARGA
0c85		KANNADA LETTER A
0c86		KANNADA LETTER AA
0c87		KANNADA LETTER I
0c88		KANNADA LETTER II
0c89		KANNADA LETTER U
0c8a		KANNADA LETTER UU
0c8b		KANNADA LETTER VOCALIC R
0c8c		KANNADA LETTER VOCALIC L
0c8e		KANNADA LETTER E
0c8f		KANNADA LETTER EE
0c90		KANNADA LETTER AI
0c92		KANNADA LETTER O
0c93		KANNADA LETTER OO
0c94		KANNADA LETTER AU
0c95		KANNADA LETTER KA
0c96		KANNADA LETTER KHA
0c97		KANNADA LETTER GA
0c98		KANNADA LETTER GHA
0c99		KANNADA LETTER NGA
0c9a		KANNADA LETTER CA
0c9b		KANNADA LETTER CHA
0c9c		KANNADA LETTER JA
0c9d		KANNADA LETTER JHA
0c9e		KANNADA LETTER NYA
0c9f		KANNADA LETTER TTA
0ca0		KANNADA LETTER TTHA
0ca1		KANNADA LETTER DDA
0ca2		KANNADA LETTER DDHA
0ca3		KANNADA LETTER NNA
0ca4		KANNADA LETTER TA
0ca5		KANNADA LETTER THA
0ca6		KANNADA LETTER DA
0ca7		KANNADA LETTER DHA
0ca8		KANNADA LETTER NA
0caa		KANNADA LETTER PA
0cab		KANNADA LETTER PHA
0cac		KANNADA LETTER BA
0cad		KANNADA LETTER BHA
0cae		KANNADA LETTER MA
0caf		KANNADA LETTER YA
0cb0		KANNADA LETTER RA
0cb1		KANNADA LETTER RRA
0cb2		KANNADA LETTER LA
0cb3		KANNADA LETTER LLA
0cb5		KANNADA LETTER VA
0cb6		KANNADA LETTER SHA
0cb7		KANNADA LETTER SSA
0cb8		KANNADA LETTER SA
0cb9		KANNADA LETTER HA
0cbe		KANNADA VOWEL SIGN AA
0cbf		KANNADA VOWEL SIGN I
0cc0		KANNADA VOWEL SIGN II
0cc1		KANNADA VOWEL SIGN U
0cc2		KANNADA VOWEL SIGN UU
0cc3		KANNADA VOWEL SIGN VOCALIC R
0cc4		KANNADA VOWEL SIGN VOCALIC RR
0cc6		KANNADA VOWEL SIGN E
0cc7		KANNADA VOWEL SIGN EE
0cc8		KANNADA VOWEL SIGN AI
0cca		KANNADA VOWEL SIGN O
0ccb		KANNADA VOWEL SIGN OO
0ccc		KANNADA VOWEL SIGN AU
0ccd		KANNADA SIGN VIRAMA
0cd5		KANNADA LENGTH MARK
0cd6		KANNADA AI LENGTH MARK
0cde		KANNADA LETTER FA
0ce0		KANNADA LETTER VOCALIC RR
0ce1		KANNADA LETTER VOCALIC LL
0ce6		KANNADA DIGIT ZERO
0ce7		KANNADA DIGIT ONE
0ce8		KANNADA DIGIT TWO
0ce9		KANNADA DIGIT THREE
0cea		KANNADA DIGIT FOUR
0ceb		KANNADA DIGIT FIVE
0cec		KANNADA DIGIT SIX
0ced		KANNADA DIGIT SEVEN
0cee		KANNADA DIGIT EIGHT
0cef		KANNADA DIGIT NINE
0d02		MALAYALAM SIGN ANUSVARA
0d03		MALAYALAM SIGN VISARGA
0d05		MALAYALAM LETTER A
0d06		MALAYALAM LETTER AA
0d07		MALAYALAM LETTER I
0d08		MALAYALAM LETTER II
0d09		MALAYALAM LETTER U
0d0a		MALAYALAM LETTER UU
0d0b		MALAYALAM LETTER VOCALIC R
0d0c		MALAYALAM LETTER VOCALIC L
0d0e		MALAYALAM LETTER E
0d0f		MALAYALAM LETTER EE
0d10		MALAYALAM LETTER AI
0d12		MALAYALAM LETTER O
0d13		MALAYALAM LETTER OO
0d14		MALAYALAM LETTER AU
0d15		MALAYALAM LETTER KA
0d16		MALAYALAM LETTER KHA
0d17		MALAYALAM LETTER GA
0d18		MALAYALAM LETTER GHA
0d19		MALAYALAM LETTER NGA
0d1a		MALAYALAM LETTER CA
0d1b		MALAYALAM LETTER CHA
0d1c		MALAYALAM LETTER JA
0d1d		MALAYALAM LETTER JHA
0d1e		MALAYALAM LETTER NYA
0d1f		MALAYALAM LETTER TTA
0d20		MALAYALAM LETTER TTHA
0d21		MALAYALAM LETTER DDA
0d22		MALAYALAM LETTER DDHA
0d23		MALAYALAM LETTER NNA
0d24		MALAYALAM LETTER TA
0d25		MALAYALAM LETTER THA
0d26		MALAYALAM LETTER DA
0d27		MALAYALAM LETTER DHA
0d28		MALAYALAM LETTER NA
0d2a		MALAYALAM LETTER PA
0d2b		MALAYALAM LETTER PHA
0d2c		MALAYALAM LETTER BA
0d2d		MALAYALAM LETTER BHA
0d2e		MALAYALAM LETTER MA
0d2f		MALAYALAM LETTER YA
0d30		MALAYALAM LETTER RA
0d31		MALAYALAM LETTER RRA
0d32		MALAYALAM LETTER LA
0d33		MALAYALAM LETTER LLA
0d34		MALAYALAM LETTER LLLA
0d35		MALAYALAM LETTER VA
0d36		MALAYALAM LETTER SHA
0d37		MALAYALAM LETTER SSA
0d38		MALAYALAM LETTER SA
0d39		MALAYALAM LETTER HA
0d3e		MALAYALAM VOWEL SIGN AA
0d3f		MALAYALAM VOWEL SIGN I
0d40		MALAYALAM VOWEL SIGN II
0d41		MALAYALAM VOWEL SIGN U
0d42		MALAYALAM VOWEL SIGN UU
0d43		MALAYALAM VOWEL SIGN VOCALIC R
0d46		MALAYALAM VOWEL SIGN E
0d47		MALAYALAM VOWEL SIGN EE
0d48		MALAYALAM VOWEL SIGN AI
0d4a		MALAYALAM VOWEL SIGN O
0d4b		MALAYALAM VOWEL SIGN OO
0d4c		MALAYALAM VOWEL SIGN AU
0d4d		MALAYALAM SIGN VIRAMA
0d57		MALAYALAM AU LENGTH MARK
0d60		MALAYALAM LETTER VOCALIC RR
0d61		MALAYALAM LETTER VOCALIC LL
0d66		MALAYALAM DIGIT ZERO
0d67		MALAYALAM DIGIT ONE
0d68		MALAYALAM DIGIT TWO
0d69		MALAYALAM DIGIT THREE
0d6a		MALAYALAM DIGIT FOUR
0d6b		MALAYALAM DIGIT FIVE
0d6c		MALAYALAM DIGIT SIX
0d6d		MALAYALAM DIGIT SEVEN
0d6e		MALAYALAM DIGIT EIGHT
0d6f		MALAYALAM DIGIT NINE
0e01		THAI CHARACTER KO KAI
0e02		THAI CHARACTER KHO KHAI
0e03		THAI CHARACTER KHO KHUAT
0e04		THAI CHARACTER KHO KHWAI
0e05		THAI CHARACTER KHO KHON
0e06		THAI CHARACTER KHO RAKHANG
0e07		THAI CHARACTER NGO NGU
0e08		THAI CHARACTER CHO CHAN
0e09		THAI CHARACTER CHO CHING
0e0a		THAI CHARACTER CHO CHANG
0e0b		THAI CHARACTER SO SO
0e0c		THAI CHARACTER CHO CHOE
0e0d		THAI CHARACTER YO YING
0e0e		THAI CHARACTER DO CHADA
0e0f		THAI CHARACTER TO PATAK
0e10		THAI CHARACTER THO THAN
0e11		THAI CHARACTER THO NANGMONTHO
0e12		THAI CHARACTER THO PHUTHAO
0e13		THAI CHARACTER NO NEN
0e14		THAI CHARACTER DO DEK
0e15		THAI CHARACTER TO TAO
0e16		THAI CHARACTER THO THUNG
0e17		THAI CHARACTER THO THAHAN
0e18		THAI CHARACTER THO THONG
0e19		THAI CHARACTER NO NU
0e1a		THAI CHARACTER BO BAIMAI
0e1b		THAI CHARACTER PO PLA
0e1c		THAI CHARACTER PHO PHUNG
0e1d		THAI CHARACTER FO FA
0e1e		THAI CHARACTER PHO PHAN
0e1f		THAI CHARACTER FO FAN
0e20		THAI CHARACTER PHO SAMPHAO
0e21		THAI CHARACTER MO MA
0e22		THAI CHARACTER YO YAK
0e23		THAI CHARACTER RO RUA
0e24		THAI CHARACTER RU
0e25		THAI CHARACTER LO LING
0e26		THAI CHARACTER LU
0e27		THAI CHARACTER WO WAEN
0e28		THAI CHARACTER SO SALA
0e29		THAI CHARACTER SO RUSI
0e2a		THAI CHARACTER SO SUA
0e2b		THAI CHARACTER HO HIP
0e2c		THAI CHARACTER LO CHULA
0e2d		THAI CHARACTER O ANG
0e2e		THAI CHARACTER HO NOKHUK
0e2f		THAI CHARACTER PAIYANNOI
0e30		THAI CHARACTER SARA A
0e31		THAI CHARACTER MAI HAN-AKAT
0e32		THAI CHARACTER SARA AA
0e33		THAI CHARACTER SARA AM
0e34		THAI CHARACTER SARA I
0e35		THAI CHARACTER SARA II
0e36		THAI CHARACTER SARA UE
0e37		THAI CHARACTER SARA UEE
0e38		THAI CHARACTER SARA U
0e39		THAI CHARACTER SARA UU
0e3a		THAI CHARACTER PHINTHU
0e3f		THAI CURRENCY SYMBOL BAHT
0e40		THAI CHARACTER SARA E
0e41		THAI CHARACTER SARA AE
0e42		THAI CHARACTER SARA O
0e43		THAI CHARACTER SARA AI MAIMUAN
0e44		THAI CHARACTER SARA AI MAIMALAI
0e45		THAI CHARACTER LAKKHANGYAO
0e46		THAI CHARACTER MAIYAMOK
0e47		THAI CHARACTER MAITAIKHU
0e48		THAI CHARACTER MAI EK
0e49		THAI CHARACTER MAI THO
0e4a		THAI CHARACTER MAI TRI
0e4b		THAI CHARACTER MAI CHATTAWA
0e4c		THAI CHARACTER THANTHAKHAT
0e4d		THAI CHARACTER NIKHAHIT
0e4e		THAI CHARACTER YAMAKKAN
0e4f		THAI CHARACTER FONGMAN
0e50		THAI DIGIT ZERO
0e51		THAI DIGIT ONE
0e52		THAI DIGIT TWO
0e53		THAI DIGIT THREE
0e54		THAI DIGIT FOUR
0e55		THAI DIGIT FIVE
0e56		THAI DIGIT SIX
0e57		THAI DIGIT SEVEN
0e58		THAI DIGIT EIGHT
0e59		THAI DIGIT NINE
0e5a		THAI CHARACTER ANGKHANKHU
0e5b		THAI CHARACTER KHOMUT
0e81		LAO LETTER KO
0e82		LAO LETTER KHO SUNG
0e84		LAO LETTER KHO TAM
0e87		LAO LETTER NGO
0e88		LAO LETTER CO
0e8a		LAO LETTER SO TAM
0e8d		LAO LETTER NYO
0e94		LAO LETTER DO
0e95		LAO LETTER TO
0e96		LAO LETTER THO SUNG
0e97		LAO LETTER THO TAM
0e99		LAO LETTER NO
0e9a		LAO LETTER BO
0e9b		LAO LETTER PO
0e9c		LAO LETTER PHO SUNG
0e9d		LAO LETTER FO TAM
0e9e		LAO LETTER PHO TAM
0e9f		LAO LETTER FO SUNG
0ea1		LAO LETTER MO
0ea2		LAO LETTER YO
0ea3		LAO LETTER LO LING
0ea5		LAO LETTER LO LOOT
0ea7		LAO LETTER WO
0eaa		LAO LETTER SO SUNG
0eab		LAO LETTER HO SUNG
0ead		LAO LETTER O
0eae		LAO LETTER HO TAM
0eaf		LAO ELLIPSIS
0eb0		LAO VOWEL SIGN A
0eb1		LAO VOWEL SIGN MAI KAN
0eb2		LAO VOWEL SIGN AA
0eb3		LAO VOWEL SIGN AM
0eb4		LAO VOWEL SIGN I
0eb5		LAO VOWEL SIGN II
0eb6		LAO VOWEL SIGN Y
0eb7		LAO VOWEL SIGN YY
0eb8		LAO VOWEL SIGN U
0eb9		LAO VOWEL SIGN UU
0ebb		LAO VOWEL SIGN MAI KON
0ebc		LAO SEMIVOWEL SIGN LO
0ebd		LAO SEMIVOWEL SIGN NYO
0ec0		LAO VOWEL SIGN E
0ec1		LAO VOWEL SIGN EI
0ec2		LAO VOWEL SIGN O
0ec3		LAO VOWEL SIGN AY
0ec4		LAO VOWEL SIGN AI
0ec6		LAO KO LA
0ec8		LAO TONE MAI EK
0ec9		LAO TONE MAI THO
0eca		LAO TONE MAI TI
0ecb		LAO TONE MAI CATAWA
0ecc		LAO CANCELLATION MARK
0ecd		LAO NIGGAHITA
0ed0		LAO DIGIT ZERO
0ed1		LAO DIGIT ONE
0ed2		LAO DIGIT TWO
0ed3		LAO DIGIT THREE
0ed4		LAO DIGIT FOUR
0ed5		LAO DIGIT FIVE
0ed6		LAO DIGIT SIX
0ed7		LAO DIGIT SEVEN
0ed8		LAO DIGIT EIGHT
0ed9		LAO DIGIT NINE
0edc		LAO HO NO
0edd		LAO HO MO
0f00		TIBETAN SYLLABLE OM
0f01		TIBETAN MARK GTER YIG MGO TRUNCATED A
0f02		TIBETAN MARK GTER YIG MGO -UM RNAM BCAD MA
0f03		TIBETAN MARK GTER YIG MGO -UM GTER TSHEG MA
0f04		TIBETAN MARK INITIAL YIG MGO MDUN MA
0f05		TIBETAN MARK CLOSING YIG MGO SGAB MA
0f06		TIBETAN MARK CARET YIG MGO PHUR SHAD MA
0f07		TIBETAN MARK YIG MGO TSHEG SHAD MA
0f08		TIBETAN MARK SBRUL SHAD
0f09		TIBETAN MARK BSKUR YIG MGO
0f0a		TIBETAN MARK BKA- SHOG YIG MGO
0f0b		TIBETAN MARK INTERSYLLABIC TSHEG
0f0c		TIBETAN MARK DELIMITER TSHEG BSTAR
0f0d		TIBETAN MARK SHAD
0f0e		TIBETAN MARK NYIS SHAD
0f0f		TIBETAN MARK TSHEG SHAD
0f10		TIBETAN MARK NYIS TSHEG SHAD
0f11		TIBETAN MARK RIN CHEN SPUNGS SHAD
0f12		TIBETAN MARK RGYA GRAM SHAD
0f13		TIBETAN MARK CARET -DZUD RTAGS ME LONG CAN
0f14		TIBETAN MARK GTER TSHEG
0f15		TIBETAN LOGOTYPE SIGN CHAD RTAGS
0f16		TIBETAN LOGOTYPE SIGN LHAG RTAGS
0f17		TIBETAN ASTROLOGICAL SIGN SGRA GCAN -CHAR RTAGS
0f18		TIBETAN ASTROLOGICAL SIGN -KHYUD PA
0f19		TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS
0f1a		TIBETAN SIGN RDEL DKAR GCIG
0f1b		TIBETAN SIGN RDEL DKAR GNYIS
0f1c		TIBETAN SIGN RDEL DKAR GSUM
0f1d		TIBETAN SIGN RDEL NAG GCIG
0f1e		TIBETAN SIGN RDEL NAG GNYIS
0f1f		TIBETAN SIGN RDEL DKAR RDEL NAG
0f20		TIBETAN DIGIT ZERO
0f21		TIBETAN DIGIT ONE
0f22		TIBETAN DIGIT TWO
0f23		TIBETAN DIGIT THREE
0f24		TIBETAN DIGIT FOUR
0f25		TIBETAN DIGIT FIVE
0f26		TIBETAN DIGIT SIX
0f27		TIBETAN DIGIT SEVEN
0f28		TIBETAN DIGIT EIGHT
0f29		TIBETAN DIGIT NINE
0f2a		TIBETAN DIGIT HALF ONE
0f2b		TIBETAN DIGIT HALF TWO
0f2c		TIBETAN DIGIT HALF THREE
0f2d		TIBETAN DIGIT HALF FOUR
0f2e		TIBETAN DIGIT HALF FIVE
0f2f		TIBETAN DIGIT HALF SIX
0f30		TIBETAN DIGIT HALF SEVEN
0f31		TIBETAN DIGIT HALF EIGHT
0f32		TIBETAN DIGIT HALF NINE
0f33		TIBETAN DIGIT HALF ZERO
0f34		TIBETAN MARK BSDUS RTAGS
0f35		TIBETAN MARK NGAS BZUNG NYI ZLA
0f36		TIBETAN MARK CARET -DZUD RTAGS BZHI MIG CAN
0f37		TIBETAN MARK NGAS BZUNG SGOR RTAGS
0f38		TIBETAN MARK CHE MGO
0f39		TIBETAN MARK TSA -PHRU
0f3a		TIBETAN MARK GUG RTAGS GYON
0f3b		TIBETAN MARK GUG RTAGS GYAS
0f3c		TIBETAN MARK ANG KHANG GYON
0f3d		TIBETAN MARK ANG KHANG GYAS
0f3e		TIBETAN SIGN YAR TSHES
0f3f		TIBETAN SIGN MAR TSHES
0f40		TIBETAN LETTER KA
0f41		TIBETAN LETTER KHA
0f42		TIBETAN LETTER GA
0f43		TIBETAN LETTER GHA
0f44		TIBETAN LETTER NGA
0f45		TIBETAN LETTER CA
0f46		TIBETAN LETTER CHA
0f47		TIBETAN LETTER JA
0f49		TIBETAN LETTER NYA
0f4a		TIBETAN LETTER TTA
0f4b		TIBETAN LETTER TTHA
0f4c		TIBETAN LETTER DDA
0f4d		TIBETAN LETTER DDHA
0f4e		TIBETAN LETTER NNA
0f4f		TIBETAN LETTER TA
0f50		TIBETAN LETTER THA
0f51		TIBETAN LETTER DA
0f52		TIBETAN LETTER DHA
0f53		TIBETAN LETTER NA
0f54		TIBETAN LETTER PA
0f55		TIBETAN LETTER PHA
0f56		TIBETAN LETTER BA
0f57		TIBETAN LETTER BHA
0f58		TIBETAN LETTER MA
0f59		TIBETAN LETTER TSA
0f5a		TIBETAN LETTER TSHA
0f5b		TIBETAN LETTER DZA
0f5c		TIBETAN LETTER DZHA
0f5d		TIBETAN LETTER WA
0f5e		TIBETAN LETTER ZHA
0f5f		TIBETAN LETTER ZA
0f60		TIBETAN LETTER -A
0f61		TIBETAN LETTER YA
0f62		TIBETAN LETTER RA
0f63		TIBETAN LETTER LA
0f64		TIBETAN LETTER SHA
0f65		TIBETAN LETTER SSA
0f66		TIBETAN LETTER SA
0f67		TIBETAN LETTER HA
0f68		TIBETAN LETTER A
0f69		TIBETAN LETTER KSSA
0f71		TIBETAN VOWEL SIGN AA
0f72		TIBETAN VOWEL SIGN I
0f73		TIBETAN VOWEL SIGN II
0f74		TIBETAN VOWEL SIGN U
0f75		TIBETAN VOWEL SIGN UU
0f76		TIBETAN VOWEL SIGN VOCALIC R
0f77		TIBETAN VOWEL SIGN VOCALIC RR
0f78		TIBETAN VOWEL SIGN VOCALIC L
0f79		TIBETAN VOWEL SIGN VOCALIC LL
0f7a		TIBETAN VOWEL SIGN E
0f7b		TIBETAN VOWEL SIGN EE
0f7c		TIBETAN VOWEL SIGN O
0f7d		TIBETAN VOWEL SIGN OO
0f7e		TIBETAN SIGN RJES SU NGA RO
0f7f		TIBETAN SIGN RNAM BCAD
0f80		TIBETAN VOWEL SIGN REVERSED I
0f81		TIBETAN VOWEL SIGN REVERSED II
0f82		TIBETAN SIGN NYI ZLA NAA DA
0f83		TIBETAN SIGN SNA LDAN
0f84		TIBETAN MARK HALANTA
0f85		TIBETAN MARK PALUTA
0f86		TIBETAN SIGN LCI RTAGS
0f87		TIBETAN SIGN YANG RTAGS
0f88		TIBETAN SIGN LCE TSA CAN
0f89		TIBETAN SIGN MCHU CAN
0f8a		TIBETAN SIGN GRU CAN RGYINGS
0f8b		TIBETAN SIGN GRU MED RGYINGS
0f90		TIBETAN SUBJOINED LETTER KA
0f91		TIBETAN SUBJOINED LETTER KHA
0f92		TIBETAN SUBJOINED LETTER GA
0f93		TIBETAN SUBJOINED LETTER GHA
0f94		TIBETAN SUBJOINED LETTER NGA
0f95		TIBETAN SUBJOINED LETTER CA
0f97		TIBETAN SUBJOINED LETTER JA
0f99		TIBETAN SUBJOINED LETTER NYA
0f9a		TIBETAN SUBJOINED LETTER TTA
0f9b		TIBETAN SUBJOINED LETTER TTHA
0f9c		TIBETAN SUBJOINED LETTER DDA
0f9d		TIBETAN SUBJOINED LETTER DDHA
0f9e		TIBETAN SUBJOINED LETTER NNA
0f9f		TIBETAN SUBJOINED LETTER TA
0fa0		TIBETAN SUBJOINED LETTER THA
0fa1		TIBETAN SUBJOINED LETTER DA
0fa2		TIBETAN SUBJOINED LETTER DHA
0fa3		TIBETAN SUBJOINED LETTER NA
0fa4		TIBETAN SUBJOINED LETTER PA
0fa5		TIBETAN SUBJOINED LETTER PHA
0fa6		TIBETAN SUBJOINED LETTER BA
0fa7		TIBETAN SUBJOINED LETTER BHA
0fa8		TIBETAN SUBJOINED LETTER MA
0fa9		TIBETAN SUBJOINED LETTER TSA
0faa		TIBETAN SUBJOINED LETTER TSHA
0fab		TIBETAN SUBJOINED LETTER DZA
0fac		TIBETAN SUBJOINED LETTER DZHA
0fad		TIBETAN SUBJOINED LETTER WA
0fb1		TIBETAN SUBJOINED LETTER YA
0fb2		TIBETAN SUBJOINED LETTER RA
0fb3		TIBETAN SUBJOINED LETTER LA
0fb4		TIBETAN SUBJOINED LETTER SHA
0fb5		TIBETAN SUBJOINED LETTER SSA
0fb6		TIBETAN SUBJOINED LETTER SA
0fb7		TIBETAN SUBJOINED LETTER HA
0fb9		TIBETAN SUBJOINED LETTER KSSA
10a0		GEORGIAN CAPITAL LETTER AN
10a1		GEORGIAN CAPITAL LETTER BAN
10a2		GEORGIAN CAPITAL LETTER GAN
10a3		GEORGIAN CAPITAL LETTER DON
10a4		GEORGIAN CAPITAL LETTER EN
10a5		GEORGIAN CAPITAL LETTER VIN
10a6		GEORGIAN CAPITAL LETTER ZEN
10a7		GEORGIAN CAPITAL LETTER TAN
10a8		GEORGIAN CAPITAL LETTER IN
10a9		GEORGIAN CAPITAL LETTER KAN
10aa		GEORGIAN CAPITAL LETTER LAS
10ab		GEORGIAN CAPITAL LETTER MAN
10ac		GEORGIAN CAPITAL LETTER NAR
10ad		GEORGIAN CAPITAL LETTER ON
10ae		GEORGIAN CAPITAL LETTER PAR
10af		GEORGIAN CAPITAL LETTER ZHAR
10b0		GEORGIAN CAPITAL LETTER RAE
10b1		GEORGIAN CAPITAL LETTER SAN
10b2		GEORGIAN CAPITAL LETTER TAR
10b3		GEORGIAN CAPITAL LETTER UN
10b4		GEORGIAN CAPITAL LETTER PHAR
10b5		GEORGIAN CAPITAL LETTER KHAR
10b6		GEORGIAN CAPITAL LETTER GHAN
10b7		GEORGIAN CAPITAL LETTER QAR
10b8		GEORGIAN CAPITAL LETTER SHIN
10b9		GEORGIAN CAPITAL LETTER CHIN
10ba		GEORGIAN CAPITAL LETTER CAN
10bb		GEORGIAN CAPITAL LETTER JIL
10bc		GEORGIAN CAPITAL LETTER CIL
10bd		GEORGIAN CAPITAL LETTER CHAR
10be		GEORGIAN CAPITAL LETTER XAN
10bf		GEORGIAN CAPITAL LETTER JHAN
10c0		GEORGIAN CAPITAL LETTER HAE
10c1		GEORGIAN CAPITAL LETTER HE
10c2		GEORGIAN CAPITAL LETTER HIE
10c3		GEORGIAN CAPITAL LETTER WE
10c4		GEORGIAN CAPITAL LETTER HAR
10c5		GEORGIAN CAPITAL LETTER HOE
10d0		GEORGIAN LETTER AN
10d1		GEORGIAN LETTER BAN
10d2		GEORGIAN LETTER GAN
10d3		GEORGIAN LETTER DON
10d4		GEORGIAN LETTER EN
10d5		GEORGIAN LETTER VIN
10d6		GEORGIAN LETTER ZEN
10d7		GEORGIAN LETTER TAN
10d8		GEORGIAN LETTER IN
10d9		GEORGIAN LETTER KAN
10da		GEORGIAN LETTER LAS
10db		GEORGIAN LETTER MAN
10dc		GEORGIAN LETTER NAR
10dd		GEORGIAN LETTER ON
10de		GEORGIAN LETTER PAR
10df		GEORGIAN LETTER ZHAR
10e0		GEORGIAN LETTER RAE
10e1		GEORGIAN LETTER SAN
10e2		GEORGIAN LETTER TAR
10e3		GEORGIAN LETTER UN
10e4		GEORGIAN LETTER PHAR
10e5		GEORGIAN LETTER KHAR
10e6		GEORGIAN LETTER GHAN
10e7		GEORGIAN LETTER QAR
10e8		GEORGIAN LETTER SHIN
10e9		GEORGIAN LETTER CHIN
10ea		GEORGIAN LETTER CAN
10eb		GEORGIAN LETTER JIL
10ec		GEORGIAN LETTER CIL
10ed		GEORGIAN LETTER CHAR
10ee		GEORGIAN LETTER XAN
10ef		GEORGIAN LETTER JHAN
10f0		GEORGIAN LETTER HAE
10f1		GEORGIAN LETTER HE
10f2		GEORGIAN LETTER HIE
10f3		GEORGIAN LETTER WE
10f4		GEORGIAN LETTER HAR
10f5		GEORGIAN LETTER HOE
10f6		GEORGIAN LETTER FI
10fb		GEORGIAN PARAGRAPH SEPARATOR
1100		HANGUL CHOSEONG KIYEOK
1101		HANGUL CHOSEONG SSANGKIYEOK
1102		HANGUL CHOSEONG NIEUN
1103		HANGUL CHOSEONG TIKEUT
1104		HANGUL CHOSEONG SSANGTIKEUT
1105		HANGUL CHOSEONG RIEUL
1106		HANGUL CHOSEONG MIEUM
1107		HANGUL CHOSEONG PIEUP
1108		HANGUL CHOSEONG SSANGPIEUP
1109		HANGUL CHOSEONG SIOS
110a		HANGUL CHOSEONG SSANGSIOS
110b		HANGUL CHOSEONG IEUNG
110c		HANGUL CHOSEONG CIEUC
110d		HANGUL CHOSEONG SSANGCIEUC
110e		HANGUL CHOSEONG CHIEUCH
110f		HANGUL CHOSEONG KHIEUKH
1110		HANGUL CHOSEONG THIEUTH
1111		HANGUL CHOSEONG PHIEUPH
1112		HANGUL CHOSEONG HIEUH
1113		HANGUL CHOSEONG NIEUN-KIYEOK
1114		HANGUL CHOSEONG SSANGNIEUN
1115		HANGUL CHOSEONG NIEUN-TIKEUT
1116		HANGUL CHOSEONG NIEUN-PIEUP
1117		HANGUL CHOSEONG TIKEUT-KIYEOK
1118		HANGUL CHOSEONG RIEUL-NIEUN
1119		HANGUL CHOSEONG SSANGRIEUL
111a		HANGUL CHOSEONG RIEUL-HIEUH
111b		HANGUL CHOSEONG KAPYEOUNRIEUL
111c		HANGUL CHOSEONG MIEUM-PIEUP
111d		HANGUL CHOSEONG KAPYEOUNMIEUM
111e		HANGUL CHOSEONG PIEUP-KIYEOK
111f		HANGUL CHOSEONG PIEUP-NIEUN
1120		HANGUL CHOSEONG PIEUP-TIKEUT
1121		HANGUL CHOSEONG PIEUP-SIOS
1122		HANGUL CHOSEONG PIEUP-SIOS-KIYEOK
1123		HANGUL CHOSEONG PIEUP-SIOS-TIKEUT
1124		HANGUL CHOSEONG PIEUP-SIOS-PIEUP
1125		HANGUL CHOSEONG PIEUP-SSANGSIOS
1126		HANGUL CHOSEONG PIEUP-SIOS-CIEUC
1127		HANGUL CHOSEONG PIEUP-CIEUC
1128		HANGUL CHOSEONG PIEUP-CHIEUCH
1129		HANGUL CHOSEONG PIEUP-THIEUTH
112a		HANGUL CHOSEONG PIEUP-PHIEUPH
112b		HANGUL CHOSEONG KAPYEOUNPIEUP
112c		HANGUL CHOSEONG KAPYEOUNSSANGPIEUP
112d		HANGUL CHOSEONG SIOS-KIYEOK
112e		HANGUL CHOSEONG SIOS-NIEUN
112f		HANGUL CHOSEONG SIOS-TIKEUT
1130		HANGUL CHOSEONG SIOS-RIEUL
1131		HANGUL CHOSEONG SIOS-MIEUM
1132		HANGUL CHOSEONG SIOS-PIEUP
1133		HANGUL CHOSEONG SIOS-PIEUP-KIYEOK
1134		HANGUL CHOSEONG SIOS-SSANGSIOS
1135		HANGUL CHOSEONG SIOS-IEUNG
1136		HANGUL CHOSEONG SIOS-CIEUC
1137		HANGUL CHOSEONG SIOS-CHIEUCH
1138		HANGUL CHOSEONG SIOS-KHIEUKH
1139		HANGUL CHOSEONG SIOS-THIEUTH
113a		HANGUL CHOSEONG SIOS-PHIEUPH
113b		HANGUL CHOSEONG SIOS-HIEUH
113c		HANGUL CHOSEONG CHITUEUMSIOS
113d		HANGUL CHOSEONG CHITUEUMSSANGSIOS
113e		HANGUL CHOSEONG CEONGCHIEUMSIOS
113f		HANGUL CHOSEONG CEONGCHIEUMSSANGSIOS
1140		HANGUL CHOSEONG PANSIOS
1141		HANGUL CHOSEONG IEUNG-KIYEOK
1142		HANGUL CHOSEONG IEUNG-TIKEUT
1143		HANGUL CHOSEONG IEUNG-MIEUM
1144		HANGUL CHOSEONG IEUNG-PIEUP
1145		HANGUL CHOSEONG IEUNG-SIOS
1146		HANGUL CHOSEONG IEUNG-PANSIOS
1147		HANGUL CHOSEONG SSANGIEUNG
1148		HANGUL CHOSEONG IEUNG-CIEUC
1149		HANGUL CHOSEONG IEUNG-CHIEUCH
114a		HANGUL CHOSEONG IEUNG-THIEUTH
114b		HANGUL CHOSEONG IEUNG-PHIEUPH
114c		HANGUL CHOSEONG YESIEUNG
114d		HANGUL CHOSEONG CIEUC-IEUNG
114e		HANGUL CHOSEONG CHITUEUMCIEUC
114f		HANGUL CHOSEONG CHITUEUMSSANGCIEUC
1150		HANGUL CHOSEONG CEONGCHIEUMCIEUC
1151		HANGUL CHOSEONG CEONGCHIEUMSSANGCIEUC
1152		HANGUL CHOSEONG CHIEUCH-KHIEUKH
1153		HANGUL CHOSEONG CHIEUCH-HIEUH
1154		HANGUL CHOSEONG CHITUEUMCHIEUCH
1155		HANGUL CHOSEONG CEONGCHIEUMCHIEUCH
1156		HANGUL CHOSEONG PHIEUPH-PIEUP
1157		HANGUL CHOSEONG KAPYEOUNPHIEUPH
1158		HANGUL CHOSEONG SSANGHIEUH
1159		HANGUL CHOSEONG YEORINHIEUH
115f		HANGUL CHOSEONG FILLER
1160		HANGUL JUNGSEONG FILLER
1161		HANGUL JUNGSEONG A
1162		HANGUL JUNGSEONG AE
1163		HANGUL JUNGSEONG YA
1164		HANGUL JUNGSEONG YAE
1165		HANGUL JUNGSEONG EO
1166		HANGUL JUNGSEONG E
1167		HANGUL JUNGSEONG YEO
1168		HANGUL JUNGSEONG YE
1169		HANGUL JUNGSEONG O
116a		HANGUL JUNGSEONG WA
116b		HANGUL JUNGSEONG WAE
116c		HANGUL JUNGSEONG OE
116d		HANGUL JUNGSEONG YO
116e		HANGUL JUNGSEONG U
116f		HANGUL JUNGSEONG WEO
1170		HANGUL JUNGSEONG WE
1171		HANGUL JUNGSEONG WI
1172		HANGUL JUNGSEONG YU
1173		HANGUL JUNGSEONG EU
1174		HANGUL JUNGSEONG YI
1175		HANGUL JUNGSEONG I
1176		HANGUL JUNGSEONG A-O
1177		HANGUL JUNGSEONG A-U
1178		HANGUL JUNGSEONG YA-O
1179		HANGUL JUNGSEONG YA-YO
117a		HANGUL JUNGSEONG EO-O
117b		HANGUL JUNGSEONG EO-U
117c		HANGUL JUNGSEONG EO-EU
117d		HANGUL JUNGSEONG YEO-O
117e		HANGUL JUNGSEONG YEO-U
117f		HANGUL JUNGSEONG O-EO
1180		HANGUL JUNGSEONG O-E
1181		HANGUL JUNGSEONG O-YE
1182		HANGUL JUNGSEONG O-O
1183		HANGUL JUNGSEONG O-U
1184		HANGUL JUNGSEONG YO-YA
1185		HANGUL JUNGSEONG YO-YAE
1186		HANGUL JUNGSEONG YO-YEO
1187		HANGUL JUNGSEONG YO-O
1188		HANGUL JUNGSEONG YO-I
1189		HANGUL JUNGSEONG U-A
118a		HANGUL JUNGSEONG U-AE
118b		HANGUL JUNGSEONG U-EO-EU
118c		HANGUL JUNGSEONG U-YE
118d		HANGUL JUNGSEONG U-U
118e		HANGUL JUNGSEONG YU-A
118f		HANGUL JUNGSEONG YU-EO
1190		HANGUL JUNGSEONG YU-E
1191		HANGUL JUNGSEONG YU-YEO
1192		HANGUL JUNGSEONG YU-YE
1193		HANGUL JUNGSEONG YU-U
1194		HANGUL JUNGSEONG YU-I
1195		HANGUL JUNGSEONG EU-U
1196		HANGUL JUNGSEONG EU-EU
1197		HANGUL JUNGSEONG YI-U
1198		HANGUL JUNGSEONG I-A
1199		HANGUL JUNGSEONG I-YA
119a		HANGUL JUNGSEONG I-O
119b		HANGUL JUNGSEONG I-U
119c		HANGUL JUNGSEONG I-EU
119d		HANGUL JUNGSEONG I-ARAEA
119e		HANGUL JUNGSEONG ARAEA
119f		HANGUL JUNGSEONG ARAEA-EO
11a0		HANGUL JUNGSEONG ARAEA-U
11a1		HANGUL JUNGSEONG ARAEA-I
11a2		HANGUL JUNGSEONG SSANGARAEA
11a8		HANGUL JONGSEONG KIYEOK
11a9		HANGUL JONGSEONG SSANGKIYEOK
11aa		HANGUL JONGSEONG KIYEOK-SIOS
11ab		HANGUL JONGSEONG NIEUN
11ac		HANGUL JONGSEONG NIEUN-CIEUC
11ad		HANGUL JONGSEONG NIEUN-HIEUH
11ae		HANGUL JONGSEONG TIKEUT
11af		HANGUL JONGSEONG RIEUL
11b0		HANGUL JONGSEONG RIEUL-KIYEOK
11b1		HANGUL JONGSEONG RIEUL-MIEUM
11b2		HANGUL JONGSEONG RIEUL-PIEUP
11b3		HANGUL JONGSEONG RIEUL-SIOS
11b4		HANGUL JONGSEONG RIEUL-THIEUTH
11b5		HANGUL JONGSEONG RIEUL-PHIEUPH
11b6		HANGUL JONGSEONG RIEUL-HIEUH
11b7		HANGUL JONGSEONG MIEUM
11b8		HANGUL JONGSEONG PIEUP
11b9		HANGUL JONGSEONG PIEUP-SIOS
11ba		HANGUL JONGSEONG SIOS
11bb		HANGUL JONGSEONG SSANGSIOS
11bc		HANGUL JONGSEONG IEUNG
11bd		HANGUL JONGSEONG CIEUC
11be		HANGUL JONGSEONG CHIEUCH
11bf		HANGUL JONGSEONG KHIEUKH
11c0		HANGUL JONGSEONG THIEUTH
11c1		HANGUL JONGSEONG PHIEUPH
11c2		HANGUL JONGSEONG HIEUH
11c3		HANGUL JONGSEONG KIYEOK-RIEUL
11c4		HANGUL JONGSEONG KIYEOK-SIOS-KIYEOK
11c5		HANGUL JONGSEONG NIEUN-KIYEOK
11c6		HANGUL JONGSEONG NIEUN-TIKEUT
11c7		HANGUL JONGSEONG NIEUN-SIOS
11c8		HANGUL JONGSEONG NIEUN-PANSIOS
11c9		HANGUL JONGSEONG NIEUN-THIEUTH
11ca		HANGUL JONGSEONG TIKEUT-KIYEOK
11cb		HANGUL JONGSEONG TIKEUT-RIEUL
11cc		HANGUL JONGSEONG RIEUL-KIYEOK-SIOS
11cd		HANGUL JONGSEONG RIEUL-NIEUN
11ce		HANGUL JONGSEONG RIEUL-TIKEUT
11cf		HANGUL JONGSEONG RIEUL-TIKEUT-HIEUH
11d0		HANGUL JONGSEONG SSANGRIEUL
11d1		HANGUL JONGSEONG RIEUL-MIEUM-KIYEOK
11d2		HANGUL JONGSEONG RIEUL-MIEUM-SIOS
11d3		HANGUL JONGSEONG RIEUL-PIEUP-SIOS
11d4		HANGUL JONGSEONG RIEUL-PIEUP-HIEUH
11d5		HANGUL JONGSEONG RIEUL-KAPYEOUNPIEUP
11d6		HANGUL JONGSEONG RIEUL-SSANGSIOS
11d7		HANGUL JONGSEONG RIEUL-PANSIOS
11d8		HANGUL JONGSEONG RIEUL-KHIEUKH
11d9		HANGUL JONGSEONG RIEUL-YEORINHIEUH
11da		HANGUL JONGSEONG MIEUM-KIYEOK
11db		HANGUL JONGSEONG MIEUM-RIEUL
11dc		HANGUL JONGSEONG MIEUM-PIEUP
11dd		HANGUL JONGSEONG MIEUM-SIOS
11de		HANGUL JONGSEONG MIEUM-SSANGSIOS
11df		HANGUL JONGSEONG MIEUM-PANSIOS
11e0		HANGUL JONGSEONG MIEUM-CHIEUCH
11e1		HANGUL JONGSEONG MIEUM-HIEUH
11e2		HANGUL JONGSEONG KAPYEOUNMIEUM
11e3		HANGUL JONGSEONG PIEUP-RIEUL
11e4		HANGUL JONGSEONG PIEUP-PHIEUPH
11e5		HANGUL JONGSEONG PIEUP-HIEUH
11e6		HANGUL JONGSEONG KAPYEOUNPIEUP
11e7		HANGUL JONGSEONG SIOS-KIYEOK
11e8		HANGUL JONGSEONG SIOS-TIKEUT
11e9		HANGUL JONGSEONG SIOS-RIEUL
11ea		HANGUL JONGSEONG SIOS-PIEUP
11eb		HANGUL JONGSEONG PANSIOS
11ec		HANGUL JONGSEONG IEUNG-KIYEOK
11ed		HANGUL JONGSEONG IEUNG-SSANGKIYEOK
11ee		HANGUL JONGSEONG SSANGIEUNG
11ef		HANGUL JONGSEONG IEUNG-KHIEUKH
11f0		HANGUL JONGSEONG YESIEUNG
11f1		HANGUL JONGSEONG YESIEUNG-SIOS
11f2		HANGUL JONGSEONG YESIEUNG-PANSIOS
11f3		HANGUL JONGSEONG PHIEUPH-PIEUP
11f4		HANGUL JONGSEONG KAPYEOUNPHIEUPH
11f5		HANGUL JONGSEONG HIEUH-NIEUN
11f6		HANGUL JONGSEONG HIEUH-RIEUL
11f7		HANGUL JONGSEONG HIEUH-MIEUM
11f8		HANGUL JONGSEONG HIEUH-PIEUP
11f9		HANGUL JONGSEONG YEORINHIEUH
1e00		LATIN CAPITAL LETTER A WITH RING BELOW
1e01		LATIN SMALL LETTER A WITH RING BELOW
1e02		LATIN CAPITAL LETTER B WITH DOT ABOVE
1e03		LATIN SMALL LETTER B WITH DOT ABOVE
1e04		LATIN CAPITAL LETTER B WITH DOT BELOW
1e05		LATIN SMALL LETTER B WITH DOT BELOW
1e06		LATIN CAPITAL LETTER B WITH LINE BELOW
1e07		LATIN SMALL LETTER B WITH LINE BELOW
1e08		LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE
1e09		LATIN SMALL LETTER C WITH CEDILLA AND ACUTE
1e0a		LATIN CAPITAL LETTER D WITH DOT ABOVE
1e0b		LATIN SMALL LETTER D WITH DOT ABOVE
1e0c		LATIN CAPITAL LETTER D WITH DOT BELOW
1e0d		LATIN SMALL LETTER D WITH DOT BELOW
1e0e		LATIN CAPITAL LETTER D WITH LINE BELOW
1e0f		LATIN SMALL LETTER D WITH LINE BELOW
1e10		LATIN CAPITAL LETTER D WITH CEDILLA
1e11		LATIN SMALL LETTER D WITH CEDILLA
1e12		LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW
1e13		LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW
1e14		LATIN CAPITAL LETTER E WITH MACRON AND GRAVE
1e15		LATIN SMALL LETTER E WITH MACRON AND GRAVE
1e16		LATIN CAPITAL LETTER E WITH MACRON AND ACUTE
1e17		LATIN SMALL LETTER E WITH MACRON AND ACUTE
1e18		LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW
1e19		LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW
1e1a		LATIN CAPITAL LETTER E WITH TILDE BELOW
1e1b		LATIN SMALL LETTER E WITH TILDE BELOW
1e1c		LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE
1e1d		LATIN SMALL LETTER E WITH CEDILLA AND BREVE
1e1e		LATIN CAPITAL LETTER F WITH DOT ABOVE
1e1f		LATIN SMALL LETTER F WITH DOT ABOVE
1e20		LATIN CAPITAL LETTER G WITH MACRON
1e21		LATIN SMALL LETTER G WITH MACRON
1e22		LATIN CAPITAL LETTER H WITH DOT ABOVE
1e23		LATIN SMALL LETTER H WITH DOT ABOVE
1e24		LATIN CAPITAL LETTER H WITH DOT BELOW
1e25		LATIN SMALL LETTER H WITH DOT BELOW
1e26		LATIN CAPITAL LETTER H WITH DIAERESIS
1e27		LATIN SMALL LETTER H WITH DIAERESIS
1e28		LATIN CAPITAL LETTER H WITH CEDILLA
1e29		LATIN SMALL LETTER H WITH CEDILLA
1e2a		LATIN CAPITAL LETTER H WITH BREVE BELOW
1e2b		LATIN SMALL LETTER H WITH BREVE BELOW
1e2c		LATIN CAPITAL LETTER I WITH TILDE BELOW
1e2d		LATIN SMALL LETTER I WITH TILDE BELOW
1e2e		LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE
1e2f		LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE
1e30		LATIN CAPITAL LETTER K WITH ACUTE
1e31		LATIN SMALL LETTER K WITH ACUTE
1e32		LATIN CAPITAL LETTER K WITH DOT BELOW
1e33		LATIN SMALL LETTER K WITH DOT BELOW
1e34		LATIN CAPITAL LETTER K WITH LINE BELOW
1e35		LATIN SMALL LETTER K WITH LINE BELOW
1e36		LATIN CAPITAL LETTER L WITH DOT BELOW
1e37		LATIN SMALL LETTER L WITH DOT BELOW
1e38		LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON
1e39		LATIN SMALL LETTER L WITH DOT BELOW AND MACRON
1e3a		LATIN CAPITAL LETTER L WITH LINE BELOW
1e3b		LATIN SMALL LETTER L WITH LINE BELOW
1e3c		LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW
1e3d		LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW
1e3e		LATIN CAPITAL LETTER M WITH ACUTE
1e3f		LATIN SMALL LETTER M WITH ACUTE
1e40		LATIN CAPITAL LETTER M WITH DOT ABOVE
1e41		LATIN SMALL LETTER M WITH DOT ABOVE
1e42		LATIN CAPITAL LETTER M WITH DOT BELOW
1e43		LATIN SMALL LETTER M WITH DOT BELOW
1e44		LATIN CAPITAL LETTER N WITH DOT ABOVE
1e45		LATIN SMALL LETTER N WITH DOT ABOVE
1e46		LATIN CAPITAL LETTER N WITH DOT BELOW
1e47		LATIN SMALL LETTER N WITH DOT BELOW
1e48		LATIN CAPITAL LETTER N WITH LINE BELOW
1e49		LATIN SMALL LETTER N WITH LINE BELOW
1e4a		LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW
1e4b		LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW
1e4c		LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
1e4d		LATIN SMALL LETTER O WITH TILDE AND ACUTE
1e4e		LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
1e4f		LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
1e50		LATIN CAPITAL LETTER O WITH MACRON AND GRAVE
1e51		LATIN SMALL LETTER O WITH MACRON AND GRAVE
1e52		LATIN CAPITAL LETTER O WITH MACRON AND ACUTE
1e53		LATIN SMALL LETTER O WITH MACRON AND ACUTE
1e54		LATIN CAPITAL LETTER P WITH ACUTE
1e55		LATIN SMALL LETTER P WITH ACUTE
1e56		LATIN CAPITAL LETTER P WITH DOT ABOVE
1e57		LATIN SMALL LETTER P WITH DOT ABOVE
1e58		LATIN CAPITAL LETTER R WITH DOT ABOVE
1e59		LATIN SMALL LETTER R WITH DOT ABOVE
1e5a		LATIN CAPITAL LETTER R WITH DOT BELOW
1e5b		LATIN SMALL LETTER R WITH DOT BELOW
1e5c		LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON
1e5d		LATIN SMALL LETTER R WITH DOT BELOW AND MACRON
1e5e		LATIN CAPITAL LETTER R WITH LINE BELOW
1e5f		LATIN SMALL LETTER R WITH LINE BELOW
1e60		LATIN CAPITAL LETTER S WITH DOT ABOVE
1e61		LATIN SMALL LETTER S WITH DOT ABOVE
1e62		LATIN CAPITAL LETTER S WITH DOT BELOW
1e63		LATIN SMALL LETTER S WITH DOT BELOW
1e64		LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE
1e65		LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE
1e66		LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE
1e67		LATIN SMALL LETTER S WITH CARON AND DOT ABOVE
1e68		LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE
1e69		LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE
1e6a		LATIN CAPITAL LETTER T WITH DOT ABOVE
1e6b		LATIN SMALL LETTER T WITH DOT ABOVE
1e6c		LATIN CAPITAL LETTER T WITH DOT BELOW
1e6d		LATIN SMALL LETTER T WITH DOT BELOW
1e6e		LATIN CAPITAL LETTER T WITH LINE BELOW
1e6f		LATIN SMALL LETTER T WITH LINE BELOW
1e70		LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW
1e71		LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW
1e72		LATIN CAPITAL LETTER U WITH DIAERESIS BELOW
1e73		LATIN SMALL LETTER U WITH DIAERESIS BELOW
1e74		LATIN CAPITAL LETTER U WITH TILDE BELOW
1e75		LATIN SMALL LETTER U WITH TILDE BELOW
1e76		LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW
1e77		LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW
1e78		LATIN CAPITAL LETTER U WITH TILDE AND ACUTE
1e79		LATIN SMALL LETTER U WITH TILDE AND ACUTE
1e7a		LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS
1e7b		LATIN SMALL LETTER U WITH MACRON AND DIAERESIS
1e7c		LATIN CAPITAL LETTER V WITH TILDE
1e7d		LATIN SMALL LETTER V WITH TILDE
1e7e		LATIN CAPITAL LETTER V WITH DOT BELOW
1e7f		LATIN SMALL LETTER V WITH DOT BELOW
1e80		LATIN CAPITAL LETTER W WITH GRAVE
1e81		LATIN SMALL LETTER W WITH GRAVE
1e82		LATIN CAPITAL LETTER W WITH ACUTE
1e83		LATIN SMALL LETTER W WITH ACUTE
1e84		LATIN CAPITAL LETTER W WITH DIAERESIS
1e85		LATIN SMALL LETTER W WITH DIAERESIS
1e86		LATIN CAPITAL LETTER W WITH DOT ABOVE
1e87		LATIN SMALL LETTER W WITH DOT ABOVE
1e88		LATIN CAPITAL LETTER W WITH DOT BELOW
1e89		LATIN SMALL LETTER W WITH DOT BELOW
1e8a		LATIN CAPITAL LETTER X WITH DOT ABOVE
1e8b		LATIN SMALL LETTER X WITH DOT ABOVE
1e8c		LATIN CAPITAL LETTER X WITH DIAERESIS
1e8d		LATIN SMALL LETTER X WITH DIAERESIS
1e8e		LATIN CAPITAL LETTER Y WITH DOT ABOVE
1e8f		LATIN SMALL LETTER Y WITH DOT ABOVE
1e90		LATIN CAPITAL LETTER Z WITH CIRCUMFLEX
1e91		LATIN SMALL LETTER Z WITH CIRCUMFLEX
1e92		LATIN CAPITAL LETTER Z WITH DOT BELOW
1e93		LATIN SMALL LETTER Z WITH DOT BELOW
1e94		LATIN CAPITAL LETTER Z WITH LINE BELOW
1e95		LATIN SMALL LETTER Z WITH LINE BELOW
1e96		LATIN SMALL LETTER H WITH LINE BELOW
1e97		LATIN SMALL LETTER T WITH DIAERESIS
1e98		LATIN SMALL LETTER W WITH RING ABOVE
1e99		LATIN SMALL LETTER Y WITH RING ABOVE
1e9a		LATIN SMALL LETTER A WITH RIGHT HALF RING
1e9b		LATIN SMALL LETTER LONG S WITH DOT ABOVE
1ea0		LATIN CAPITAL LETTER A WITH DOT BELOW
1ea1		LATIN SMALL LETTER A WITH DOT BELOW
1ea2		LATIN CAPITAL LETTER A WITH HOOK ABOVE
1ea3		LATIN SMALL LETTER A WITH HOOK ABOVE
1ea4		LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE
1ea5		LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE
1ea6		LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE
1ea7		LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE
1ea8		LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
1ea9		LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
1eaa		LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE
1eab		LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE
1eac		LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW
1ead		LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW
1eae		LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
1eaf		LATIN SMALL LETTER A WITH BREVE AND ACUTE
1eb0		LATIN CAPITAL LETTER A WITH BREVE AND GRAVE
1eb1		LATIN SMALL LETTER A WITH BREVE AND GRAVE
1eb2		LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE
1eb3		LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE
1eb4		LATIN CAPITAL LETTER A WITH BREVE AND TILDE
1eb5		LATIN SMALL LETTER A WITH BREVE AND TILDE
1eb6		LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW
1eb7		LATIN SMALL LETTER A WITH BREVE AND DOT BELOW
1eb8		LATIN CAPITAL LETTER E WITH DOT BELOW
1eb9		LATIN SMALL LETTER E WITH DOT BELOW
1eba		LATIN CAPITAL LETTER E WITH HOOK ABOVE
1ebb		LATIN SMALL LETTER E WITH HOOK ABOVE
1ebc		LATIN CAPITAL LETTER E WITH TILDE
1ebd		LATIN SMALL LETTER E WITH TILDE
1ebe		LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
1ebf		LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
1ec0		LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
1ec1		LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
1ec2		LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1ec3		LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1ec4		LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
1ec5		LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
1ec6		LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
1ec7		LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
1ec8		LATIN CAPITAL LETTER I WITH HOOK ABOVE
1ec9		LATIN SMALL LETTER I WITH HOOK ABOVE
1eca		LATIN CAPITAL LETTER I WITH DOT BELOW
1ecb		LATIN SMALL LETTER I WITH DOT BELOW
1ecc		LATIN CAPITAL LETTER O WITH DOT BELOW
1ecd		LATIN SMALL LETTER O WITH DOT BELOW
1ece		LATIN CAPITAL LETTER O WITH HOOK ABOVE
1ecf		LATIN SMALL LETTER O WITH HOOK ABOVE
1ed0		LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
1ed1		LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
1ed2		LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
1ed3		LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
1ed4		LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ed5		LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ed6		LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
1ed7		LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
1ed8		LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1ed9		LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1eda		LATIN CAPITAL LETTER O WITH HORN AND ACUTE
1edb		LATIN SMALL LETTER O WITH HORN AND ACUTE
1edc		LATIN CAPITAL LETTER O WITH HORN AND GRAVE
1edd		LATIN SMALL LETTER O WITH HORN AND GRAVE
1ede		LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE
1edf		LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE
1ee0		LATIN CAPITAL LETTER O WITH HORN AND TILDE
1ee1		LATIN SMALL LETTER O WITH HORN AND TILDE
1ee2		LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW
1ee3		LATIN SMALL LETTER O WITH HORN AND DOT BELOW
1ee4		LATIN CAPITAL LETTER U WITH DOT BELOW
1ee5		LATIN SMALL LETTER U WITH DOT BELOW
1ee6		LATIN CAPITAL LETTER U WITH HOOK ABOVE
1ee7		LATIN SMALL LETTER U WITH HOOK ABOVE
1ee8		LATIN CAPITAL LETTER U WITH HORN AND ACUTE
1ee9		LATIN SMALL LETTER U WITH HORN AND ACUTE
1eea		LATIN CAPITAL LETTER U WITH HORN AND GRAVE
1eeb		LATIN SMALL LETTER U WITH HORN AND GRAVE
1eec		LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE
1eed		LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE
1eee		LATIN CAPITAL LETTER U WITH HORN AND TILDE
1eef		LATIN SMALL LETTER U WITH HORN AND TILDE
1ef0		LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW
1ef1		LATIN SMALL LETTER U WITH HORN AND DOT BELOW
1ef2		LATIN CAPITAL LETTER Y WITH GRAVE
1ef3		LATIN SMALL LETTER Y WITH GRAVE
1ef4		LATIN CAPITAL LETTER Y WITH DOT BELOW
1ef5		LATIN SMALL LETTER Y WITH DOT BELOW
1ef6		LATIN CAPITAL LETTER Y WITH HOOK ABOVE
1ef7		LATIN SMALL LETTER Y WITH HOOK ABOVE
1ef8		LATIN CAPITAL LETTER Y WITH TILDE
1ef9		LATIN SMALL LETTER Y WITH TILDE
1f00		GREEK SMALL LETTER ALPHA WITH PSILI
1f01		GREEK SMALL LETTER ALPHA WITH DASIA
1f02		GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA
1f03		GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA
1f04		GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA
1f05		GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA
1f06		GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI
1f07		GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI
1f08		GREEK CAPITAL LETTER ALPHA WITH PSILI
1f09		GREEK CAPITAL LETTER ALPHA WITH DASIA
1f0a		GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA
1f0b		GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA
1f0c		GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA
1f0d		GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA
1f0e		GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI
1f0f		GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI
1f10		GREEK SMALL LETTER EPSILON WITH PSILI
1f11		GREEK SMALL LETTER EPSILON WITH DASIA
1f12		GREEK SMALL LETTER EPSILON WITH PSILI AND VARIA
1f13		GREEK SMALL LETTER EPSILON WITH DASIA AND VARIA
1f14		GREEK SMALL LETTER EPSILON WITH PSILI AND OXIA
1f15		GREEK SMALL LETTER EPSILON WITH DASIA AND OXIA
1f18		GREEK CAPITAL LETTER EPSILON WITH PSILI
1f19		GREEK CAPITAL LETTER EPSILON WITH DASIA
1f1a		GREEK CAPITAL LETTER EPSILON WITH PSILI AND VARIA
1f1b		GREEK CAPITAL LETTER EPSILON WITH DASIA AND VARIA
1f1c		GREEK CAPITAL LETTER EPSILON WITH PSILI AND OXIA
1f1d		GREEK CAPITAL LETTER EPSILON WITH DASIA AND OXIA
1f20		GREEK SMALL LETTER ETA WITH PSILI
1f21		GREEK SMALL LETTER ETA WITH DASIA
1f22		GREEK SMALL LETTER ETA WITH PSILI AND VARIA
1f23		GREEK SMALL LETTER ETA WITH DASIA AND VARIA
1f24		GREEK SMALL LETTER ETA WITH PSILI AND OXIA
1f25		GREEK SMALL LETTER ETA WITH DASIA AND OXIA
1f26		GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI
1f27		GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI
1f28		GREEK CAPITAL LETTER ETA WITH PSILI
1f29		GREEK CAPITAL LETTER ETA WITH DASIA
1f2a		GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA
1f2b		GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA
1f2c		GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA
1f2d		GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA
1f2e		GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI
1f2f		GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI
1f30		GREEK SMALL LETTER IOTA WITH PSILI
1f31		GREEK SMALL LETTER IOTA WITH DASIA
1f32		GREEK SMALL LETTER IOTA WITH PSILI AND VARIA
1f33		GREEK SMALL LETTER IOTA WITH DASIA AND VARIA
1f34		GREEK SMALL LETTER IOTA WITH PSILI AND OXIA
1f35		GREEK SMALL LETTER IOTA WITH DASIA AND OXIA
1f36		GREEK SMALL LETTER IOTA WITH PSILI AND PERISPOMENI
1f37		GREEK SMALL LETTER IOTA WITH DASIA AND PERISPOMENI
1f38		GREEK CAPITAL LETTER IOTA WITH PSILI
1f39		GREEK CAPITAL LETTER IOTA WITH DASIA
1f3a		GREEK CAPITAL LETTER IOTA WITH PSILI AND VARIA
1f3b		GREEK CAPITAL LETTER IOTA WITH DASIA AND VARIA
1f3c		GREEK CAPITAL LETTER IOTA WITH PSILI AND OXIA
1f3d		GREEK CAPITAL LETTER IOTA WITH DASIA AND OXIA
1f3e		GREEK CAPITAL LETTER IOTA WITH PSILI AND PERISPOMENI
1f3f		GREEK CAPITAL LETTER IOTA WITH DASIA AND PERISPOMENI
1f40		GREEK SMALL LETTER OMICRON WITH PSILI
1f41		GREEK SMALL LETTER OMICRON WITH DASIA
1f42		GREEK SMALL LETTER OMICRON WITH PSILI AND VARIA
1f43		GREEK SMALL LETTER OMICRON WITH DASIA AND VARIA
1f44		GREEK SMALL LETTER OMICRON WITH PSILI AND OXIA
1f45		GREEK SMALL LETTER OMICRON WITH DASIA AND OXIA
1f48		GREEK CAPITAL LETTER OMICRON WITH PSILI
1f49		GREEK CAPITAL LETTER OMICRON WITH DASIA
1f4a		GREEK CAPITAL LETTER OMICRON WITH PSILI AND VARIA
1f4b		GREEK CAPITAL LETTER OMICRON WITH DASIA AND VARIA
1f4c		GREEK CAPITAL LETTER OMICRON WITH PSILI AND OXIA
1f4d		GREEK CAPITAL LETTER OMICRON WITH DASIA AND OXIA
1f50		GREEK SMALL LETTER UPSILON WITH PSILI
1f51		GREEK SMALL LETTER UPSILON WITH DASIA
1f52		GREEK SMALL LETTER UPSILON WITH PSILI AND VARIA
1f53		GREEK SMALL LETTER UPSILON WITH DASIA AND VARIA
1f54		GREEK SMALL LETTER UPSILON WITH PSILI AND OXIA
1f55		GREEK SMALL LETTER UPSILON WITH DASIA AND OXIA
1f56		GREEK SMALL LETTER UPSILON WITH PSILI AND PERISPOMENI
1f57		GREEK SMALL LETTER UPSILON WITH DASIA AND PERISPOMENI
1f59		GREEK CAPITAL LETTER UPSILON WITH DASIA
1f5b		GREEK CAPITAL LETTER UPSILON WITH DASIA AND VARIA
1f5d		GREEK CAPITAL LETTER UPSILON WITH DASIA AND OXIA
1f5f		GREEK CAPITAL LETTER UPSILON WITH DASIA AND PERISPOMENI
1f60		GREEK SMALL LETTER OMEGA WITH PSILI
1f61		GREEK SMALL LETTER OMEGA WITH DASIA
1f62		GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA
1f63		GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA
1f64		GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA
1f65		GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA
1f66		GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI
1f67		GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI
1f68		GREEK CAPITAL LETTER OMEGA WITH PSILI
1f69		GREEK CAPITAL LETTER OMEGA WITH DASIA
1f6a		GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA
1f6b		GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA
1f6c		GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA
1f6d		GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA
1f6e		GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI
1f6f		GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI
1f70		GREEK SMALL LETTER ALPHA WITH VARIA
1f71		GREEK SMALL LETTER ALPHA WITH OXIA
1f72		GREEK SMALL LETTER EPSILON WITH VARIA
1f73		GREEK SMALL LETTER EPSILON WITH OXIA
1f74		GREEK SMALL LETTER ETA WITH VARIA
1f75		GREEK SMALL LETTER ETA WITH OXIA
1f76		GREEK SMALL LETTER IOTA WITH VARIA
1f77		GREEK SMALL LETTER IOTA WITH OXIA
1f78		GREEK SMALL LETTER OMICRON WITH VARIA
1f79		GREEK SMALL LETTER OMICRON WITH OXIA
1f7a		GREEK SMALL LETTER UPSILON WITH VARIA
1f7b		GREEK SMALL LETTER UPSILON WITH OXIA
1f7c		GREEK SMALL LETTER OMEGA WITH VARIA
1f7d		GREEK SMALL LETTER OMEGA WITH OXIA
1f80		GREEK SMALL LETTER ALPHA WITH PSILI AND YPOGEGRAMMENI
1f81		GREEK SMALL LETTER ALPHA WITH DASIA AND YPOGEGRAMMENI
1f82		GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA AND YPOGEGRAMMENI
1f83		GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA AND YPOGEGRAMMENI
1f84		GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA AND YPOGEGRAMMENI
1f85		GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA AND YPOGEGRAMMENI
1f86		GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI
1f87		GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI
1f88		GREEK CAPITAL LETTER ALPHA WITH PSILI AND PROSGEGRAMMENI
1f89		GREEK CAPITAL LETTER ALPHA WITH DASIA AND PROSGEGRAMMENI
1f8a		GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA AND PROSGEGRAMMENI
1f8b		GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA AND PROSGEGRAMMENI
1f8c		GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA AND PROSGEGRAMMENI
1f8d		GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA AND PROSGEGRAMMENI
1f8e		GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI
1f8f		GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI
1f90		GREEK SMALL LETTER ETA WITH PSILI AND YPOGEGRAMMENI
1f91		GREEK SMALL LETTER ETA WITH DASIA AND YPOGEGRAMMENI
1f92		GREEK SMALL LETTER ETA WITH PSILI AND VARIA AND YPOGEGRAMMENI
1f93		GREEK SMALL LETTER ETA WITH DASIA AND VARIA AND YPOGEGRAMMENI
1f94		GREEK SMALL LETTER ETA WITH PSILI AND OXIA AND YPOGEGRAMMENI
1f95		GREEK SMALL LETTER ETA WITH DASIA AND OXIA AND YPOGEGRAMMENI
1f96		GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI
1f97		GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI
1f98		GREEK CAPITAL LETTER ETA WITH PSILI AND PROSGEGRAMMENI
1f99		GREEK CAPITAL LETTER ETA WITH DASIA AND PROSGEGRAMMENI
1f9a		GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA AND PROSGEGRAMMENI
1f9b		GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA AND PROSGEGRAMMENI
1f9c		GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA AND PROSGEGRAMMENI
1f9d		GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA AND PROSGEGRAMMENI
1f9e		GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI
1f9f		GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI
1fa0		GREEK SMALL LETTER OMEGA WITH PSILI AND YPOGEGRAMMENI
1fa1		GREEK SMALL LETTER OMEGA WITH DASIA AND YPOGEGRAMMENI
1fa2		GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA AND YPOGEGRAMMENI
1fa3		GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA AND YPOGEGRAMMENI
1fa4		GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA AND YPOGEGRAMMENI
1fa5		GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA AND YPOGEGRAMMENI
1fa6		GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI
1fa7		GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI
1fa8		GREEK CAPITAL LETTER OMEGA WITH PSILI AND PROSGEGRAMMENI
1fa9		GREEK CAPITAL LETTER OMEGA WITH DASIA AND PROSGEGRAMMENI
1faa		GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA AND PROSGEGRAMMENI
1fab		GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA AND PROSGEGRAMMENI
1fac		GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA AND PROSGEGRAMMENI
1fad		GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA AND PROSGEGRAMMENI
1fae		GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI
1faf		GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI
1fb0		GREEK SMALL LETTER ALPHA WITH VRACHY
1fb1		GREEK SMALL LETTER ALPHA WITH MACRON
1fb2		GREEK SMALL LETTER ALPHA WITH VARIA AND YPOGEGRAMMENI
1fb3		GREEK SMALL LETTER ALPHA WITH YPOGEGRAMMENI
1fb4		GREEK SMALL LETTER ALPHA WITH OXIA AND YPOGEGRAMMENI
1fb6		GREEK SMALL LETTER ALPHA WITH PERISPOMENI
1fb7		GREEK SMALL LETTER ALPHA WITH PERISPOMENI AND YPOGEGRAMMENI
1fb8		GREEK CAPITAL LETTER ALPHA WITH VRACHY
1fb9		GREEK CAPITAL LETTER ALPHA WITH MACRON
1fba		GREEK CAPITAL LETTER ALPHA WITH VARIA
1fbb		GREEK CAPITAL LETTER ALPHA WITH OXIA
1fbc		GREEK CAPITAL LETTER ALPHA WITH PROSGEGRAMMENI
1fbd		GREEK KORONIS
1fbe		GREEK PROSGEGRAMMENI
1fbf		GREEK PSILI
1fc0		GREEK PERISPOMENI
1fc1		GREEK DIALYTIKA AND PERISPOMENI
1fc2		GREEK SMALL LETTER ETA WITH VARIA AND YPOGEGRAMMENI
1fc3		GREEK SMALL LETTER ETA WITH YPOGEGRAMMENI
1fc4		GREEK SMALL LETTER ETA WITH OXIA AND YPOGEGRAMMENI
1fc6		GREEK SMALL LETTER ETA WITH PERISPOMENI
1fc7		GREEK SMALL LETTER ETA WITH PERISPOMENI AND YPOGEGRAMMENI
1fc8		GREEK CAPITAL LETTER EPSILON WITH VARIA
1fc9		GREEK CAPITAL LETTER EPSILON WITH OXIA
1fca		GREEK CAPITAL LETTER ETA WITH VARIA
1fcb		GREEK CAPITAL LETTER ETA WITH OXIA
1fcc		GREEK CAPITAL LETTER ETA WITH PROSGEGRAMMENI
1fcd		GREEK PSILI AND VARIA
1fce		GREEK PSILI AND OXIA
1fcf		GREEK PSILI AND PERISPOMENI
1fd0		GREEK SMALL LETTER IOTA WITH VRACHY
1fd1		GREEK SMALL LETTER IOTA WITH MACRON
1fd2		GREEK SMALL LETTER IOTA WITH DIALYTIKA AND VARIA
1fd3		GREEK SMALL LETTER IOTA WITH DIALYTIKA AND OXIA
1fd6		GREEK SMALL LETTER IOTA WITH PERISPOMENI
1fd7		GREEK SMALL LETTER IOTA WITH DIALYTIKA AND PERISPOMENI
1fd8		GREEK CAPITAL LETTER IOTA WITH VRACHY
1fd9		GREEK CAPITAL LETTER IOTA WITH MACRON
1fda		GREEK CAPITAL LETTER IOTA WITH VARIA
1fdb		GREEK CAPITAL LETTER IOTA WITH OXIA
1fdd		GREEK DASIA AND VARIA
1fde		GREEK DASIA AND OXIA
1fdf		GREEK DASIA AND PERISPOMENI
1fe0		GREEK SMALL LETTER UPSILON WITH VRACHY
1fe1		GREEK SMALL LETTER UPSILON WITH MACRON
1fe2		GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND VARIA
1fe3		GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND OXIA
1fe4		GREEK SMALL LETTER RHO WITH PSILI
1fe5		GREEK SMALL LETTER RHO WITH DASIA
1fe6		GREEK SMALL LETTER UPSILON WITH PERISPOMENI
1fe7		GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND PERISPOMENI
1fe8		GREEK CAPITAL LETTER UPSILON WITH VRACHY
1fe9		GREEK CAPITAL LETTER UPSILON WITH MACRON
1fea		GREEK CAPITAL LETTER UPSILON WITH VARIA
1feb		GREEK CAPITAL LETTER UPSILON WITH OXIA
1fec		GREEK CAPITAL LETTER RHO WITH DASIA
1fed		GREEK DIALYTIKA AND VARIA
1fee		GREEK DIALYTIKA AND OXIA
1fef		GREEK VARIA
1ff2		GREEK SMALL LETTER OMEGA WITH VARIA AND YPOGEGRAMMENI
1ff3		GREEK SMALL LETTER OMEGA WITH YPOGEGRAMMENI
1ff4		GREEK SMALL LETTER OMEGA WITH OXIA AND YPOGEGRAMMENI
1ff6		GREEK SMALL LETTER OMEGA WITH PERISPOMENI
1ff7		GREEK SMALL LETTER OMEGA WITH PERISPOMENI AND YPOGEGRAMMENI
1ff8		GREEK CAPITAL LETTER OMICRON WITH VARIA
1ff9		GREEK CAPITAL LETTER OMICRON WITH OXIA
1ffa		GREEK CAPITAL LETTER OMEGA WITH VARIA
1ffb		GREEK CAPITAL LETTER OMEGA WITH OXIA
1ffc		GREEK CAPITAL LETTER OMEGA WITH PROSGEGRAMMENI
1ffd		GREEK OXIA
1ffe		GREEK DASIA
2000		EN QUAD
2001		EM QUAD
2002		EN SPACE
2003		EM SPACE
2004		THREE-PER-EM SPACE
2005		FOUR-PER-EM SPACE
2006		SIX-PER-EM SPACE
2007		FIGURE SPACE
2008		PUNCTUATION SPACE
2009		THIN SPACE
200a		HAIR SPACE
200b		ZERO WIDTH SPACE
200c		ZERO WIDTH NON-JOINER
200d		ZERO WIDTH JOINER
200e		LEFT-TO-RIGHT MARK
200f		RIGHT-TO-LEFT MARK
2010		HYPHEN
2011		NON-BREAKING HYPHEN
2012		FIGURE DASH
2013		EN DASH
2014		EM DASH
2015		HORIZONTAL BAR
2016		DOUBLE VERTICAL LINE
2017		DOUBLE LOW LINE
2018		LEFT SINGLE QUOTATION MARK
2019		RIGHT SINGLE QUOTATION MARK
201a		SINGLE LOW-9 QUOTATION MARK
201b		SINGLE HIGH-REVERSED-9 QUOTATION MARK
201c		LEFT DOUBLE QUOTATION MARK
201d		RIGHT DOUBLE QUOTATION MARK
201e		DOUBLE LOW-9 QUOTATION MARK
201f		DOUBLE HIGH-REVERSED-9 QUOTATION MARK
2020		DAGGER
2021		DOUBLE DAGGER
2022		BULLET
2023		TRIANGULAR BULLET
2024		ONE DOT LEADER
2025		TWO DOT LEADER
2026		HORIZONTAL ELLIPSIS
2027		HYPHENATION POINT
2028		LINE SEPARATOR
2029		PARAGRAPH SEPARATOR
202a		LEFT-TO-RIGHT EMBEDDING
202b		RIGHT-TO-LEFT EMBEDDING
202c		POP DIRECTIONAL FORMATTING
202d		LEFT-TO-RIGHT OVERRIDE
202e		RIGHT-TO-LEFT OVERRIDE
2030		PER MILLE SIGN
2031		PER TEN THOUSAND SIGN
2032		PRIME
2033		DOUBLE PRIME
2034		TRIPLE PRIME
2035		REVERSED PRIME
2036		REVERSED DOUBLE PRIME
2037		REVERSED TRIPLE PRIME
2038		CARET
2039		SINGLE LEFT-POINTING ANGLE QUOTATION MARK
203a		SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
203b		REFERENCE MARK
203c		DOUBLE EXCLAMATION MARK
203d		INTERROBANG
203e		OVERLINE
203f		UNDERTIE
2040		CHARACTER TIE
2041		CARET INSERTION POINT
2042		ASTERISM
2043		HYPHEN BULLET
2044		FRACTION SLASH
2045		LEFT SQUARE BRACKET WITH QUILL
2046		RIGHT SQUARE BRACKET WITH QUILL
206a		INHIBIT SYMMETRIC SWAPPING
206b		ACTIVATE SYMMETRIC SWAPPING
206c		INHIBIT ARABIC FORM SHAPING
206d		ACTIVATE ARABIC FORM SHAPING
206e		NATIONAL DIGIT SHAPES
206f		NOMINAL DIGIT SHAPES
2070		SUPERSCRIPT ZERO
2074		SUPERSCRIPT FOUR
2075		SUPERSCRIPT FIVE
2076		SUPERSCRIPT SIX
2077		SUPERSCRIPT SEVEN
2078		SUPERSCRIPT EIGHT
2079		SUPERSCRIPT NINE
207a		SUPERSCRIPT PLUS SIGN
207b		SUPERSCRIPT MINUS
207c		SUPERSCRIPT EQUALS SIGN
207d		SUPERSCRIPT LEFT PARENTHESIS
207e		SUPERSCRIPT RIGHT PARENTHESIS
207f		SUPERSCRIPT LATIN SMALL LETTER N
2080		SUBSCRIPT ZERO
2081		SUBSCRIPT ONE
2082		SUBSCRIPT TWO
2083		SUBSCRIPT THREE
2084		SUBSCRIPT FOUR
2085		SUBSCRIPT FIVE
2086		SUBSCRIPT SIX
2087		SUBSCRIPT SEVEN
2088		SUBSCRIPT EIGHT
2089		SUBSCRIPT NINE
208a		SUBSCRIPT PLUS SIGN
208b		SUBSCRIPT MINUS
208c		SUBSCRIPT EQUALS SIGN
208d		SUBSCRIPT LEFT PARENTHESIS
208e		SUBSCRIPT RIGHT PARENTHESIS
20a0		EURO-CURRENCY SIGN
20a1		COLON SIGN
20a2		CRUZEIRO SIGN
20a3		FRENCH FRANC SIGN
20a4		LIRA SIGN
20a5		MILL SIGN
20a6		NAIRA SIGN
20a7		PESETA SIGN
20a8		RUPEE SIGN
20a9		WON SIGN
20aa		NEW SHEQEL SIGN
20ab		DONG SIGN
20ac		EURO SIGN
20d0		COMBINING LEFT HARPOON ABOVE
20d1		COMBINING RIGHT HARPOON ABOVE
20d2		COMBINING LONG VERTICAL LINE OVERLAY
20d3		COMBINING SHORT VERTICAL LINE OVERLAY
20d4		COMBINING ANTICLOCKWISE ARROW ABOVE
20d5		COMBINING CLOCKWISE ARROW ABOVE
20d6		COMBINING LEFT ARROW ABOVE
20d7		COMBINING RIGHT ARROW ABOVE
20d8		COMBINING RING OVERLAY
20d9		COMBINING CLOCKWISE RING OVERLAY
20da		COMBINING ANTICLOCKWISE RING OVERLAY
20db		COMBINING THREE DOTS ABOVE
20dc		COMBINING FOUR DOTS ABOVE
20dd		COMBINING ENCLOSING CIRCLE
20de		COMBINING ENCLOSING SQUARE
20df		COMBINING ENCLOSING DIAMOND
20e0		COMBINING ENCLOSING CIRCLE BACKSLASH
20e1		COMBINING LEFT RIGHT ARROW ABOVE
2100		ACCOUNT OF
2101		ADDRESSED TO THE SUBJECT
2102		DOUBLE-STRUCK CAPITAL C
2103		DEGREE CELSIUS
2104		CENTRE LINE SYMBOL
2105		CARE OF
2106		CADA UNA
2107		EULER CONSTANT
2108		SCRUPLE
2109		DEGREE FAHRENHEIT
210a		SCRIPT SMALL G
210b		SCRIPT CAPITAL H
210c		BLACK-LETTER CAPITAL H
210d		DOUBLE-STRUCK CAPITAL H
210e		PLANCK CONSTANT
210f		PLANCK CONSTANT OVER TWO PI
2110		SCRIPT CAPITAL I
2111		BLACK-LETTER CAPITAL I
2112		SCRIPT CAPITAL L
2113		SCRIPT SMALL L
2114		L B BAR SYMBOL
2115		DOUBLE-STRUCK CAPITAL N
2116		NUMERO SIGN
2117		SOUND RECORDING COPYRIGHT
2118		SCRIPT CAPITAL P
2119		DOUBLE-STRUCK CAPITAL P
211a		DOUBLE-STRUCK CAPITAL Q
211b		SCRIPT CAPITAL R
211c		BLACK-LETTER CAPITAL R
211d		DOUBLE-STRUCK CAPITAL R
211e		PRESCRIPTION TAKE
211f		RESPONSE
2120		SERVICE MARK
2121		TELEPHONE SIGN
2122		TRADE MARK SIGN
2123		VERSICLE
2124		DOUBLE-STRUCK CAPITAL Z
2125		OUNCE SIGN
2126		OHM SIGN
2127		INVERTED OHM SIGN
2128		BLACK-LETTER CAPITAL Z
2129		TURNED GREEK SMALL LETTER IOTA
212a		KELVIN SIGN
212b		ANGSTROM SIGN
212c		SCRIPT CAPITAL B
212d		BLACK-LETTER CAPITAL C
212e		ESTIMATED SYMBOL
212f		SCRIPT SMALL E
2130		SCRIPT CAPITAL E
2131		SCRIPT CAPITAL F
2132		TURNED CAPITAL F
2133		SCRIPT CAPITAL M
2134		SCRIPT SMALL O
2135		ALEF SYMBOL
2136		BET SYMBOL
2137		GIMEL SYMBOL
2138		DALET SYMBOL
2153		VULGAR FRACTION ONE THIRD
2154		VULGAR FRACTION TWO THIRDS
2155		VULGAR FRACTION ONE FIFTH
2156		VULGAR FRACTION TWO FIFTHS
2157		VULGAR FRACTION THREE FIFTHS
2158		VULGAR FRACTION FOUR FIFTHS
2159		VULGAR FRACTION ONE SIXTH
215a		VULGAR FRACTION FIVE SIXTHS
215b		VULGAR FRACTION ONE EIGHTH
215c		VULGAR FRACTION THREE EIGHTHS
215d		VULGAR FRACTION FIVE EIGHTHS
215e		VULGAR FRACTION SEVEN EIGHTHS
215f		FRACTION NUMERATOR ONE
2160		ROMAN NUMERAL ONE
2161		ROMAN NUMERAL TWO
2162		ROMAN NUMERAL THREE
2163		ROMAN NUMERAL FOUR
2164		ROMAN NUMERAL FIVE
2165		ROMAN NUMERAL SIX
2166		ROMAN NUMERAL SEVEN
2167		ROMAN NUMERAL EIGHT
2168		ROMAN NUMERAL NINE
2169		ROMAN NUMERAL TEN
216a		ROMAN NUMERAL ELEVEN
216b		ROMAN NUMERAL TWELVE
216c		ROMAN NUMERAL FIFTY
216d		ROMAN NUMERAL ONE HUNDRED
216e		ROMAN NUMERAL FIVE HUNDRED
216f		ROMAN NUMERAL ONE THOUSAND
2170		SMALL ROMAN NUMERAL ONE
2171		SMALL ROMAN NUMERAL TWO
2172		SMALL ROMAN NUMERAL THREE
2173		SMALL ROMAN NUMERAL FOUR
2174		SMALL ROMAN NUMERAL FIVE
2175		SMALL ROMAN NUMERAL SIX
2176		SMALL ROMAN NUMERAL SEVEN
2177		SMALL ROMAN NUMERAL EIGHT
2178		SMALL ROMAN NUMERAL NINE
2179		SMALL ROMAN NUMERAL TEN
217a		SMALL ROMAN NUMERAL ELEVEN
217b		SMALL ROMAN NUMERAL TWELVE
217c		SMALL ROMAN NUMERAL FIFTY
217d		SMALL ROMAN NUMERAL ONE HUNDRED
217e		SMALL ROMAN NUMERAL FIVE HUNDRED
217f		SMALL ROMAN NUMERAL ONE THOUSAND
2180		ROMAN NUMERAL ONE THOUSAND C D
2181		ROMAN NUMERAL FIVE THOUSAND
2182		ROMAN NUMERAL TEN THOUSAND
2190		LEFTWARDS ARROW
2191		UPWARDS ARROW
2192		RIGHTWARDS ARROW
2193		DOWNWARDS ARROW
2194		LEFT RIGHT ARROW
2195		UP DOWN ARROW
2196		NORTH WEST ARROW
2197		NORTH EAST ARROW
2198		SOUTH EAST ARROW
2199		SOUTH WEST ARROW
219a		LEFTWARDS ARROW WITH STROKE
219b		RIGHTWARDS ARROW WITH STROKE
219c		LEFTWARDS WAVE ARROW
219d		RIGHTWARDS WAVE ARROW
219e		LEFTWARDS TWO HEADED ARROW
219f		UPWARDS TWO HEADED ARROW
21a0		RIGHTWARDS TWO HEADED ARROW
21a1		DOWNWARDS TWO HEADED ARROW
21a2		LEFTWARDS ARROW WITH TAIL
21a3		RIGHTWARDS ARROW WITH TAIL
21a4		LEFTWARDS ARROW FROM BAR
21a5		UPWARDS ARROW FROM BAR
21a6		RIGHTWARDS ARROW FROM BAR
21a7		DOWNWARDS ARROW FROM BAR
21a8		UP DOWN ARROW WITH BASE
21a9		LEFTWARDS ARROW WITH HOOK
21aa		RIGHTWARDS ARROW WITH HOOK
21ab		LEFTWARDS ARROW WITH LOOP
21ac		RIGHTWARDS ARROW WITH LOOP
21ad		LEFT RIGHT WAVE ARROW
21ae		LEFT RIGHT ARROW WITH STROKE
21af		DOWNWARDS ZIGZAG ARROW
21b0		UPWARDS ARROW WITH TIP LEFTWARDS
21b1		UPWARDS ARROW WITH TIP RIGHTWARDS
21b2		DOWNWARDS ARROW WITH TIP LEFTWARDS
21b3		DOWNWARDS ARROW WITH TIP RIGHTWARDS
21b4		RIGHTWARDS ARROW WITH CORNER DOWNWARDS
21b5		DOWNWARDS ARROW WITH CORNER LEFTWARDS
21b6		ANTICLOCKWISE TOP SEMICIRCLE ARROW
21b7		CLOCKWISE TOP SEMICIRCLE ARROW
21b8		NORTH WEST ARROW TO LONG BAR
21b9		LEFTWARDS ARROW TO BAR OVER RIGHTWARDS ARROW TO BAR
21ba		ANTICLOCKWISE OPEN CIRCLE ARROW
21bb		CLOCKWISE OPEN CIRCLE ARROW
21bc		LEFTWARDS HARPOON WITH BARB UPWARDS
21bd		LEFTWARDS HARPOON WITH BARB DOWNWARDS
21be		UPWARDS HARPOON WITH BARB RIGHTWARDS
21bf		UPWARDS HARPOON WITH BARB LEFTWARDS
21c0		RIGHTWARDS HARPOON WITH BARB UPWARDS
21c1		RIGHTWARDS HARPOON WITH BARB DOWNWARDS
21c2		DOWNWARDS HARPOON WITH BARB RIGHTWARDS
21c3		DOWNWARDS HARPOON WITH BARB LEFTWARDS
21c4		RIGHTWARDS ARROW OVER LEFTWARDS ARROW
21c5		UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW
21c6		LEFTWARDS ARROW OVER RIGHTWARDS ARROW
21c7		LEFTWARDS PAIRED ARROWS
21c8		UPWARDS PAIRED ARROWS
21c9		RIGHTWARDS PAIRED ARROWS
21ca		DOWNWARDS PAIRED ARROWS
21cb		LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON
21cc		RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON
21cd		LEFTWARDS DOUBLE ARROW WITH STROKE
21ce		LEFT RIGHT DOUBLE ARROW WITH STROKE
21cf		RIGHTWARDS DOUBLE ARROW WITH STROKE
21d0		LEFTWARDS DOUBLE ARROW
21d1		UPWARDS DOUBLE ARROW
21d2		RIGHTWARDS DOUBLE ARROW
21d3		DOWNWARDS DOUBLE ARROW
21d4		LEFT RIGHT DOUBLE ARROW
21d5		UP DOWN DOUBLE ARROW
21d6		NORTH WEST DOUBLE ARROW
21d7		NORTH EAST DOUBLE ARROW
21d8		SOUTH EAST DOUBLE ARROW
21d9		SOUTH WEST DOUBLE ARROW
21da		LEFTWARDS TRIPLE ARROW
21db		RIGHTWARDS TRIPLE ARROW
21dc		LEFTWARDS SQUIGGLE ARROW
21dd		RIGHTWARDS SQUIGGLE ARROW
21de		UPWARDS ARROW WITH DOUBLE STROKE
21df		DOWNWARDS ARROW WITH DOUBLE STROKE
21e0		LEFTWARDS DASHED ARROW
21e1		UPWARDS DASHED ARROW
21e2		RIGHTWARDS DASHED ARROW
21e3		DOWNWARDS DASHED ARROW
21e4		LEFTWARDS ARROW TO BAR
21e5		RIGHTWARDS ARROW TO BAR
21e6		LEFTWARDS WHITE ARROW
21e7		UPWARDS WHITE ARROW
21e8		RIGHTWARDS WHITE ARROW
21e9		DOWNWARDS WHITE ARROW
21ea		UPWARDS WHITE ARROW FROM BAR
2200		FOR ALL
2201		COMPLEMENT
2202		PARTIAL DIFFERENTIAL
2203		THERE EXISTS
2204		THERE DOES NOT EXIST
2205		EMPTY SET
2206		INCREMENT
2207		NABLA
2208		ELEMENT OF
2209		NOT AN ELEMENT OF
220a		SMALL ELEMENT OF
220b		CONTAINS AS MEMBER
220c		DOES NOT CONTAIN AS MEMBER
220d		SMALL CONTAINS AS MEMBER
220e		END OF PROOF
220f		N-ARY PRODUCT
2210		N-ARY COPRODUCT
2211		N-ARY SUMMATION
2212		MINUS SIGN
2213		MINUS-OR-PLUS SIGN
2214		DOT PLUS
2215		DIVISION SLASH
2216		SET MINUS
2217		ASTERISK OPERATOR
2218		RING OPERATOR
2219		BULLET OPERATOR
221a		SQUARE ROOT
221b		CUBE ROOT
221c		FOURTH ROOT
221d		PROPORTIONAL TO
221e		INFINITY
221f		RIGHT ANGLE
2220		ANGLE
2221		MEASURED ANGLE
2222		SPHERICAL ANGLE
2223		DIVIDES
2224		DOES NOT DIVIDE
2225		PARALLEL TO
2226		NOT PARALLEL TO
2227		LOGICAL AND
2228		LOGICAL OR
2229		INTERSECTION
222a		UNION
222b		INTEGRAL
222c		DOUBLE INTEGRAL
222d		TRIPLE INTEGRAL
222e		CONTOUR INTEGRAL
222f		SURFACE INTEGRAL
2230		VOLUME INTEGRAL
2231		CLOCKWISE INTEGRAL
2232		CLOCKWISE CONTOUR INTEGRAL
2233		ANTICLOCKWISE CONTOUR INTEGRAL
2234		THEREFORE
2235		BECAUSE
2236		RATIO
2237		PROPORTION
2238		DOT MINUS
2239		EXCESS
223a		GEOMETRIC PROPORTION
223b		HOMOTHETIC
223c		TILDE OPERATOR
223d		REVERSED TILDE
223e		INVERTED LAZY S
223f		SINE WAVE
2240		WREATH PRODUCT
2241		NOT TILDE
2242		MINUS TILDE
2243		ASYMPTOTICALLY EQUAL TO
2244		NOT ASYMPTOTICALLY EQUAL TO
2245		APPROXIMATELY EQUAL TO
2246		APPROXIMATELY BUT NOT ACTUALLY EQUAL TO
2247		NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO
2248		ALMOST EQUAL TO
2249		NOT ALMOST EQUAL TO
224a		ALMOST EQUAL OR EQUAL TO
224b		TRIPLE TILDE
224c		ALL EQUAL TO
224d		EQUIVALENT TO
224e		GEOMETRICALLY EQUIVALENT TO
224f		DIFFERENCE BETWEEN
2250		APPROACHES THE LIMIT
2251		GEOMETRICALLY EQUAL TO
2252		APPROXIMATELY EQUAL TO OR THE IMAGE OF
2253		IMAGE OF OR APPROXIMATELY EQUAL TO
2254		COLON EQUALS
2255		EQUALS COLON
2256		RING IN EQUAL TO
2257		RING EQUAL TO
2258		CORRESPONDS TO
2259		ESTIMATES
225a		EQUIANGULAR TO
225b		STAR EQUALS
225c		DELTA EQUAL TO
225d		EQUAL TO BY DEFINITION
225e		MEASURED BY
225f		QUESTIONED EQUAL TO
2260		NOT EQUAL TO
2261		IDENTICAL TO
2262		NOT IDENTICAL TO
2263		STRICTLY EQUIVALENT TO
2264		LESS-THAN OR EQUAL TO
2265		GREATER-THAN OR EQUAL TO
2266		LESS-THAN OVER EQUAL TO
2267		GREATER-THAN OVER EQUAL TO
2268		LESS-THAN BUT NOT EQUAL TO
2269		GREATER-THAN BUT NOT EQUAL TO
226a		MUCH LESS-THAN
226b		MUCH GREATER-THAN
226c		BETWEEN
226d		NOT EQUIVALENT TO
226e		NOT LESS-THAN
226f		NOT GREATER-THAN
2270		NEITHER LESS-THAN NOR EQUAL TO
2271		NEITHER GREATER-THAN NOR EQUAL TO
2272		LESS-THAN OR EQUIVALENT TO
2273		GREATER-THAN OR EQUIVALENT TO
2274		NEITHER LESS-THAN NOR EQUIVALENT TO
2275		NEITHER GREATER-THAN NOR EQUIVALENT TO
2276		LESS-THAN OR GREATER-THAN
2277		GREATER-THAN OR LESS-THAN
2278		NEITHER LESS-THAN NOR GREATER-THAN
2279		NEITHER GREATER-THAN NOR LESS-THAN
227a		PRECEDES
227b		SUCCEEDS
227c		PRECEDES OR EQUAL TO
227d		SUCCEEDS OR EQUAL TO
227e		PRECEDES OR EQUIVALENT TO
227f		SUCCEEDS OR EQUIVALENT TO
2280		DOES NOT PRECEDE
2281		DOES NOT SUCCEED
2282		SUBSET OF
2283		SUPERSET OF
2284		NOT A SUBSET OF
2285		NOT A SUPERSET OF
2286		SUBSET OF OR EQUAL TO
2287		SUPERSET OF OR EQUAL TO
2288		NEITHER A SUBSET OF NOR EQUAL TO
2289		NEITHER A SUPERSET OF NOR EQUAL TO
228a		SUBSET OF WITH NOT EQUAL TO
228b		SUPERSET OF WITH NOT EQUAL TO
228c		MULTISET
228d		MULTISET MULTIPLICATION
228e		MULTISET UNION
228f		SQUARE IMAGE OF
2290		SQUARE ORIGINAL OF
2291		SQUARE IMAGE OF OR EQUAL TO
2292		SQUARE ORIGINAL OF OR EQUAL TO
2293		SQUARE CAP
2294		SQUARE CUP
2295		CIRCLED PLUS
2296		CIRCLED MINUS
2297		CIRCLED TIMES
2298		CIRCLED DIVISION SLASH
2299		CIRCLED DOT OPERATOR
229a		CIRCLED RING OPERATOR
229b		CIRCLED ASTERISK OPERATOR
229c		CIRCLED EQUALS
229d		CIRCLED DASH
229e		SQUARED PLUS
229f		SQUARED MINUS
22a0		SQUARED TIMES
22a1		SQUARED DOT OPERATOR
22a2		RIGHT TACK
22a3		LEFT TACK
22a4		DOWN TACK
22a5		UP TACK
22a6		ASSERTION
22a7		MODELS
22a8		TRUE
22a9		FORCES
22aa		TRIPLE VERTICAL BAR RIGHT TURNSTILE
22ab		DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE
22ac		DOES NOT PROVE
22ad		NOT TRUE
22ae		DOES NOT FORCE
22af		NEGATED DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE
22b0		PRECEDES UNDER RELATION
22b1		SUCCEEDS UNDER RELATION
22b2		NORMAL SUBGROUP OF
22b3		CONTAINS AS NORMAL SUBGROUP
22b4		NORMAL SUBGROUP OF OR EQUAL TO
22b5		CONTAINS AS NORMAL SUBGROUP OR EQUAL TO
22b6		ORIGINAL OF
22b7		IMAGE OF
22b8		MULTIMAP
22b9		HERMITIAN CONJUGATE MATRIX
22ba		INTERCALATE
22bb		XOR
22bc		NAND
22bd		NOR
22be		RIGHT ANGLE WITH ARC
22bf		RIGHT TRIANGLE
22c0		N-ARY LOGICAL AND
22c1		N-ARY LOGICAL OR
22c2		N-ARY INTERSECTION
22c3		N-ARY UNION
22c4		DIAMOND OPERATOR
22c5		DOT OPERATOR
22c6		STAR OPERATOR
22c7		DIVISION TIMES
22c8		BOWTIE
22c9		LEFT NORMAL FACTOR SEMIDIRECT PRODUCT
22ca		RIGHT NORMAL FACTOR SEMIDIRECT PRODUCT
22cb		LEFT SEMIDIRECT PRODUCT
22cc		RIGHT SEMIDIRECT PRODUCT
22cd		REVERSED TILDE EQUALS
22ce		CURLY LOGICAL OR
22cf		CURLY LOGICAL AND
22d0		DOUBLE SUBSET
22d1		DOUBLE SUPERSET
22d2		DOUBLE INTERSECTION
22d3		DOUBLE UNION
22d4		PITCHFORK
22d5		EQUAL AND PARALLEL TO
22d6		LESS-THAN WITH DOT
22d7		GREATER-THAN WITH DOT
22d8		VERY MUCH LESS-THAN
22d9		VERY MUCH GREATER-THAN
22da		LESS-THAN EQUAL TO OR GREATER-THAN
22db		GREATER-THAN EQUAL TO OR LESS-THAN
22dc		EQUAL TO OR LESS-THAN
22dd		EQUAL TO OR GREATER-THAN
22de		EQUAL TO OR PRECEDES
22df		EQUAL TO OR SUCCEEDS
22e0		DOES NOT PRECEDE OR EQUAL
22e1		DOES NOT SUCCEED OR EQUAL
22e2		NOT SQUARE IMAGE OF OR EQUAL TO
22e3		NOT SQUARE ORIGINAL OF OR EQUAL TO
22e4		SQUARE IMAGE OF OR NOT EQUAL TO
22e5		SQUARE ORIGINAL OF OR NOT EQUAL TO
22e6		LESS-THAN BUT NOT EQUIVALENT TO
22e7		GREATER-THAN BUT NOT EQUIVALENT TO
22e8		PRECEDES BUT NOT EQUIVALENT TO
22e9		SUCCEEDS BUT NOT EQUIVALENT TO
22ea		NOT NORMAL SUBGROUP OF
22eb		DOES NOT CONTAIN AS NORMAL SUBGROUP
22ec		NOT NORMAL SUBGROUP OF OR EQUAL TO
22ed		DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL
22ee		VERTICAL ELLIPSIS
22ef		MIDLINE HORIZONTAL ELLIPSIS
22f0		UP RIGHT DIAGONAL ELLIPSIS
22f1		DOWN RIGHT DIAGONAL ELLIPSIS
2300		DIAMETER SIGN
2302		HOUSE
2303		UP ARROWHEAD
2304		DOWN ARROWHEAD
2305		PROJECTIVE
2306		PERSPECTIVE
2307		WAVY LINE
2308		LEFT CEILING
2309		RIGHT CEILING
230a		LEFT FLOOR
230b		RIGHT FLOOR
230c		BOTTOM RIGHT CROP
230d		BOTTOM LEFT CROP
230e		TOP RIGHT CROP
230f		TOP LEFT CROP
2310		REVERSED NOT SIGN
2311		SQUARE LOZENGE
2312		ARC
2313		SEGMENT
2314		SECTOR
2315		TELEPHONE RECORDER
2316		POSITION INDICATOR
2317		VIEWDATA SQUARE
2318		PLACE OF INTEREST SIGN
2319		TURNED NOT SIGN
231a		WATCH
231b		HOURGLASS
231c		TOP LEFT CORNER
231d		TOP RIGHT CORNER
231e		BOTTOM LEFT CORNER
231f		BOTTOM RIGHT CORNER
2320		TOP HALF INTEGRAL
2321		BOTTOM HALF INTEGRAL
2322		FROWN
2323		SMILE
2324		UP ARROWHEAD BETWEEN TWO HORIZONTAL BARS
2325		OPTION KEY
2326		ERASE TO THE RIGHT
2327		X IN A RECTANGLE BOX
2328		KEYBOARD
2329		LEFT-POINTING ANGLE BRACKET
232a		RIGHT-POINTING ANGLE BRACKET
232b		ERASE TO THE LEFT
232c		BENZENE RING
232d		CYLINDRICITY
232e		ALL AROUND-PROFILE
232f		SYMMETRY
2330		TOTAL RUNOUT
2331		DIMENSION ORIGIN
2332		CONICAL TAPER
2333		SLOPE
2334		COUNTERBORE
2335		COUNTERSINK
2336		APL FUNCTIONAL SYMBOL I-BEAM
2337		APL FUNCTIONAL SYMBOL SQUISH QUAD
2338		APL FUNCTIONAL SYMBOL QUAD EQUAL
2339		APL FUNCTIONAL SYMBOL QUAD DIVIDE
233a		APL FUNCTIONAL SYMBOL QUAD DIAMOND
233b		APL FUNCTIONAL SYMBOL QUAD JOT
233c		APL FUNCTIONAL SYMBOL QUAD CIRCLE
233d		APL FUNCTIONAL SYMBOL CIRCLE STILE
233e		APL FUNCTIONAL SYMBOL CIRCLE JOT
233f		APL FUNCTIONAL SYMBOL SLASH BAR
2340		APL FUNCTIONAL SYMBOL BACKSLASH BAR
2341		APL FUNCTIONAL SYMBOL QUAD SLASH
2342		APL FUNCTIONAL SYMBOL QUAD BACKSLASH
2343		APL FUNCTIONAL SYMBOL QUAD LESS-THAN
2344		APL FUNCTIONAL SYMBOL QUAD GREATER-THAN
2345		APL FUNCTIONAL SYMBOL LEFTWARDS VANE
2346		APL FUNCTIONAL SYMBOL RIGHTWARDS VANE
2347		APL FUNCTIONAL SYMBOL QUAD LEFTWARDS ARROW
2348		APL FUNCTIONAL SYMBOL QUAD RIGHTWARDS ARROW
2349		APL FUNCTIONAL SYMBOL CIRCLE BACKSLASH
234a		APL FUNCTIONAL SYMBOL DOWN TACK UNDERBAR
234b		APL FUNCTIONAL SYMBOL DELTA STILE
234c		APL FUNCTIONAL SYMBOL QUAD DOWN CARET
234d		APL FUNCTIONAL SYMBOL QUAD DELTA
234e		APL FUNCTIONAL SYMBOL DOWN TACK JOT
234f		APL FUNCTIONAL SYMBOL UPWARDS VANE
2350		APL FUNCTIONAL SYMBOL QUAD UPWARDS ARROW
2351		APL FUNCTIONAL SYMBOL UP TACK OVERBAR
2352		APL FUNCTIONAL SYMBOL DEL STILE
2353		APL FUNCTIONAL SYMBOL QUAD UP CARET
2354		APL FUNCTIONAL SYMBOL QUAD DEL
2355		APL FUNCTIONAL SYMBOL UP TACK JOT
2356		APL FUNCTIONAL SYMBOL DOWNWARDS VANE
2357		APL FUNCTIONAL SYMBOL QUAD DOWNWARDS ARROW
2358		APL FUNCTIONAL SYMBOL QUOTE UNDERBAR
2359		APL FUNCTIONAL SYMBOL DELTA UNDERBAR
235a		APL FUNCTIONAL SYMBOL DIAMOND UNDERBAR
235b		APL FUNCTIONAL SYMBOL JOT UNDERBAR
235c		APL FUNCTIONAL SYMBOL CIRCLE UNDERBAR
235d		APL FUNCTIONAL SYMBOL UP SHOE JOT
235e		APL FUNCTIONAL SYMBOL QUOTE QUAD
235f		APL FUNCTIONAL SYMBOL CIRCLE STAR
2360		APL FUNCTIONAL SYMBOL QUAD COLON
2361		APL FUNCTIONAL SYMBOL UP TACK DIAERESIS
2362		APL FUNCTIONAL SYMBOL DEL DIAERESIS
2363		APL FUNCTIONAL SYMBOL STAR DIAERESIS
2364		APL FUNCTIONAL SYMBOL JOT DIAERESIS
2365		APL FUNCTIONAL SYMBOL CIRCLE DIAERESIS
2366		APL FUNCTIONAL SYMBOL DOWN SHOE STILE
2367		APL FUNCTIONAL SYMBOL LEFT SHOE STILE
2368		APL FUNCTIONAL SYMBOL TILDE DIAERESIS
2369		APL FUNCTIONAL SYMBOL GREATER-THAN DIAERESIS
236a		APL FUNCTIONAL SYMBOL COMMA BAR
236b		APL FUNCTIONAL SYMBOL DEL TILDE
236c		APL FUNCTIONAL SYMBOL ZILDE
236d		APL FUNCTIONAL SYMBOL STILE TILDE
236e		APL FUNCTIONAL SYMBOL SEMICOLON UNDERBAR
236f		APL FUNCTIONAL SYMBOL QUAD NOT EQUAL
2370		APL FUNCTIONAL SYMBOL QUAD QUESTION
2371		APL FUNCTIONAL SYMBOL DOWN CARET TILDE
2372		APL FUNCTIONAL SYMBOL UP CARET TILDE
2373		APL FUNCTIONAL SYMBOL IOTA
2374		APL FUNCTIONAL SYMBOL RHO
2375		APL FUNCTIONAL SYMBOL OMEGA
2376		APL FUNCTIONAL SYMBOL ALPHA UNDERBAR
2377		APL FUNCTIONAL SYMBOL EPSILON UNDERBAR
2378		APL FUNCTIONAL SYMBOL IOTA UNDERBAR
2379		APL FUNCTIONAL SYMBOL OMEGA UNDERBAR
237a		APL FUNCTIONAL SYMBOL ALPHA
2400		SYMBOL FOR NULL
2401		SYMBOL FOR START OF HEADING
2402		SYMBOL FOR START OF TEXT
2403		SYMBOL FOR END OF TEXT
2404		SYMBOL FOR END OF TRANSMISSION
2405		SYMBOL FOR ENQUIRY
2406		SYMBOL FOR ACKNOWLEDGE
2407		SYMBOL FOR BELL
2408		SYMBOL FOR BACKSPACE
2409		SYMBOL FOR HORIZONTAL TABULATION
240a		SYMBOL FOR LINE FEED
240b		SYMBOL FOR VERTICAL TABULATION
240c		SYMBOL FOR FORM FEED
240d		SYMBOL FOR CARRIAGE RETURN
240e		SYMBOL FOR SHIFT OUT
240f		SYMBOL FOR SHIFT IN
2410		SYMBOL FOR DATA LINK ESCAPE
2411		SYMBOL FOR DEVICE CONTROL ONE
2412		SYMBOL FOR DEVICE CONTROL TWO
2413		SYMBOL FOR DEVICE CONTROL THREE
2414		SYMBOL FOR DEVICE CONTROL FOUR
2415		SYMBOL FOR NEGATIVE ACKNOWLEDGE
2416		SYMBOL FOR SYNCHRONOUS IDLE
2417		SYMBOL FOR END OF TRANSMISSION BLOCK
2418		SYMBOL FOR CANCEL
2419		SYMBOL FOR END OF MEDIUM
241a		SYMBOL FOR SUBSTITUTE
241b		SYMBOL FOR ESCAPE
241c		SYMBOL FOR FILE SEPARATOR
241d		SYMBOL FOR GROUP SEPARATOR
241e		SYMBOL FOR RECORD SEPARATOR
241f		SYMBOL FOR UNIT SEPARATOR
2420		SYMBOL FOR SPACE
2421		SYMBOL FOR DELETE
2422		BLANK SYMBOL
2423		OPEN BOX
2424		SYMBOL FOR NEWLINE
2440		OCR HOOK
2441		OCR CHAIR
2442		OCR FORK
2443		OCR INVERTED FORK
2444		OCR BELT BUCKLE
2445		OCR BOW TIE
2446		OCR BRANCH BANK IDENTIFICATION
2447		OCR AMOUNT OF CHECK
2448		OCR DASH
2449		OCR CUSTOMER ACCOUNT NUMBER
244a		OCR DOUBLE BACKSLASH
2460		CIRCLED DIGIT ONE
2461		CIRCLED DIGIT TWO
2462		CIRCLED DIGIT THREE
2463		CIRCLED DIGIT FOUR
2464		CIRCLED DIGIT FIVE
2465		CIRCLED DIGIT SIX
2466		CIRCLED DIGIT SEVEN
2467		CIRCLED DIGIT EIGHT
2468		CIRCLED DIGIT NINE
2469		CIRCLED NUMBER TEN
246a		CIRCLED NUMBER ELEVEN
246b		CIRCLED NUMBER TWELVE
246c		CIRCLED NUMBER THIRTEEN
246d		CIRCLED NUMBER FOURTEEN
246e		CIRCLED NUMBER FIFTEEN
246f		CIRCLED NUMBER SIXTEEN
2470		CIRCLED NUMBER SEVENTEEN
2471		CIRCLED NUMBER EIGHTEEN
2472		CIRCLED NUMBER NINETEEN
2473		CIRCLED NUMBER TWENTY
2474		PARENTHESIZED DIGIT ONE
2475		PARENTHESIZED DIGIT TWO
2476		PARENTHESIZED DIGIT THREE
2477		PARENTHESIZED DIGIT FOUR
2478		PARENTHESIZED DIGIT FIVE
2479		PARENTHESIZED DIGIT SIX
247a		PARENTHESIZED DIGIT SEVEN
247b		PARENTHESIZED DIGIT EIGHT
247c		PARENTHESIZED DIGIT NINE
247d		PARENTHESIZED NUMBER TEN
247e		PARENTHESIZED NUMBER ELEVEN
247f		PARENTHESIZED NUMBER TWELVE
2480		PARENTHESIZED NUMBER THIRTEEN
2481		PARENTHESIZED NUMBER FOURTEEN
2482		PARENTHESIZED NUMBER FIFTEEN
2483		PARENTHESIZED NUMBER SIXTEEN
2484		PARENTHESIZED NUMBER SEVENTEEN
2485		PARENTHESIZED NUMBER EIGHTEEN
2486		PARENTHESIZED NUMBER NINETEEN
2487		PARENTHESIZED NUMBER TWENTY
2488		DIGIT ONE FULL STOP
2489		DIGIT TWO FULL STOP
248a		DIGIT THREE FULL STOP
248b		DIGIT FOUR FULL STOP
248c		DIGIT FIVE FULL STOP
248d		DIGIT SIX FULL STOP
248e		DIGIT SEVEN FULL STOP
248f		DIGIT EIGHT FULL STOP
2490		DIGIT NINE FULL STOP
2491		NUMBER TEN FULL STOP
2492		NUMBER ELEVEN FULL STOP
2493		NUMBER TWELVE FULL STOP
2494		NUMBER THIRTEEN FULL STOP
2495		NUMBER FOURTEEN FULL STOP
2496		NUMBER FIFTEEN FULL STOP
2497		NUMBER SIXTEEN FULL STOP
2498		NUMBER SEVENTEEN FULL STOP
2499		NUMBER EIGHTEEN FULL STOP
249a		NUMBER NINETEEN FULL STOP
249b		NUMBER TWENTY FULL STOP
249c		PARENTHESIZED LATIN SMALL LETTER A
249d		PARENTHESIZED LATIN SMALL LETTER B
249e		PARENTHESIZED LATIN SMALL LETTER C
249f		PARENTHESIZED LATIN SMALL LETTER D
24a0		PARENTHESIZED LATIN SMALL LETTER E
24a1		PARENTHESIZED LATIN SMALL LETTER F
24a2		PARENTHESIZED LATIN SMALL LETTER G
24a3		PARENTHESIZED LATIN SMALL LETTER H
24a4		PARENTHESIZED LATIN SMALL LETTER I
24a5		PARENTHESIZED LATIN SMALL LETTER J
24a6		PARENTHESIZED LATIN SMALL LETTER K
24a7		PARENTHESIZED LATIN SMALL LETTER L
24a8		PARENTHESIZED LATIN SMALL LETTER M
24a9		PARENTHESIZED LATIN SMALL LETTER N
24aa		PARENTHESIZED LATIN SMALL LETTER O
24ab		PARENTHESIZED LATIN SMALL LETTER P
24ac		PARENTHESIZED LATIN SMALL LETTER Q
24ad		PARENTHESIZED LATIN SMALL LETTER R
24ae		PARENTHESIZED LATIN SMALL LETTER S
24af		PARENTHESIZED LATIN SMALL LETTER T
24b0		PARENTHESIZED LATIN SMALL LETTER U
24b1		PARENTHESIZED LATIN SMALL LETTER V
24b2		PARENTHESIZED LATIN SMALL LETTER W
24b3		PARENTHESIZED LATIN SMALL LETTER X
24b4		PARENTHESIZED LATIN SMALL LETTER Y
24b5		PARENTHESIZED LATIN SMALL LETTER Z
24b6		CIRCLED LATIN CAPITAL LETTER A
24b7		CIRCLED LATIN CAPITAL LETTER B
24b8		CIRCLED LATIN CAPITAL LETTER C
24b9		CIRCLED LATIN CAPITAL LETTER D
24ba		CIRCLED LATIN CAPITAL LETTER E
24bb		CIRCLED LATIN CAPITAL LETTER F
24bc		CIRCLED LATIN CAPITAL LETTER G
24bd		CIRCLED LATIN CAPITAL LETTER H
24be		CIRCLED LATIN CAPITAL LETTER I
24bf		CIRCLED LATIN CAPITAL LETTER J
24c0		CIRCLED LATIN CAPITAL LETTER K
24c1		CIRCLED LATIN CAPITAL LETTER L
24c2		CIRCLED LATIN CAPITAL LETTER M
24c3		CIRCLED LATIN CAPITAL LETTER N
24c4		CIRCLED LATIN CAPITAL LETTER O
24c5		CIRCLED LATIN CAPITAL LETTER P
24c6		CIRCLED LATIN CAPITAL LETTER Q
24c7		CIRCLED LATIN CAPITAL LETTER R
24c8		CIRCLED LATIN CAPITAL LETTER S
24c9		CIRCLED LATIN CAPITAL LETTER T
24ca		CIRCLED LATIN CAPITAL LETTER U
24cb		CIRCLED LATIN CAPITAL LETTER V
24cc		CIRCLED LATIN CAPITAL LETTER W
24cd		CIRCLED LATIN CAPITAL LETTER X
24ce		CIRCLED LATIN CAPITAL LETTER Y
24cf		CIRCLED LATIN CAPITAL LETTER Z
24d0		CIRCLED LATIN SMALL LETTER A
24d1		CIRCLED LATIN SMALL LETTER B
24d2		CIRCLED LATIN SMALL LETTER C
24d3		CIRCLED LATIN SMALL LETTER D
24d4		CIRCLED LATIN SMALL LETTER E
24d5		CIRCLED LATIN SMALL LETTER F
24d6		CIRCLED LATIN SMALL LETTER G
24d7		CIRCLED LATIN SMALL LETTER H
24d8		CIRCLED LATIN SMALL LETTER I
24d9		CIRCLED LATIN SMALL LETTER J
24da		CIRCLED LATIN SMALL LETTER K
24db		CIRCLED LATIN SMALL LETTER L
24dc		CIRCLED LATIN SMALL LETTER M
24dd		CIRCLED LATIN SMALL LETTER N
24de		CIRCLED LATIN SMALL LETTER O
24df		CIRCLED LATIN SMALL LETTER P
24e0		CIRCLED LATIN SMALL LETTER Q
24e1		CIRCLED LATIN SMALL LETTER R
24e2		CIRCLED LATIN SMALL LETTER S
24e3		CIRCLED LATIN SMALL LETTER T
24e4		CIRCLED LATIN SMALL LETTER U
24e5		CIRCLED LATIN SMALL LETTER V
24e6		CIRCLED LATIN SMALL LETTER W
24e7		CIRCLED LATIN SMALL LETTER X
24e8		CIRCLED LATIN SMALL LETTER Y
24e9		CIRCLED LATIN SMALL LETTER Z
24ea		CIRCLED DIGIT ZERO
2500		BOX DRAWINGS LIGHT HORIZONTAL
2501		BOX DRAWINGS HEAVY HORIZONTAL
2502		BOX DRAWINGS LIGHT VERTICAL
2503		BOX DRAWINGS HEAVY VERTICAL
2504		BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL
2505		BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL
2506		BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL
2507		BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL
2508		BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL
2509		BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL
250a		BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL
250b		BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL
250c		BOX DRAWINGS LIGHT DOWN AND RIGHT
250d		BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY
250e		BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT
250f		BOX DRAWINGS HEAVY DOWN AND RIGHT
2510		BOX DRAWINGS LIGHT DOWN AND LEFT
2511		BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY
2512		BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT
2513		BOX DRAWINGS HEAVY DOWN AND LEFT
2514		BOX DRAWINGS LIGHT UP AND RIGHT
2515		BOX DRAWINGS UP LIGHT AND RIGHT HEAVY
2516		BOX DRAWINGS UP HEAVY AND RIGHT LIGHT
2517		BOX DRAWINGS HEAVY UP AND RIGHT
2518		BOX DRAWINGS LIGHT UP AND LEFT
2519		BOX DRAWINGS UP LIGHT AND LEFT HEAVY
251a		BOX DRAWINGS UP HEAVY AND LEFT LIGHT
251b		BOX DRAWINGS HEAVY UP AND LEFT
251c		BOX DRAWINGS LIGHT VERTICAL AND RIGHT
251d		BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY
251e		BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT
251f		BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT
2520		BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT
2521		BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY
2522		BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY
2523		BOX DRAWINGS HEAVY VERTICAL AND RIGHT
2524		BOX DRAWINGS LIGHT VERTICAL AND LEFT
2525		BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY
2526		BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT
2527		BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT
2528		BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT
2529		BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY
252a		BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY
252b		BOX DRAWINGS HEAVY VERTICAL AND LEFT
252c		BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
252d		BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT
252e		BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT
252f		BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY
2530		BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT
2531		BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY
2532		BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY
2533		BOX DRAWINGS HEAVY DOWN AND HORIZONTAL
2534		BOX DRAWINGS LIGHT UP AND HORIZONTAL
2535		BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT
2536		BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT
2537		BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY
2538		BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT
2539		BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY
253a		BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY
253b		BOX DRAWINGS HEAVY UP AND HORIZONTAL
253c		BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
253d		BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT
253e		BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT
253f		BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY
2540		BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT
2541		BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT
2542		BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT
2543		BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT
2544		BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT
2545		BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT
2546		BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT
2547		BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY
2548		BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY
2549		BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY
254a		BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY
254b		BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL
254c		BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL
254d		BOX DRAWINGS HEAVY DOUBLE DASH HORIZONTAL
254e		BOX DRAWINGS LIGHT DOUBLE DASH VERTICAL
254f		BOX DRAWINGS HEAVY DOUBLE DASH VERTICAL
2550		BOX DRAWINGS DOUBLE HORIZONTAL
2551		BOX DRAWINGS DOUBLE VERTICAL
2552		BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE
2553		BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE
2554		BOX DRAWINGS DOUBLE DOWN AND RIGHT
2555		BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE
2556		BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE
2557		BOX DRAWINGS DOUBLE DOWN AND LEFT
2558		BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE
2559		BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE
255a		BOX DRAWINGS DOUBLE UP AND RIGHT
255b		BOX DRAWINGS UP SINGLE AND LEFT DOUBLE
255c		BOX DRAWINGS UP DOUBLE AND LEFT SINGLE
255d		BOX DRAWINGS DOUBLE UP AND LEFT
255e		BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE
255f		BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE
2560		BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
2561		BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE
2562		BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE
2563		BOX DRAWINGS DOUBLE VERTICAL AND LEFT
2564		BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE
2565		BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE
2566		BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
2567		BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE
2568		BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE
2569		BOX DRAWINGS DOUBLE UP AND HORIZONTAL
256a		BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE
256b		BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE
256c		BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
256d		BOX DRAWINGS LIGHT ARC DOWN AND RIGHT
256e		BOX DRAWINGS LIGHT ARC DOWN AND LEFT
256f		BOX DRAWINGS LIGHT ARC UP AND LEFT
2570		BOX DRAWINGS LIGHT ARC UP AND RIGHT
2571		BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT
2572		BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT
2573		BOX DRAWINGS LIGHT DIAGONAL CROSS
2574		BOX DRAWINGS LIGHT LEFT
2575		BOX DRAWINGS LIGHT UP
2576		BOX DRAWINGS LIGHT RIGHT
2577		BOX DRAWINGS LIGHT DOWN
2578		BOX DRAWINGS HEAVY LEFT
2579		BOX DRAWINGS HEAVY UP
257a		BOX DRAWINGS HEAVY RIGHT
257b		BOX DRAWINGS HEAVY DOWN
257c		BOX DRAWINGS LIGHT LEFT AND HEAVY RIGHT
257d		BOX DRAWINGS LIGHT UP AND HEAVY DOWN
257e		BOX DRAWINGS HEAVY LEFT AND LIGHT RIGHT
257f		BOX DRAWINGS HEAVY UP AND LIGHT DOWN
2580		UPPER HALF BLOCK
2581		LOWER ONE EIGHTH BLOCK
2582		LOWER ONE QUARTER BLOCK
2583		LOWER THREE EIGHTHS BLOCK
2584		LOWER HALF BLOCK
2585		LOWER FIVE EIGHTHS BLOCK
2586		LOWER THREE QUARTERS BLOCK
2587		LOWER SEVEN EIGHTHS BLOCK
2588		FULL BLOCK
2589		LEFT SEVEN EIGHTHS BLOCK
258a		LEFT THREE QUARTERS BLOCK
258b		LEFT FIVE EIGHTHS BLOCK
258c		LEFT HALF BLOCK
258d		LEFT THREE EIGHTHS BLOCK
258e		LEFT ONE QUARTER BLOCK
258f		LEFT ONE EIGHTH BLOCK
2590		RIGHT HALF BLOCK
2591		LIGHT SHADE
2592		MEDIUM SHADE
2593		DARK SHADE
2594		UPPER ONE EIGHTH BLOCK
2595		RIGHT ONE EIGHTH BLOCK
25a0		BLACK SQUARE
25a1		WHITE SQUARE
25a2		WHITE SQUARE WITH ROUNDED CORNERS
25a3		WHITE SQUARE CONTAINING BLACK SMALL SQUARE
25a4		SQUARE WITH HORIZONTAL FILL
25a5		SQUARE WITH VERTICAL FILL
25a6		SQUARE WITH ORTHOGONAL CROSSHATCH FILL
25a7		SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL
25a8		SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL
25a9		SQUARE WITH DIAGONAL CROSSHATCH FILL
25aa		BLACK SMALL SQUARE
25ab		WHITE SMALL SQUARE
25ac		BLACK RECTANGLE
25ad		WHITE RECTANGLE
25ae		BLACK VERTICAL RECTANGLE
25af		WHITE VERTICAL RECTANGLE
25b0		BLACK PARALLELOGRAM
25b1		WHITE PARALLELOGRAM
25b2		BLACK UP-POINTING TRIANGLE
25b3		WHITE UP-POINTING TRIANGLE
25b4		BLACK UP-POINTING SMALL TRIANGLE
25b5		WHITE UP-POINTING SMALL TRIANGLE
25b6		BLACK RIGHT-POINTING TRIANGLE
25b7		WHITE RIGHT-POINTING TRIANGLE
25b8		BLACK RIGHT-POINTING SMALL TRIANGLE
25b9		WHITE RIGHT-POINTING SMALL TRIANGLE
25ba		BLACK RIGHT-POINTING POINTER
25bb		WHITE RIGHT-POINTING POINTER
25bc		BLACK DOWN-POINTING TRIANGLE
25bd		WHITE DOWN-POINTING TRIANGLE
25be		BLACK DOWN-POINTING SMALL TRIANGLE
25bf		WHITE DOWN-POINTING SMALL TRIANGLE
25c0		BLACK LEFT-POINTING TRIANGLE
25c1		WHITE LEFT-POINTING TRIANGLE
25c2		BLACK LEFT-POINTING SMALL TRIANGLE
25c3		WHITE LEFT-POINTING SMALL TRIANGLE
25c4		BLACK LEFT-POINTING POINTER
25c5		WHITE LEFT-POINTING POINTER
25c6		BLACK DIAMOND
25c7		WHITE DIAMOND
25c8		WHITE DIAMOND CONTAINING BLACK SMALL DIAMOND
25c9		FISHEYE
25ca		LOZENGE
25cb		WHITE CIRCLE
25cc		DOTTED CIRCLE
25cd		CIRCLE WITH VERTICAL FILL
25ce		BULLSEYE
25cf		BLACK CIRCLE
25d0		CIRCLE WITH LEFT HALF BLACK
25d1		CIRCLE WITH RIGHT HALF BLACK
25d2		CIRCLE WITH LOWER HALF BLACK
25d3		CIRCLE WITH UPPER HALF BLACK
25d4		CIRCLE WITH UPPER RIGHT QUADRANT BLACK
25d5		CIRCLE WITH ALL BUT UPPER LEFT QUADRANT BLACK
25d6		LEFT HALF BLACK CIRCLE
25d7		RIGHT HALF BLACK CIRCLE
25d8		INVERSE BULLET
25d9		INVERSE WHITE CIRCLE
25da		UPPER HALF INVERSE WHITE CIRCLE
25db		LOWER HALF INVERSE WHITE CIRCLE
25dc		UPPER LEFT QUADRANT CIRCULAR ARC
25dd		UPPER RIGHT QUADRANT CIRCULAR ARC
25de		LOWER RIGHT QUADRANT CIRCULAR ARC
25df		LOWER LEFT QUADRANT CIRCULAR ARC
25e0		UPPER HALF CIRCLE
25e1		LOWER HALF CIRCLE
25e2		BLACK LOWER RIGHT TRIANGLE
25e3		BLACK LOWER LEFT TRIANGLE
25e4		BLACK UPPER LEFT TRIANGLE
25e5		BLACK UPPER RIGHT TRIANGLE
25e6		WHITE BULLET
25e7		SQUARE WITH LEFT HALF BLACK
25e8		SQUARE WITH RIGHT HALF BLACK
25e9		SQUARE WITH UPPER LEFT DIAGONAL HALF BLACK
25ea		SQUARE WITH LOWER RIGHT DIAGONAL HALF BLACK
25eb		WHITE SQUARE WITH VERTICAL BISECTING LINE
25ec		WHITE UP-POINTING TRIANGLE WITH DOT
25ed		UP-POINTING TRIANGLE WITH LEFT HALF BLACK
25ee		UP-POINTING TRIANGLE WITH RIGHT HALF BLACK
25ef		LARGE CIRCLE
2600		BLACK SUN WITH RAYS
2601		CLOUD
2602		UMBRELLA
2603		SNOWMAN
2604		COMET
2605		BLACK STAR
2606		WHITE STAR
2607		LIGHTNING
2608		THUNDERSTORM
2609		SUN
260a		ASCENDING NODE
260b		DESCENDING NODE
260c		CONJUNCTION
260d		OPPOSITION
260e		BLACK TELEPHONE
260f		WHITE TELEPHONE
2610		BALLOT BOX
2611		BALLOT BOX WITH CHECK
2612		BALLOT BOX WITH X
2613		SALTIRE
261a		BLACK LEFT POINTING INDEX
261b		BLACK RIGHT POINTING INDEX
261c		WHITE LEFT POINTING INDEX
261d		WHITE UP POINTING INDEX
261e		WHITE RIGHT POINTING INDEX
261f		WHITE DOWN POINTING INDEX
2620		SKULL AND CROSSBONES
2621		CAUTION SIGN
2622		RADIOACTIVE SIGN
2623		BIOHAZARD SIGN
2624		CADUCEUS
2625		ANKH
2626		ORTHODOX CROSS
2627		CHI RHO
2628		CROSS OF LORRAINE
2629		CROSS OF JERUSALEM
262a		STAR AND CRESCENT
262b		FARSI SYMBOL
262c		ADI SHAKTI
262d		HAMMER AND SICKLE
262e		PEACE SYMBOL
262f		YIN YANG
2630		TRIGRAM FOR HEAVEN
2631		TRIGRAM FOR LAKE
2632		TRIGRAM FOR FIRE
2633		TRIGRAM FOR THUNDER
2634		TRIGRAM FOR WIND
2635		TRIGRAM FOR WATER
2636		TRIGRAM FOR MOUNTAIN
2637		TRIGRAM FOR EARTH
2638		WHEEL OF DHARMA
2639		WHITE FROWNING FACE
263a		WHITE SMILING FACE
263b		BLACK SMILING FACE
263c		WHITE SUN WITH RAYS
263d		FIRST QUARTER MOON
263e		LAST QUARTER MOON
263f		MERCURY
2640		FEMALE SIGN
2641		EARTH
2642		MALE SIGN
2643		JUPITER
2644		SATURN
2645		URANUS
2646		NEPTUNE
2647		PLUTO
2648		ARIES
2649		TAURUS
264a		GEMINI
264b		CANCER
264c		LEO
264d		VIRGO
264e		LIBRA
264f		SCORPIUS
2650		SAGITTARIUS
2651		CAPRICORN
2652		AQUARIUS
2653		PISCES
2654		WHITE CHESS KING
2655		WHITE CHESS QUEEN
2656		WHITE CHESS ROOK
2657		WHITE CHESS BISHOP
2658		WHITE CHESS KNIGHT
2659		WHITE CHESS PAWN
265a		BLACK CHESS KING
265b		BLACK CHESS QUEEN
265c		BLACK CHESS ROOK
265d		BLACK CHESS BISHOP
265e		BLACK CHESS KNIGHT
265f		BLACK CHESS PAWN
2660		BLACK SPADE SUIT
2661		WHITE HEART SUIT
2662		WHITE DIAMOND SUIT
2663		BLACK CLUB SUIT
2664		WHITE SPADE SUIT
2665		BLACK HEART SUIT
2666		BLACK DIAMOND SUIT
2667		WHITE CLUB SUIT
2668		HOT SPRINGS
2669		QUARTER NOTE
266a		EIGHTH NOTE
266b		BEAMED EIGHTH NOTES
266c		BEAMED SIXTEENTH NOTES
266d		MUSIC FLAT SIGN
266e		MUSIC NATURAL SIGN
266f		MUSIC SHARP SIGN
2701		UPPER BLADE SCISSORS
2702		BLACK SCISSORS
2703		LOWER BLADE SCISSORS
2704		WHITE SCISSORS
2706		TELEPHONE LOCATION SIGN
2707		TAPE DRIVE
2708		AIRPLANE
2709		ENVELOPE
270c		VICTORY HAND
270d		WRITING HAND
270e		LOWER RIGHT PENCIL
270f		PENCIL
2710		UPPER RIGHT PENCIL
2711		WHITE NIB
2712		BLACK NIB
2713		CHECK MARK
2714		HEAVY CHECK MARK
2715		MULTIPLICATION X
2716		HEAVY MULTIPLICATION X
2717		BALLOT X
2718		HEAVY BALLOT X
2719		OUTLINED GREEK CROSS
271a		HEAVY GREEK CROSS
271b		OPEN CENTRE CROSS
271c		HEAVY OPEN CENTRE CROSS
271d		LATIN CROSS
271e		SHADOWED WHITE LATIN CROSS
271f		OUTLINED LATIN CROSS
2720		MALTESE CROSS
2721		STAR OF DAVID
2722		FOUR TEARDROP-SPOKED ASTERISK
2723		FOUR BALLOON-SPOKED ASTERISK
2724		HEAVY FOUR BALLOON-SPOKED ASTERISK
2725		FOUR CLUB-SPOKED ASTERISK
2726		BLACK FOUR POINTED STAR
2727		WHITE FOUR POINTED STAR
2729		STRESS OUTLINED WHITE STAR
272a		CIRCLED WHITE STAR
272b		OPEN CENTRE BLACK STAR
272c		BLACK CENTRE WHITE STAR
272d		OUTLINED BLACK STAR
272e		HEAVY OUTLINED BLACK STAR
272f		PINWHEEL STAR
2730		SHADOWED WHITE STAR
2731		HEAVY ASTERISK
2732		OPEN CENTRE ASTERISK
2733		EIGHT SPOKED ASTERISK
2734		EIGHT POINTED BLACK STAR
2735		EIGHT POINTED PINWHEEL STAR
2736		SIX POINTED BLACK STAR
2737		EIGHT POINTED RECTILINEAR BLACK STAR
2738		HEAVY EIGHT POINTED RECTILINEAR BLACK STAR
2739		TWELVE POINTED BLACK STAR
273a		SIXTEEN POINTED ASTERISK
273b		TEARDROP-SPOKED ASTERISK
273c		OPEN CENTRE TEARDROP-SPOKED ASTERISK
273d		HEAVY TEARDROP-SPOKED ASTERISK
273e		SIX PETALLED BLACK AND WHITE FLORETTE
273f		BLACK FLORETTE
2740		WHITE FLORETTE
2741		EIGHT PETALLED OUTLINED BLACK FLORETTE
2742		CIRCLED OPEN CENTRE EIGHT POINTED STAR
2743		HEAVY TEARDROP-SPOKED PINWHEEL ASTERISK
2744		SNOWFLAKE
2745		TIGHT TRIFOLIATE SNOWFLAKE
2746		HEAVY CHEVRON SNOWFLAKE
2747		SPARKLE
2748		HEAVY SPARKLE
2749		BALLOON-SPOKED ASTERISK
274a		EIGHT TEARDROP-SPOKED PROPELLER ASTERISK
274b		HEAVY EIGHT TEARDROP-SPOKED PROPELLER ASTERISK
274d		SHADOWED WHITE CIRCLE
274f		LOWER RIGHT DROP-SHADOWED WHITE SQUARE
2750		UPPER RIGHT DROP-SHADOWED WHITE SQUARE
2751		LOWER RIGHT SHADOWED WHITE SQUARE
2752		UPPER RIGHT SHADOWED WHITE SQUARE
2756		BLACK DIAMOND MINUS WHITE X
2758		LIGHT VERTICAL BAR
2759		MEDIUM VERTICAL BAR
275a		HEAVY VERTICAL BAR
275b		HEAVY SINGLE TURNED COMMA QUOTATION MARK ORNAMENT
275c		HEAVY SINGLE COMMA QUOTATION MARK ORNAMENT
275d		HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT
275e		HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT
2761		CURVED STEM PARAGRAPH SIGN ORNAMENT
2762		HEAVY EXCLAMATION MARK ORNAMENT
2763		HEAVY HEART EXCLAMATION MARK ORNAMENT
2764		HEAVY BLACK HEART
2765		ROTATED HEAVY BLACK HEART BULLET
2766		FLORAL HEART
2767		ROTATED FLORAL HEART BULLET
2776		DINGBAT NEGATIVE CIRCLED DIGIT ONE
2777		DINGBAT NEGATIVE CIRCLED DIGIT TWO
2778		DINGBAT NEGATIVE CIRCLED DIGIT THREE
2779		DINGBAT NEGATIVE CIRCLED DIGIT FOUR
277a		DINGBAT NEGATIVE CIRCLED DIGIT FIVE
277b		DINGBAT NEGATIVE CIRCLED DIGIT SIX
277c		DINGBAT NEGATIVE CIRCLED DIGIT SEVEN
277d		DINGBAT NEGATIVE CIRCLED DIGIT EIGHT
277e		DINGBAT NEGATIVE CIRCLED DIGIT NINE
277f		DINGBAT NEGATIVE CIRCLED NUMBER TEN
2780		DINGBAT CIRCLED SANS-SERIF DIGIT ONE
2781		DINGBAT CIRCLED SANS-SERIF DIGIT TWO
2782		DINGBAT CIRCLED SANS-SERIF DIGIT THREE
2783		DINGBAT CIRCLED SANS-SERIF DIGIT FOUR
2784		DINGBAT CIRCLED SANS-SERIF DIGIT FIVE
2785		DINGBAT CIRCLED SANS-SERIF DIGIT SIX
2786		DINGBAT CIRCLED SANS-SERIF DIGIT SEVEN
2787		DINGBAT CIRCLED SANS-SERIF DIGIT EIGHT
2788		DINGBAT CIRCLED SANS-SERIF DIGIT NINE
2789		DINGBAT CIRCLED SANS-SERIF NUMBER TEN
278a		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ONE
278b		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT TWO
278c		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT THREE
278d		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FOUR
278e		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FIVE
278f		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SIX
2790		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SEVEN
2791		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT EIGHT
2792		DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT NINE
2793		DINGBAT NEGATIVE CIRCLED SANS-SERIF NUMBER TEN
2794		HEAVY WIDE-HEADED RIGHTWARDS ARROW
2798		HEAVY SOUTH EAST ARROW
2799		HEAVY RIGHTWARDS ARROW
279a		HEAVY NORTH EAST ARROW
279b		DRAFTING POINT RIGHTWARDS ARROW
279c		HEAVY ROUND-TIPPED RIGHTWARDS ARROW
279d		TRIANGLE-HEADED RIGHTWARDS ARROW
279e		HEAVY TRIANGLE-HEADED RIGHTWARDS ARROW
279f		DASHED TRIANGLE-HEADED RIGHTWARDS ARROW
27a0		HEAVY DASHED TRIANGLE-HEADED RIGHTWARDS ARROW
27a1		BLACK RIGHTWARDS ARROW
27a2		THREE-D TOP-LIGHTED RIGHTWARDS ARROWHEAD
27a3		THREE-D BOTTOM-LIGHTED RIGHTWARDS ARROWHEAD
27a4		BLACK RIGHTWARDS ARROWHEAD
27a5		HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW
27a6		HEAVY BLACK CURVED UPWARDS AND RIGHTWARDS ARROW
27a7		SQUAT BLACK RIGHTWARDS ARROW
27a8		HEAVY CONCAVE-POINTED BLACK RIGHTWARDS ARROW
27a9		RIGHT-SHADED WHITE RIGHTWARDS ARROW
27aa		LEFT-SHADED WHITE RIGHTWARDS ARROW
27ab		BACK-TILTED SHADOWED WHITE RIGHTWARDS ARROW
27ac		FRONT-TILTED SHADOWED WHITE RIGHTWARDS ARROW
27ad		HEAVY LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27ae		HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27af		NOTCHED LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27b1		NOTCHED UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27b2		CIRCLED HEAVY WHITE RIGHTWARDS ARROW
27b3		WHITE-FEATHERED RIGHTWARDS ARROW
27b4		BLACK-FEATHERED SOUTH EAST ARROW
27b5		BLACK-FEATHERED RIGHTWARDS ARROW
27b6		BLACK-FEATHERED NORTH EAST ARROW
27b7		HEAVY BLACK-FEATHERED SOUTH EAST ARROW
27b8		HEAVY BLACK-FEATHERED RIGHTWARDS ARROW
27b9		HEAVY BLACK-FEATHERED NORTH EAST ARROW
27ba		TEARDROP-BARBED RIGHTWARDS ARROW
27bb		HEAVY TEARDROP-SHANKED RIGHTWARDS ARROW
27bc		WEDGE-TAILED RIGHTWARDS ARROW
27bd		HEAVY WEDGE-TAILED RIGHTWARDS ARROW
27be		OPEN-OUTLINED RIGHTWARDS ARROW
3000		IDEOGRAPHIC SPACE
3001		IDEOGRAPHIC COMMA
3002		IDEOGRAPHIC FULL STOP
3003		DITTO MARK
3004		JAPANESE INDUSTRIAL STANDARD SYMBOL
3005		IDEOGRAPHIC ITERATION MARK
3006		IDEOGRAPHIC CLOSING MARK
3007		IDEOGRAPHIC NUMBER ZERO
3008		LEFT ANGLE BRACKET
3009		RIGHT ANGLE BRACKET
300a		LEFT DOUBLE ANGLE BRACKET
300b		RIGHT DOUBLE ANGLE BRACKET
300c		LEFT CORNER BRACKET
300d		RIGHT CORNER BRACKET
300e		LEFT WHITE CORNER BRACKET
300f		RIGHT WHITE CORNER BRACKET
3010		LEFT BLACK LENTICULAR BRACKET
3011		RIGHT BLACK LENTICULAR BRACKET
3012		POSTAL MARK
3013		GETA MARK
3014		LEFT TORTOISE SHELL BRACKET
3015		RIGHT TORTOISE SHELL BRACKET
3016		LEFT WHITE LENTICULAR BRACKET
3017		RIGHT WHITE LENTICULAR BRACKET
3018		LEFT WHITE TORTOISE SHELL BRACKET
3019		RIGHT WHITE TORTOISE SHELL BRACKET
301a		LEFT WHITE SQUARE BRACKET
301b		RIGHT WHITE SQUARE BRACKET
301c		WAVE DASH
301d		REVERSED DOUBLE PRIME QUOTATION MARK
301e		DOUBLE PRIME QUOTATION MARK
301f		LOW DOUBLE PRIME QUOTATION MARK
3020		POSTAL MARK FACE
3021		HANGZHOU NUMERAL ONE
3022		HANGZHOU NUMERAL TWO
3023		HANGZHOU NUMERAL THREE
3024		HANGZHOU NUMERAL FOUR
3025		HANGZHOU NUMERAL FIVE
3026		HANGZHOU NUMERAL SIX
3027		HANGZHOU NUMERAL SEVEN
3028		HANGZHOU NUMERAL EIGHT
3029		HANGZHOU NUMERAL NINE
302a		IDEOGRAPHIC LEVEL TONE MARK
302b		IDEOGRAPHIC RISING TONE MARK
302c		IDEOGRAPHIC DEPARTING TONE MARK
302d		IDEOGRAPHIC ENTERING TONE MARK
302e		HANGUL SINGLE DOT TONE MARK
302f		HANGUL DOUBLE DOT TONE MARK
3030		WAVY DASH
3031		VERTICAL KANA REPEAT MARK
3032		VERTICAL KANA REPEAT WITH VOICED SOUND MARK
3033		VERTICAL KANA REPEAT MARK UPPER HALF
3034		VERTICAL KANA REPEAT WITH VOICED SOUND MARK UPPER HALF
3035		VERTICAL KANA REPEAT MARK LOWER HALF
3036		CIRCLED POSTAL MARK
3037		IDEOGRAPHIC TELEGRAPH LINE FEED SEPARATOR SYMBOL
303f		IDEOGRAPHIC HALF FILL SPACE
3041		HIRAGANA LETTER SMALL A
3042		HIRAGANA LETTER A
3043		HIRAGANA LETTER SMALL I
3044		HIRAGANA LETTER I
3045		HIRAGANA LETTER SMALL U
3046		HIRAGANA LETTER U
3047		HIRAGANA LETTER SMALL E
3048		HIRAGANA LETTER E
3049		HIRAGANA LETTER SMALL O
304a		HIRAGANA LETTER O
304b		HIRAGANA LETTER KA
304c		HIRAGANA LETTER GA
304d		HIRAGANA LETTER KI
304e		HIRAGANA LETTER GI
304f		HIRAGANA LETTER KU
3050		HIRAGANA LETTER GU
3051		HIRAGANA LETTER KE
3052		HIRAGANA LETTER GE
3053		HIRAGANA LETTER KO
3054		HIRAGANA LETTER GO
3055		HIRAGANA LETTER SA
3056		HIRAGANA LETTER ZA
3057		HIRAGANA LETTER SI
3058		HIRAGANA LETTER ZI
3059		HIRAGANA LETTER SU
305a		HIRAGANA LETTER ZU
305b		HIRAGANA LETTER SE
305c		HIRAGANA LETTER ZE
305d		HIRAGANA LETTER SO
305e		HIRAGANA LETTER ZO
305f		HIRAGANA LETTER TA
3060		HIRAGANA LETTER DA
3061		HIRAGANA LETTER TI
3062		HIRAGANA LETTER DI
3063		HIRAGANA LETTER SMALL TU
3064		HIRAGANA LETTER TU
3065		HIRAGANA LETTER DU
3066		HIRAGANA LETTER TE
3067		HIRAGANA LETTER DE
3068		HIRAGANA LETTER TO
3069		HIRAGANA LETTER DO
306a		HIRAGANA LETTER NA
306b		HIRAGANA LETTER NI
306c		HIRAGANA LETTER NU
306d		HIRAGANA LETTER NE
306e		HIRAGANA LETTER NO
306f		HIRAGANA LETTER HA
3070		HIRAGANA LETTER BA
3071		HIRAGANA LETTER PA
3072		HIRAGANA LETTER HI
3073		HIRAGANA LETTER BI
3074		HIRAGANA LETTER PI
3075		HIRAGANA LETTER HU
3076		HIRAGANA LETTER BU
3077		HIRAGANA LETTER PU
3078		HIRAGANA LETTER HE
3079		HIRAGANA LETTER BE
307a		HIRAGANA LETTER PE
307b		HIRAGANA LETTER HO
307c		HIRAGANA LETTER BO
307d		HIRAGANA LETTER PO
307e		HIRAGANA LETTER MA
307f		HIRAGANA LETTER MI
3080		HIRAGANA LETTER MU
3081		HIRAGANA LETTER ME
3082		HIRAGANA LETTER MO
3083		HIRAGANA LETTER SMALL YA
3084		HIRAGANA LETTER YA
3085		HIRAGANA LETTER SMALL YU
3086		HIRAGANA LETTER YU
3087		HIRAGANA LETTER SMALL YO
3088		HIRAGANA LETTER YO
3089		HIRAGANA LETTER RA
308a		HIRAGANA LETTER RI
308b		HIRAGANA LETTER RU
308c		HIRAGANA LETTER RE
308d		HIRAGANA LETTER RO
308e		HIRAGANA LETTER SMALL WA
308f		HIRAGANA LETTER WA
3090		HIRAGANA LETTER WI
3091		HIRAGANA LETTER WE
3092		HIRAGANA LETTER WO
3093		HIRAGANA LETTER N
3094		HIRAGANA LETTER VU
3099		COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK
309a		COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
309b		KATAKANA-HIRAGANA VOICED SOUND MARK
309c		KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
309d		HIRAGANA ITERATION MARK
309e		HIRAGANA VOICED ITERATION MARK
30a1		KATAKANA LETTER SMALL A
30a2		KATAKANA LETTER A
30a3		KATAKANA LETTER SMALL I
30a4		KATAKANA LETTER I
30a5		KATAKANA LETTER SMALL U
30a6		KATAKANA LETTER U
30a7		KATAKANA LETTER SMALL E
30a8		KATAKANA LETTER E
30a9		KATAKANA LETTER SMALL O
30aa		KATAKANA LETTER O
30ab		KATAKANA LETTER KA
30ac		KATAKANA LETTER GA
30ad		KATAKANA LETTER KI
30ae		KATAKANA LETTER GI
30af		KATAKANA LETTER KU
30b0		KATAKANA LETTER GU
30b1		KATAKANA LETTER KE
30b2		KATAKANA LETTER GE
30b3		KATAKANA LETTER KO
30b4		KATAKANA LETTER GO
30b5		KATAKANA LETTER SA
30b6		KATAKANA LETTER ZA
30b7		KATAKANA LETTER SI
30b8		KATAKANA LETTER ZI
30b9		KATAKANA LETTER SU
30ba		KATAKANA LETTER ZU
30bb		KATAKANA LETTER SE
30bc		KATAKANA LETTER ZE
30bd		KATAKANA LETTER SO
30be		KATAKANA LETTER ZO
30bf		KATAKANA LETTER TA
30c0		KATAKANA LETTER DA
30c1		KATAKANA LETTER TI
30c2		KATAKANA LETTER DI
30c3		KATAKANA LETTER SMALL TU
30c4		KATAKANA LETTER TU
30c5		KATAKANA LETTER DU
30c6		KATAKANA LETTER TE
30c7		KATAKANA LETTER DE
30c8		KATAKANA LETTER TO
30c9		KATAKANA LETTER DO
30ca		KATAKANA LETTER NA
30cb		KATAKANA LETTER NI
30cc		KATAKANA LETTER NU
30cd		KATAKANA LETTER NE
30ce		KATAKANA LETTER NO
30cf		KATAKANA LETTER HA
30d0		KATAKANA LETTER BA
30d1		KATAKANA LETTER PA
30d2		KATAKANA LETTER HI
30d3		KATAKANA LETTER BI
30d4		KATAKANA LETTER PI
30d5		KATAKANA LETTER HU
30d6		KATAKANA LETTER BU
30d7		KATAKANA LETTER PU
30d8		KATAKANA LETTER HE
30d9		KATAKANA LETTER BE
30da		KATAKANA LETTER PE
30db		KATAKANA LETTER HO
30dc		KATAKANA LETTER BO
30dd		KATAKANA LETTER PO
30de		KATAKANA LETTER MA
30df		KATAKANA LETTER MI
30e0		KATAKANA LETTER MU
30e1		KATAKANA LETTER ME
30e2		KATAKANA LETTER MO
30e3		KATAKANA LETTER SMALL YA
30e4		KATAKANA LETTER YA
30e5		KATAKANA LETTER SMALL YU
30e6		KATAKANA LETTER YU
30e7		KATAKANA LETTER SMALL YO
30e8		KATAKANA LETTER YO
30e9		KATAKANA LETTER RA
30ea		KATAKANA LETTER RI
30eb		KATAKANA LETTER RU
30ec		KATAKANA LETTER RE
30ed		KATAKANA LETTER RO
30ee		KATAKANA LETTER SMALL WA
30ef		KATAKANA LETTER WA
30f0		KATAKANA LETTER WI
30f1		KATAKANA LETTER WE
30f2		KATAKANA LETTER WO
30f3		KATAKANA LETTER N
30f4		KATAKANA LETTER VU
30f5		KATAKANA LETTER SMALL KA
30f6		KATAKANA LETTER SMALL KE
30f7		KATAKANA LETTER VA
30f8		KATAKANA LETTER VI
30f9		KATAKANA LETTER VE
30fa		KATAKANA LETTER VO
30fb		KATAKANA MIDDLE DOT
30fc		KATAKANA-HIRAGANA PROLONGED SOUND MARK
30fd		KATAKANA ITERATION MARK
30fe		KATAKANA VOICED ITERATION MARK
3105		BOPOMOFO LETTER B
3106		BOPOMOFO LETTER P
3107		BOPOMOFO LETTER M
3108		BOPOMOFO LETTER F
3109		BOPOMOFO LETTER D
310a		BOPOMOFO LETTER T
310b		BOPOMOFO LETTER N
310c		BOPOMOFO LETTER L
310d		BOPOMOFO LETTER G
310e		BOPOMOFO LETTER K
310f		BOPOMOFO LETTER H
3110		BOPOMOFO LETTER J
3111		BOPOMOFO LETTER Q
3112		BOPOMOFO LETTER X
3113		BOPOMOFO LETTER ZH
3114		BOPOMOFO LETTER CH
3115		BOPOMOFO LETTER SH
3116		BOPOMOFO LETTER R
3117		BOPOMOFO LETTER Z
3118		BOPOMOFO LETTER C
3119		BOPOMOFO LETTER S
311a		BOPOMOFO LETTER A
311b		BOPOMOFO LETTER O
311c		BOPOMOFO LETTER E
311d		BOPOMOFO LETTER EH
311e		BOPOMOFO LETTER AI
311f		BOPOMOFO LETTER EI
3120		BOPOMOFO LETTER AU
3121		BOPOMOFO LETTER OU
3122		BOPOMOFO LETTER AN
3123		BOPOMOFO LETTER EN
3124		BOPOMOFO LETTER ANG
3125		BOPOMOFO LETTER ENG
3126		BOPOMOFO LETTER ER
3127		BOPOMOFO LETTER I
3128		BOPOMOFO LETTER U
3129		BOPOMOFO LETTER IU
312a		BOPOMOFO LETTER V
312b		BOPOMOFO LETTER NG
312c		BOPOMOFO LETTER GN
3131		HANGUL LETTER KIYEOK
3132		HANGUL LETTER SSANGKIYEOK
3133		HANGUL LETTER KIYEOK-SIOS
3134		HANGUL LETTER NIEUN
3135		HANGUL LETTER NIEUN-CIEUC
3136		HANGUL LETTER NIEUN-HIEUH
3137		HANGUL LETTER TIKEUT
3138		HANGUL LETTER SSANGTIKEUT
3139		HANGUL LETTER RIEUL
313a		HANGUL LETTER RIEUL-KIYEOK
313b		HANGUL LETTER RIEUL-MIEUM
313c		HANGUL LETTER RIEUL-PIEUP
313d		HANGUL LETTER RIEUL-SIOS
313e		HANGUL LETTER RIEUL-THIEUTH
313f		HANGUL LETTER RIEUL-PHIEUPH
3140		HANGUL LETTER RIEUL-HIEUH
3141		HANGUL LETTER MIEUM
3142		HANGUL LETTER PIEUP
3143		HANGUL LETTER SSANGPIEUP
3144		HANGUL LETTER PIEUP-SIOS
3145		HANGUL LETTER SIOS
3146		HANGUL LETTER SSANGSIOS
3147		HANGUL LETTER IEUNG
3148		HANGUL LETTER CIEUC
3149		HANGUL LETTER SSANGCIEUC
314a		HANGUL LETTER CHIEUCH
314b		HANGUL LETTER KHIEUKH
314c		HANGUL LETTER THIEUTH
314d		HANGUL LETTER PHIEUPH
314e		HANGUL LETTER HIEUH
314f		HANGUL LETTER A
3150		HANGUL LETTER AE
3151		HANGUL LETTER YA
3152		HANGUL LETTER YAE
3153		HANGUL LETTER EO
3154		HANGUL LETTER E
3155		HANGUL LETTER YEO
3156		HANGUL LETTER YE
3157		HANGUL LETTER O
3158		HANGUL LETTER WA
3159		HANGUL LETTER WAE
315a		HANGUL LETTER OE
315b		HANGUL LETTER YO
315c		HANGUL LETTER U
315d		HANGUL LETTER WEO
315e		HANGUL LETTER WE
315f		HANGUL LETTER WI
3160		HANGUL LETTER YU
3161		HANGUL LETTER EU
3162		HANGUL LETTER YI
3163		HANGUL LETTER I
3164		HANGUL FILLER
3165		HANGUL LETTER SSANGNIEUN
3166		HANGUL LETTER NIEUN-TIKEUT
3167		HANGUL LETTER NIEUN-SIOS
3168		HANGUL LETTER NIEUN-PANSIOS
3169		HANGUL LETTER RIEUL-KIYEOK-SIOS
316a		HANGUL LETTER RIEUL-TIKEUT
316b		HANGUL LETTER RIEUL-PIEUP-SIOS
316c		HANGUL LETTER RIEUL-PANSIOS
316d		HANGUL LETTER RIEUL-YEORINHIEUH
316e		HANGUL LETTER MIEUM-PIEUP
316f		HANGUL LETTER MIEUM-SIOS
3170		HANGUL LETTER MIEUM-PANSIOS
3171		HANGUL LETTER KAPYEOUNMIEUM
3172		HANGUL LETTER PIEUP-KIYEOK
3173		HANGUL LETTER PIEUP-TIKEUT
3174		HANGUL LETTER PIEUP-SIOS-KIYEOK
3175		HANGUL LETTER PIEUP-SIOS-TIKEUT
3176		HANGUL LETTER PIEUP-CIEUC
3177		HANGUL LETTER PIEUP-THIEUTH
3178		HANGUL LETTER KAPYEOUNPIEUP
3179		HANGUL LETTER KAPYEOUNSSANGPIEUP
317a		HANGUL LETTER SIOS-KIYEOK
317b		HANGUL LETTER SIOS-NIEUN
317c		HANGUL LETTER SIOS-TIKEUT
317d		HANGUL LETTER SIOS-PIEUP
317e		HANGUL LETTER SIOS-CIEUC
317f		HANGUL LETTER PANSIOS
3180		HANGUL LETTER SSANGIEUNG
3181		HANGUL LETTER YESIEUNG
3182		HANGUL LETTER YESIEUNG-SIOS
3183		HANGUL LETTER YESIEUNG-PANSIOS
3184		HANGUL LETTER KAPYEOUNPHIEUPH
3185		HANGUL LETTER SSANGHIEUH
3186		HANGUL LETTER YEORINHIEUH
3187		HANGUL LETTER YO-YA
3188		HANGUL LETTER YO-YAE
3189		HANGUL LETTER YO-I
318a		HANGUL LETTER YU-YEO
318b		HANGUL LETTER YU-YE
318c		HANGUL LETTER YU-I
318d		HANGUL LETTER ARAEA
318e		HANGUL LETTER ARAEAE
3190		IDEOGRAPHIC ANNOTATION LINKING MARK
3191		IDEOGRAPHIC ANNOTATION REVERSE MARK
3192		IDEOGRAPHIC ANNOTATION ONE MARK
3193		IDEOGRAPHIC ANNOTATION TWO MARK
3194		IDEOGRAPHIC ANNOTATION THREE MARK
3195		IDEOGRAPHIC ANNOTATION FOUR MARK
3196		IDEOGRAPHIC ANNOTATION TOP MARK
3197		IDEOGRAPHIC ANNOTATION MIDDLE MARK
3198		IDEOGRAPHIC ANNOTATION BOTTOM MARK
3199		IDEOGRAPHIC ANNOTATION FIRST MARK
319a		IDEOGRAPHIC ANNOTATION SECOND MARK
319b		IDEOGRAPHIC ANNOTATION THIRD MARK
319c		IDEOGRAPHIC ANNOTATION FOURTH MARK
319d		IDEOGRAPHIC ANNOTATION HEAVEN MARK
319e		IDEOGRAPHIC ANNOTATION EARTH MARK
319f		IDEOGRAPHIC ANNOTATION MAN MARK
3200		PARENTHESIZED HANGUL KIYEOK
3201		PARENTHESIZED HANGUL NIEUN
3202		PARENTHESIZED HANGUL TIKEUT
3203		PARENTHESIZED HANGUL RIEUL
3204		PARENTHESIZED HANGUL MIEUM
3205		PARENTHESIZED HANGUL PIEUP
3206		PARENTHESIZED HANGUL SIOS
3207		PARENTHESIZED HANGUL IEUNG
3208		PARENTHESIZED HANGUL CIEUC
3209		PARENTHESIZED HANGUL CHIEUCH
320a		PARENTHESIZED HANGUL KHIEUKH
320b		PARENTHESIZED HANGUL THIEUTH
320c		PARENTHESIZED HANGUL PHIEUPH
320d		PARENTHESIZED HANGUL HIEUH
320e		PARENTHESIZED HANGUL KIYEOK A
320f		PARENTHESIZED HANGUL NIEUN A
3210		PARENTHESIZED HANGUL TIKEUT A
3211		PARENTHESIZED HANGUL RIEUL A
3212		PARENTHESIZED HANGUL MIEUM A
3213		PARENTHESIZED HANGUL PIEUP A
3214		PARENTHESIZED HANGUL SIOS A
3215		PARENTHESIZED HANGUL IEUNG A
3216		PARENTHESIZED HANGUL CIEUC A
3217		PARENTHESIZED HANGUL CHIEUCH A
3218		PARENTHESIZED HANGUL KHIEUKH A
3219		PARENTHESIZED HANGUL THIEUTH A
321a		PARENTHESIZED HANGUL PHIEUPH A
321b		PARENTHESIZED HANGUL HIEUH A
321c		PARENTHESIZED HANGUL CIEUC U
3220		PARENTHESIZED IDEOGRAPH ONE
3221		PARENTHESIZED IDEOGRAPH TWO
3222		PARENTHESIZED IDEOGRAPH THREE
3223		PARENTHESIZED IDEOGRAPH FOUR
3224		PARENTHESIZED IDEOGRAPH FIVE
3225		PARENTHESIZED IDEOGRAPH SIX
3226		PARENTHESIZED IDEOGRAPH SEVEN
3227		PARENTHESIZED IDEOGRAPH EIGHT
3228		PARENTHESIZED IDEOGRAPH NINE
3229		PARENTHESIZED IDEOGRAPH TEN
322a		PARENTHESIZED IDEOGRAPH MOON
322b		PARENTHESIZED IDEOGRAPH FIRE
322c		PARENTHESIZED IDEOGRAPH WATER
322d		PARENTHESIZED IDEOGRAPH WOOD
322e		PARENTHESIZED IDEOGRAPH METAL
322f		PARENTHESIZED IDEOGRAPH EARTH
3230		PARENTHESIZED IDEOGRAPH SUN
3231		PARENTHESIZED IDEOGRAPH STOCK
3232		PARENTHESIZED IDEOGRAPH HAVE
3233		PARENTHESIZED IDEOGRAPH SOCIETY
3234		PARENTHESIZED IDEOGRAPH NAME
3235		PARENTHESIZED IDEOGRAPH SPECIAL
3236		PARENTHESIZED IDEOGRAPH FINANCIAL
3237		PARENTHESIZED IDEOGRAPH CONGRATULATION
3238		PARENTHESIZED IDEOGRAPH LABOR
3239		PARENTHESIZED IDEOGRAPH REPRESENT
323a		PARENTHESIZED IDEOGRAPH CALL
323b		PARENTHESIZED IDEOGRAPH STUDY
323c		PARENTHESIZED IDEOGRAPH SUPERVISE
323d		PARENTHESIZED IDEOGRAPH ENTERPRISE
323e		PARENTHESIZED IDEOGRAPH RESOURCE
323f		PARENTHESIZED IDEOGRAPH ALLIANCE
3240		PARENTHESIZED IDEOGRAPH FESTIVAL
3241		PARENTHESIZED IDEOGRAPH REST
3242		PARENTHESIZED IDEOGRAPH SELF
3243		PARENTHESIZED IDEOGRAPH REACH
3260		CIRCLED HANGUL KIYEOK
3261		CIRCLED HANGUL NIEUN
3262		CIRCLED HANGUL TIKEUT
3263		CIRCLED HANGUL RIEUL
3264		CIRCLED HANGUL MIEUM
3265		CIRCLED HANGUL PIEUP
3266		CIRCLED HANGUL SIOS
3267		CIRCLED HANGUL IEUNG
3268		CIRCLED HANGUL CIEUC
3269		CIRCLED HANGUL CHIEUCH
326a		CIRCLED HANGUL KHIEUKH
326b		CIRCLED HANGUL THIEUTH
326c		CIRCLED HANGUL PHIEUPH
326d		CIRCLED HANGUL HIEUH
326e		CIRCLED HANGUL KIYEOK A
326f		CIRCLED HANGUL NIEUN A
3270		CIRCLED HANGUL TIKEUT A
3271		CIRCLED HANGUL RIEUL A
3272		CIRCLED HANGUL MIEUM A
3273		CIRCLED HANGUL PIEUP A
3274		CIRCLED HANGUL SIOS A
3275		CIRCLED HANGUL IEUNG A
3276		CIRCLED HANGUL CIEUC A
3277		CIRCLED HANGUL CHIEUCH A
3278		CIRCLED HANGUL KHIEUKH A
3279		CIRCLED HANGUL THIEUTH A
327a		CIRCLED HANGUL PHIEUPH A
327b		CIRCLED HANGUL HIEUH A
327f		KOREAN STANDARD SYMBOL
3280		CIRCLED IDEOGRAPH ONE
3281		CIRCLED IDEOGRAPH TWO
3282		CIRCLED IDEOGRAPH THREE
3283		CIRCLED IDEOGRAPH FOUR
3284		CIRCLED IDEOGRAPH FIVE
3285		CIRCLED IDEOGRAPH SIX
3286		CIRCLED IDEOGRAPH SEVEN
3287		CIRCLED IDEOGRAPH EIGHT
3288		CIRCLED IDEOGRAPH NINE
3289		CIRCLED IDEOGRAPH TEN
328a		CIRCLED IDEOGRAPH MOON
328b		CIRCLED IDEOGRAPH FIRE
328c		CIRCLED IDEOGRAPH WATER
328d		CIRCLED IDEOGRAPH WOOD
328e		CIRCLED IDEOGRAPH METAL
328f		CIRCLED IDEOGRAPH EARTH
3290		CIRCLED IDEOGRAPH SUN
3291		CIRCLED IDEOGRAPH STOCK
3292		CIRCLED IDEOGRAPH HAVE
3293		CIRCLED IDEOGRAPH SOCIETY
3294		CIRCLED IDEOGRAPH NAME
3295		CIRCLED IDEOGRAPH SPECIAL
3296		CIRCLED IDEOGRAPH FINANCIAL
3297		CIRCLED IDEOGRAPH CONGRATULATION
3298		CIRCLED IDEOGRAPH LABOR
3299		CIRCLED IDEOGRAPH SECRET
329a		CIRCLED IDEOGRAPH MALE
329b		CIRCLED IDEOGRAPH FEMALE
329c		CIRCLED IDEOGRAPH SUITABLE
329d		CIRCLED IDEOGRAPH EXCELLENT
329e		CIRCLED IDEOGRAPH PRINT
329f		CIRCLED IDEOGRAPH ATTENTION
32a0		CIRCLED IDEOGRAPH ITEM
32a1		CIRCLED IDEOGRAPH REST
32a2		CIRCLED IDEOGRAPH COPY
32a3		CIRCLED IDEOGRAPH CORRECT
32a4		CIRCLED IDEOGRAPH HIGH
32a5		CIRCLED IDEOGRAPH CENTRE
32a6		CIRCLED IDEOGRAPH LOW
32a7		CIRCLED IDEOGRAPH LEFT
32a8		CIRCLED IDEOGRAPH RIGHT
32a9		CIRCLED IDEOGRAPH MEDICINE
32aa		CIRCLED IDEOGRAPH RELIGION
32ab		CIRCLED IDEOGRAPH STUDY
32ac		CIRCLED IDEOGRAPH SUPERVISE
32ad		CIRCLED IDEOGRAPH ENTERPRISE
32ae		CIRCLED IDEOGRAPH RESOURCE
32af		CIRCLED IDEOGRAPH ALLIANCE
32b0		CIRCLED IDEOGRAPH NIGHT
32c0		IDEOGRAPHIC TELEGRAPH SYMBOL FOR JANUARY
32c1		IDEOGRAPHIC TELEGRAPH SYMBOL FOR FEBRUARY
32c2		IDEOGRAPHIC TELEGRAPH SYMBOL FOR MARCH
32c3		IDEOGRAPHIC TELEGRAPH SYMBOL FOR APRIL
32c4		IDEOGRAPHIC TELEGRAPH SYMBOL FOR MAY
32c5		IDEOGRAPHIC TELEGRAPH SYMBOL FOR JUNE
32c6		IDEOGRAPHIC TELEGRAPH SYMBOL FOR JULY
32c7		IDEOGRAPHIC TELEGRAPH SYMBOL FOR AUGUST
32c8		IDEOGRAPHIC TELEGRAPH SYMBOL FOR SEPTEMBER
32c9		IDEOGRAPHIC TELEGRAPH SYMBOL FOR OCTOBER
32ca		IDEOGRAPHIC TELEGRAPH SYMBOL FOR NOVEMBER
32cb		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DECEMBER
32d0		CIRCLED KATAKANA A
32d1		CIRCLED KATAKANA I
32d2		CIRCLED KATAKANA U
32d3		CIRCLED KATAKANA E
32d4		CIRCLED KATAKANA O
32d5		CIRCLED KATAKANA KA
32d6		CIRCLED KATAKANA KI
32d7		CIRCLED KATAKANA KU
32d8		CIRCLED KATAKANA KE
32d9		CIRCLED KATAKANA KO
32da		CIRCLED KATAKANA SA
32db		CIRCLED KATAKANA SI
32dc		CIRCLED KATAKANA SU
32dd		CIRCLED KATAKANA SE
32de		CIRCLED KATAKANA SO
32df		CIRCLED KATAKANA TA
32e0		CIRCLED KATAKANA TI
32e1		CIRCLED KATAKANA TU
32e2		CIRCLED KATAKANA TE
32e3		CIRCLED KATAKANA TO
32e4		CIRCLED KATAKANA NA
32e5		CIRCLED KATAKANA NI
32e6		CIRCLED KATAKANA NU
32e7		CIRCLED KATAKANA NE
32e8		CIRCLED KATAKANA NO
32e9		CIRCLED KATAKANA HA
32ea		CIRCLED KATAKANA HI
32eb		CIRCLED KATAKANA HU
32ec		CIRCLED KATAKANA HE
32ed		CIRCLED KATAKANA HO
32ee		CIRCLED KATAKANA MA
32ef		CIRCLED KATAKANA MI
32f0		CIRCLED KATAKANA MU
32f1		CIRCLED KATAKANA ME
32f2		CIRCLED KATAKANA MO
32f3		CIRCLED KATAKANA YA
32f4		CIRCLED KATAKANA YU
32f5		CIRCLED KATAKANA YO
32f6		CIRCLED KATAKANA RA
32f7		CIRCLED KATAKANA RI
32f8		CIRCLED KATAKANA RU
32f9		CIRCLED KATAKANA RE
32fa		CIRCLED KATAKANA RO
32fb		CIRCLED KATAKANA WA
32fc		CIRCLED KATAKANA WI
32fd		CIRCLED KATAKANA WE
32fe		CIRCLED KATAKANA WO
3300		SQUARE APAATO
3301		SQUARE ARUHUA
3302		SQUARE ANPEA
3303		SQUARE AARU
3304		SQUARE ININGU
3305		SQUARE INTI
3306		SQUARE UON
3307		SQUARE ESUKUUDO
3308		SQUARE EEKAA
3309		SQUARE ONSU
330a		SQUARE OOMU
330b		SQUARE KAIRI
330c		SQUARE KARATTO
330d		SQUARE KARORII
330e		SQUARE GARON
330f		SQUARE GANMA
3310		SQUARE GIGA
3311		SQUARE GINII
3312		SQUARE KYURII
3313		SQUARE GIRUDAA
3314		SQUARE KIRO
3315		SQUARE KIROGURAMU
3316		SQUARE KIROMEETORU
3317		SQUARE KIROWATTO
3318		SQUARE GURAMU
3319		SQUARE GURAMUTON
331a		SQUARE KURUZEIRO
331b		SQUARE KUROONE
331c		SQUARE KEESU
331d		SQUARE KORUNA
331e		SQUARE KOOPO
331f		SQUARE SAIKURU
3320		SQUARE SANTIIMU
3321		SQUARE SIRINGU
3322		SQUARE SENTI
3323		SQUARE SENTO
3324		SQUARE DAASU
3325		SQUARE DESI
3326		SQUARE DORU
3327		SQUARE TON
3328		SQUARE NANO
3329		SQUARE NOTTO
332a		SQUARE HAITU
332b		SQUARE PAASENTO
332c		SQUARE PAATU
332d		SQUARE BAARERU
332e		SQUARE PIASUTORU
332f		SQUARE PIKURU
3330		SQUARE PIKO
3331		SQUARE BIRU
3332		SQUARE HUARADDO
3333		SQUARE HUIITO
3334		SQUARE BUSSYERU
3335		SQUARE HURAN
3336		SQUARE HEKUTAARU
3337		SQUARE PESO
3338		SQUARE PENIHI
3339		SQUARE HERUTU
333a		SQUARE PENSU
333b		SQUARE PEEZI
333c		SQUARE BEETA
333d		SQUARE POINTO
333e		SQUARE BORUTO
333f		SQUARE HON
3340		SQUARE PONDO
3341		SQUARE HOORU
3342		SQUARE HOON
3343		SQUARE MAIKURO
3344		SQUARE MAIRU
3345		SQUARE MAHHA
3346		SQUARE MARUKU
3347		SQUARE MANSYON
3348		SQUARE MIKURON
3349		SQUARE MIRI
334a		SQUARE MIRIBAARU
334b		SQUARE MEGA
334c		SQUARE MEGATON
334d		SQUARE MEETORU
334e		SQUARE YAADO
334f		SQUARE YAARU
3350		SQUARE YUAN
3351		SQUARE RITTORU
3352		SQUARE RIRA
3353		SQUARE RUPII
3354		SQUARE RUUBURU
3355		SQUARE REMU
3356		SQUARE RENTOGEN
3357		SQUARE WATTO
3358		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ZERO
3359		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ONE
335a		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWO
335b		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THREE
335c		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOUR
335d		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIVE
335e		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIX
335f		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVEN
3360		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHT
3361		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINE
3362		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TEN
3363		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ELEVEN
3364		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWELVE
3365		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THIRTEEN
3366		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOURTEEN
3367		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIFTEEN
3368		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIXTEEN
3369		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVENTEEN
336a		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHTEEN
336b		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINETEEN
336c		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY
336d		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-ONE
336e		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-TWO
336f		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-THREE
3370		IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-FOUR
3371		SQUARE HPA
3372		SQUARE DA
3373		SQUARE AU
3374		SQUARE BAR
3375		SQUARE OV
3376		SQUARE PC
337b		SQUARE ERA NAME HEISEI
337c		SQUARE ERA NAME SYOUWA
337d		SQUARE ERA NAME TAISYOU
337e		SQUARE ERA NAME MEIZI
337f		SQUARE CORPORATION
3380		SQUARE PA AMPS
3381		SQUARE NA
3382		SQUARE MU A
3383		SQUARE MA
3384		SQUARE KA
3385		SQUARE KB
3386		SQUARE MB
3387		SQUARE GB
3388		SQUARE CAL
3389		SQUARE KCAL
338a		SQUARE PF
338b		SQUARE NF
338c		SQUARE MU F
338d		SQUARE MU G
338e		SQUARE MG
338f		SQUARE KG
3390		SQUARE HZ
3391		SQUARE KHZ
3392		SQUARE MHZ
3393		SQUARE GHZ
3394		SQUARE THZ
3395		SQUARE MU L
3396		SQUARE ML
3397		SQUARE DL
3398		SQUARE KL
3399		SQUARE FM
339a		SQUARE NM
339b		SQUARE MU M
339c		SQUARE MM
339d		SQUARE CM
339e		SQUARE KM
339f		SQUARE MM SQUARED
33a0		SQUARE CM SQUARED
33a1		SQUARE M SQUARED
33a2		SQUARE KM SQUARED
33a3		SQUARE MM CUBED
33a4		SQUARE CM CUBED
33a5		SQUARE M CUBED
33a6		SQUARE KM CUBED
33a7		SQUARE M OVER S
33a8		SQUARE M OVER S SQUARED
33a9		SQUARE PA
33aa		SQUARE KPA
33ab		SQUARE MPA
33ac		SQUARE GPA
33ad		SQUARE RAD
33ae		SQUARE RAD OVER S
33af		SQUARE RAD OVER S SQUARED
33b0		SQUARE PS
33b1		SQUARE NS
33b2		SQUARE MU S
33b3		SQUARE MS
33b4		SQUARE PV
33b5		SQUARE NV
33b6		SQUARE MU V
33b7		SQUARE MV
33b8		SQUARE KV
33b9		SQUARE MV MEGA
33ba		SQUARE PW
33bb		SQUARE NW
33bc		SQUARE MU W
33bd		SQUARE MW
33be		SQUARE KW
33bf		SQUARE MW MEGA
33c0		SQUARE K OHM
33c1		SQUARE M OHM
33c2		SQUARE AM
33c3		SQUARE BQ
33c4		SQUARE CC
33c5		SQUARE CD
33c6		SQUARE C OVER KG
33c7		SQUARE CO
33c8		SQUARE DB
33c9		SQUARE GY
33ca		SQUARE HA
33cb		SQUARE HP
33cc		SQUARE IN
33cd		SQUARE KK
33ce		SQUARE KM CAPITAL
33cf		SQUARE KT
33d0		SQUARE LM
33d1		SQUARE LN
33d2		SQUARE LOG
33d3		SQUARE LX
33d4		SQUARE MB SMALL
33d5		SQUARE MIL
33d6		SQUARE MOL
33d7		SQUARE PH
33d8		SQUARE PM
33d9		SQUARE PPM
33da		SQUARE PR
33db		SQUARE SR
33dc		SQUARE SV
33dd		SQUARE WB
33e0		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ONE
33e1		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWO
33e2		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THREE
33e3		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOUR
33e4		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIVE
33e5		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIX
33e6		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVEN
33e7		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHT
33e8		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINE
33e9		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TEN
33ea		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ELEVEN
33eb		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWELVE
33ec		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTEEN
33ed		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOURTEEN
33ee		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIFTEEN
33ef		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIXTEEN
33f0		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVENTEEN
33f1		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHTEEN
33f2		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINETEEN
33f3		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY
33f4		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-ONE
33f5		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-TWO
33f6		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-THREE
33f7		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FOUR
33f8		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FIVE
33f9		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SIX
33fa		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SEVEN
33fb		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-EIGHT
33fc		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-NINE
33fd		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY
33fe		IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY-ONE
4e00	9fa5	<CJK Ideograph, First>
ac00	d7a3	<Hangul Syllable, First>
d800	db7f	<Unassigned High Surrogate, First>
db80	dbff	<Private Use High Surrogate, First>
dc00	dfff	<Low Surrogate, First>
e000	f8ff	<Private Use, First>
f900	fa2d	<CJK Compatibility Ideograph, First>
fb00		LATIN SMALL LIGATURE FF
fb01		LATIN SMALL LIGATURE FI
fb02		LATIN SMALL LIGATURE FL
fb03		LATIN SMALL LIGATURE FFI
fb04		LATIN SMALL LIGATURE FFL
fb05		LATIN SMALL LIGATURE LONG S T
fb06		LATIN SMALL LIGATURE ST
fb13		ARMENIAN SMALL LIGATURE MEN NOW
fb14		ARMENIAN SMALL LIGATURE MEN ECH
fb15		ARMENIAN SMALL LIGATURE MEN INI
fb16		ARMENIAN SMALL LIGATURE VEW NOW
fb17		ARMENIAN SMALL LIGATURE MEN XEH
fb1e		HEBREW POINT JUDEO-SPANISH VARIKA
fb1f		HEBREW LIGATURE YIDDISH YOD YOD PATAH
fb20		HEBREW LETTER ALTERNATIVE AYIN
fb21		HEBREW LETTER WIDE ALEF
fb22		HEBREW LETTER WIDE DALET
fb23		HEBREW LETTER WIDE HE
fb24		HEBREW LETTER WIDE KAF
fb25		HEBREW LETTER WIDE LAMED
fb26		HEBREW LETTER WIDE FINAL MEM
fb27		HEBREW LETTER WIDE RESH
fb28		HEBREW LETTER WIDE TAV
fb29		HEBREW LETTER ALTERNATIVE PLUS SIGN
fb2a		HEBREW LETTER SHIN WITH SHIN DOT
fb2b		HEBREW LETTER SHIN WITH SIN DOT
fb2c		HEBREW LETTER SHIN WITH DAGESH AND SHIN DOT
fb2d		HEBREW LETTER SHIN WITH DAGESH AND SIN DOT
fb2e		HEBREW LETTER ALEF WITH PATAH
fb2f		HEBREW LETTER ALEF WITH QAMATS
fb30		HEBREW LETTER ALEF WITH MAPIQ
fb31		HEBREW LETTER BET WITH DAGESH
fb32		HEBREW LETTER GIMEL WITH DAGESH
fb33		HEBREW LETTER DALET WITH DAGESH
fb34		HEBREW LETTER HE WITH MAPIQ
fb35		HEBREW LETTER VAV WITH DAGESH
fb36		HEBREW LETTER ZAYIN WITH DAGESH
fb38		HEBREW LETTER TET WITH DAGESH
fb39		HEBREW LETTER YOD WITH DAGESH
fb3a		HEBREW LETTER FINAL KAF WITH DAGESH
fb3b		HEBREW LETTER KAF WITH DAGESH
fb3c		HEBREW LETTER LAMED WITH DAGESH
fb3e		HEBREW LETTER MEM WITH DAGESH
fb40		HEBREW LETTER NUN WITH DAGESH
fb41		HEBREW LETTER SAMEKH WITH DAGESH
fb43		HEBREW LETTER FINAL PE WITH DAGESH
fb44		HEBREW LETTER PE WITH DAGESH
fb46		HEBREW LETTER TSADI WITH DAGESH
fb47		HEBREW LETTER QOF WITH DAGESH
fb48		HEBREW LETTER RESH WITH DAGESH
fb49		HEBREW LETTER SHIN WITH DAGESH
fb4a		HEBREW LETTER TAV WITH DAGESH
fb4b		HEBREW LETTER VAV WITH HOLAM
fb4c		HEBREW LETTER BET WITH RAFE
fb4d		HEBREW LETTER KAF WITH RAFE
fb4e		HEBREW LETTER PE WITH RAFE
fb4f		HEBREW LIGATURE ALEF LAMED
fb50		ARABIC LETTER ALEF WASLA ISOLATED FORM
fb51		ARABIC LETTER ALEF WASLA FINAL FORM
fb52		ARABIC LETTER BEEH ISOLATED FORM
fb53		ARABIC LETTER BEEH FINAL FORM
fb54		ARABIC LETTER BEEH INITIAL FORM
fb55		ARABIC LETTER BEEH MEDIAL FORM
fb56		ARABIC LETTER PEH ISOLATED FORM
fb57		ARABIC LETTER PEH FINAL FORM
fb58		ARABIC LETTER PEH INITIAL FORM
fb59		ARABIC LETTER PEH MEDIAL FORM
fb5a		ARABIC LETTER BEHEH ISOLATED FORM
fb5b		ARABIC LETTER BEHEH FINAL FORM
fb5c		ARABIC LETTER BEHEH INITIAL FORM
fb5d		ARABIC LETTER BEHEH MEDIAL FORM
fb5e		ARABIC LETTER TTEHEH ISOLATED FORM
fb5f		ARABIC LETTER TTEHEH FINAL FORM
fb60		ARABIC LETTER TTEHEH INITIAL FORM
fb61		ARABIC LETTER TTEHEH MEDIAL FORM
fb62		ARABIC LETTER TEHEH ISOLATED FORM
fb63		ARABIC LETTER TEHEH FINAL FORM
fb64		ARABIC LETTER TEHEH INITIAL FORM
fb65		ARABIC LETTER TEHEH MEDIAL FORM
fb66		ARABIC LETTER TTEH ISOLATED FORM
fb67		ARABIC LETTER TTEH FINAL FORM
fb68		ARABIC LETTER TTEH INITIAL FORM
fb69		ARABIC LETTER TTEH MEDIAL FORM
fb6a		ARABIC LETTER VEH ISOLATED FORM
fb6b		ARABIC LETTER VEH FINAL FORM
fb6c		ARABIC LETTER VEH INITIAL FORM
fb6d		ARABIC LETTER VEH MEDIAL FORM
fb6e		ARABIC LETTER PEHEH ISOLATED FORM
fb6f		ARABIC LETTER PEHEH FINAL FORM
fb70		ARABIC LETTER PEHEH INITIAL FORM
fb71		ARABIC LETTER PEHEH MEDIAL FORM
fb72		ARABIC LETTER DYEH ISOLATED FORM
fb73		ARABIC LETTER DYEH FINAL FORM
fb74		ARABIC LETTER DYEH INITIAL FORM
fb75		ARABIC LETTER DYEH MEDIAL FORM
fb76		ARABIC LETTER NYEH ISOLATED FORM
fb77		ARABIC LETTER NYEH FINAL FORM
fb78		ARABIC LETTER NYEH INITIAL FORM
fb79		ARABIC LETTER NYEH MEDIAL FORM
fb7a		ARABIC LETTER TCHEH ISOLATED FORM
fb7b		ARABIC LETTER TCHEH FINAL FORM
fb7c		ARABIC LETTER TCHEH INITIAL FORM
fb7d		ARABIC LETTER TCHEH MEDIAL FORM
fb7e		ARABIC LETTER TCHEHEH ISOLATED FORM
fb7f		ARABIC LETTER TCHEHEH FINAL FORM
fb80		ARABIC LETTER TCHEHEH INITIAL FORM
fb81		ARABIC LETTER TCHEHEH MEDIAL FORM
fb82		ARABIC LETTER DDAHAL ISOLATED FORM
fb83		ARABIC LETTER DDAHAL FINAL FORM
fb84		ARABIC LETTER DAHAL ISOLATED FORM
fb85		ARABIC LETTER DAHAL FINAL FORM
fb86		ARABIC LETTER DUL ISOLATED FORM
fb87		ARABIC LETTER DUL FINAL FORM
fb88		ARABIC LETTER DDAL ISOLATED FORM
fb89		ARABIC LETTER DDAL FINAL FORM
fb8a		ARABIC LETTER JEH ISOLATED FORM
fb8b		ARABIC LETTER JEH FINAL FORM
fb8c		ARABIC LETTER RREH ISOLATED FORM
fb8d		ARABIC LETTER RREH FINAL FORM
fb8e		ARABIC LETTER KEHEH ISOLATED FORM
fb8f		ARABIC LETTER KEHEH FINAL FORM
fb90		ARABIC LETTER KEHEH INITIAL FORM
fb91		ARABIC LETTER KEHEH MEDIAL FORM
fb92		ARABIC LETTER GAF ISOLATED FORM
fb93		ARABIC LETTER GAF FINAL FORM
fb94		ARABIC LETTER GAF INITIAL FORM
fb95		ARABIC LETTER GAF MEDIAL FORM
fb96		ARABIC LETTER GUEH ISOLATED FORM
fb97		ARABIC LETTER GUEH FINAL FORM
fb98		ARABIC LETTER GUEH INITIAL FORM
fb99		ARABIC LETTER GUEH MEDIAL FORM
fb9a		ARABIC LETTER NGOEH ISOLATED FORM
fb9b		ARABIC LETTER NGOEH FINAL FORM
fb9c		ARABIC LETTER NGOEH INITIAL FORM
fb9d		ARABIC LETTER NGOEH MEDIAL FORM
fb9e		ARABIC LETTER NOON GHUNNA ISOLATED FORM
fb9f		ARABIC LETTER NOON GHUNNA FINAL FORM
fba0		ARABIC LETTER RNOON ISOLATED FORM
fba1		ARABIC LETTER RNOON FINAL FORM
fba2		ARABIC LETTER RNOON INITIAL FORM
fba3		ARABIC LETTER RNOON MEDIAL FORM
fba4		ARABIC LETTER HEH WITH YEH ABOVE ISOLATED FORM
fba5		ARABIC LETTER HEH WITH YEH ABOVE FINAL FORM
fba6		ARABIC LETTER HEH GOAL ISOLATED FORM
fba7		ARABIC LETTER HEH GOAL FINAL FORM
fba8		ARABIC LETTER HEH GOAL INITIAL FORM
fba9		ARABIC LETTER HEH GOAL MEDIAL FORM
fbaa		ARABIC LETTER HEH DOACHASHMEE ISOLATED FORM
fbab		ARABIC LETTER HEH DOACHASHMEE FINAL FORM
fbac		ARABIC LETTER HEH DOACHASHMEE INITIAL FORM
fbad		ARABIC LETTER HEH DOACHASHMEE MEDIAL FORM
fbae		ARABIC LETTER YEH BARREE ISOLATED FORM
fbaf		ARABIC LETTER YEH BARREE FINAL FORM
fbb0		ARABIC LETTER YEH BARREE WITH HAMZA ABOVE ISOLATED FORM
fbb1		ARABIC LETTER YEH BARREE WITH HAMZA ABOVE FINAL FORM
fbd3		ARABIC LETTER NG ISOLATED FORM
fbd4		ARABIC LETTER NG FINAL FORM
fbd5		ARABIC LETTER NG INITIAL FORM
fbd6		ARABIC LETTER NG MEDIAL FORM
fbd7		ARABIC LETTER U ISOLATED FORM
fbd8		ARABIC LETTER U FINAL FORM
fbd9		ARABIC LETTER OE ISOLATED FORM
fbda		ARABIC LETTER OE FINAL FORM
fbdb		ARABIC LETTER YU ISOLATED FORM
fbdc		ARABIC LETTER YU FINAL FORM
fbdd		ARABIC LETTER U WITH HAMZA ABOVE ISOLATED FORM
fbde		ARABIC LETTER VE ISOLATED FORM
fbdf		ARABIC LETTER VE FINAL FORM
fbe0		ARABIC LETTER KIRGHIZ OE ISOLATED FORM
fbe1		ARABIC LETTER KIRGHIZ OE FINAL FORM
fbe2		ARABIC LETTER KIRGHIZ YU ISOLATED FORM
fbe3		ARABIC LETTER KIRGHIZ YU FINAL FORM
fbe4		ARABIC LETTER E ISOLATED FORM
fbe5		ARABIC LETTER E FINAL FORM
fbe6		ARABIC LETTER E INITIAL FORM
fbe7		ARABIC LETTER E MEDIAL FORM
fbe8		ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA INITIAL FORM
fbe9		ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA MEDIAL FORM
fbea		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF ISOLATED FORM
fbeb		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF FINAL FORM
fbec		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE ISOLATED FORM
fbed		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE FINAL FORM
fbee		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW ISOLATED FORM
fbef		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW FINAL FORM
fbf0		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U ISOLATED FORM
fbf1		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U FINAL FORM
fbf2		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE ISOLATED FORM
fbf3		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE FINAL FORM
fbf4		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU ISOLATED FORM
fbf5		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU FINAL FORM
fbf6		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E ISOLATED FORM
fbf7		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E FINAL FORM
fbf8		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E INITIAL FORM
fbf9		ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM
fbfa		ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM
fbfb		ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA INITIAL FORM
fbfc		ARABIC LETTER FARSI YEH ISOLATED FORM
fbfd		ARABIC LETTER FARSI YEH FINAL FORM
fbfe		ARABIC LETTER FARSI YEH INITIAL FORM
fbff		ARABIC LETTER FARSI YEH MEDIAL FORM
fc00		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM ISOLATED FORM
fc01		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH ISOLATED FORM
fc02		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM ISOLATED FORM
fc03		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM
fc04		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH ISOLATED FORM
fc05		ARABIC LIGATURE BEH WITH JEEM ISOLATED FORM
fc06		ARABIC LIGATURE BEH WITH HAH ISOLATED FORM
fc07		ARABIC LIGATURE BEH WITH KHAH ISOLATED FORM
fc08		ARABIC LIGATURE BEH WITH MEEM ISOLATED FORM
fc09		ARABIC LIGATURE BEH WITH ALEF MAKSURA ISOLATED FORM
fc0a		ARABIC LIGATURE BEH WITH YEH ISOLATED FORM
fc0b		ARABIC LIGATURE TEH WITH JEEM ISOLATED FORM
fc0c		ARABIC LIGATURE TEH WITH HAH ISOLATED FORM
fc0d		ARABIC LIGATURE TEH WITH KHAH ISOLATED FORM
fc0e		ARABIC LIGATURE TEH WITH MEEM ISOLATED FORM
fc0f		ARABIC LIGATURE TEH WITH ALEF MAKSURA ISOLATED FORM
fc10		ARABIC LIGATURE TEH WITH YEH ISOLATED FORM
fc11		ARABIC LIGATURE THEH WITH JEEM ISOLATED FORM
fc12		ARABIC LIGATURE THEH WITH MEEM ISOLATED FORM
fc13		ARABIC LIGATURE THEH WITH ALEF MAKSURA ISOLATED FORM
fc14		ARABIC LIGATURE THEH WITH YEH ISOLATED FORM
fc15		ARABIC LIGATURE JEEM WITH HAH ISOLATED FORM
fc16		ARABIC LIGATURE JEEM WITH MEEM ISOLATED FORM
fc17		ARABIC LIGATURE HAH WITH JEEM ISOLATED FORM
fc18		ARABIC LIGATURE HAH WITH MEEM ISOLATED FORM
fc19		ARABIC LIGATURE KHAH WITH JEEM ISOLATED FORM
fc1a		ARABIC LIGATURE KHAH WITH HAH ISOLATED FORM
fc1b		ARABIC LIGATURE KHAH WITH MEEM ISOLATED FORM
fc1c		ARABIC LIGATURE SEEN WITH JEEM ISOLATED FORM
fc1d		ARABIC LIGATURE SEEN WITH HAH ISOLATED FORM
fc1e		ARABIC LIGATURE SEEN WITH KHAH ISOLATED FORM
fc1f		ARABIC LIGATURE SEEN WITH MEEM ISOLATED FORM
fc20		ARABIC LIGATURE SAD WITH HAH ISOLATED FORM
fc21		ARABIC LIGATURE SAD WITH MEEM ISOLATED FORM
fc22		ARABIC LIGATURE DAD WITH JEEM ISOLATED FORM
fc23		ARABIC LIGATURE DAD WITH HAH ISOLATED FORM
fc24		ARABIC LIGATURE DAD WITH KHAH ISOLATED FORM
fc25		ARABIC LIGATURE DAD WITH MEEM ISOLATED FORM
fc26		ARABIC LIGATURE TAH WITH HAH ISOLATED FORM
fc27		ARABIC LIGATURE TAH WITH MEEM ISOLATED FORM
fc28		ARABIC LIGATURE ZAH WITH MEEM ISOLATED FORM
fc29		ARABIC LIGATURE AIN WITH JEEM ISOLATED FORM
fc2a		ARABIC LIGATURE AIN WITH MEEM ISOLATED FORM
fc2b		ARABIC LIGATURE GHAIN WITH JEEM ISOLATED FORM
fc2c		ARABIC LIGATURE GHAIN WITH MEEM ISOLATED FORM
fc2d		ARABIC LIGATURE FEH WITH JEEM ISOLATED FORM
fc2e		ARABIC LIGATURE FEH WITH HAH ISOLATED FORM
fc2f		ARABIC LIGATURE FEH WITH KHAH ISOLATED FORM
fc30		ARABIC LIGATURE FEH WITH MEEM ISOLATED FORM
fc31		ARABIC LIGATURE FEH WITH ALEF MAKSURA ISOLATED FORM
fc32		ARABIC LIGATURE FEH WITH YEH ISOLATED FORM
fc33		ARABIC LIGATURE QAF WITH HAH ISOLATED FORM
fc34		ARABIC LIGATURE QAF WITH MEEM ISOLATED FORM
fc35		ARABIC LIGATURE QAF WITH ALEF MAKSURA ISOLATED FORM
fc36		ARABIC LIGATURE QAF WITH YEH ISOLATED FORM
fc37		ARABIC LIGATURE KAF WITH ALEF ISOLATED FORM
fc38		ARABIC LIGATURE KAF WITH JEEM ISOLATED FORM
fc39		ARABIC LIGATURE KAF WITH HAH ISOLATED FORM
fc3a		ARABIC LIGATURE KAF WITH KHAH ISOLATED FORM
fc3b		ARABIC LIGATURE KAF WITH LAM ISOLATED FORM
fc3c		ARABIC LIGATURE KAF WITH MEEM ISOLATED FORM
fc3d		ARABIC LIGATURE KAF WITH ALEF MAKSURA ISOLATED FORM
fc3e		ARABIC LIGATURE KAF WITH YEH ISOLATED FORM
fc3f		ARABIC LIGATURE LAM WITH JEEM ISOLATED FORM
fc40		ARABIC LIGATURE LAM WITH HAH ISOLATED FORM
fc41		ARABIC LIGATURE LAM WITH KHAH ISOLATED FORM
fc42		ARABIC LIGATURE LAM WITH MEEM ISOLATED FORM
fc43		ARABIC LIGATURE LAM WITH ALEF MAKSURA ISOLATED FORM
fc44		ARABIC LIGATURE LAM WITH YEH ISOLATED FORM
fc45		ARABIC LIGATURE MEEM WITH JEEM ISOLATED FORM
fc46		ARABIC LIGATURE MEEM WITH HAH ISOLATED FORM
fc47		ARABIC LIGATURE MEEM WITH KHAH ISOLATED FORM
fc48		ARABIC LIGATURE MEEM WITH MEEM ISOLATED FORM
fc49		ARABIC LIGATURE MEEM WITH ALEF MAKSURA ISOLATED FORM
fc4a		ARABIC LIGATURE MEEM WITH YEH ISOLATED FORM
fc4b		ARABIC LIGATURE NOON WITH JEEM ISOLATED FORM
fc4c		ARABIC LIGATURE NOON WITH HAH ISOLATED FORM
fc4d		ARABIC LIGATURE NOON WITH KHAH ISOLATED FORM
fc4e		ARABIC LIGATURE NOON WITH MEEM ISOLATED FORM
fc4f		ARABIC LIGATURE NOON WITH ALEF MAKSURA ISOLATED FORM
fc50		ARABIC LIGATURE NOON WITH YEH ISOLATED FORM
fc51		ARABIC LIGATURE HEH WITH JEEM ISOLATED FORM
fc52		ARABIC LIGATURE HEH WITH MEEM ISOLATED FORM
fc53		ARABIC LIGATURE HEH WITH ALEF MAKSURA ISOLATED FORM
fc54		ARABIC LIGATURE HEH WITH YEH ISOLATED FORM
fc55		ARABIC LIGATURE YEH WITH JEEM ISOLATED FORM
fc56		ARABIC LIGATURE YEH WITH HAH ISOLATED FORM
fc57		ARABIC LIGATURE YEH WITH KHAH ISOLATED FORM
fc58		ARABIC LIGATURE YEH WITH MEEM ISOLATED FORM
fc59		ARABIC LIGATURE YEH WITH ALEF MAKSURA ISOLATED FORM
fc5a		ARABIC LIGATURE YEH WITH YEH ISOLATED FORM
fc5b		ARABIC LIGATURE THAL WITH SUPERSCRIPT ALEF ISOLATED FORM
fc5c		ARABIC LIGATURE REH WITH SUPERSCRIPT ALEF ISOLATED FORM
fc5d		ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF ISOLATED FORM
fc5e		ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM
fc5f		ARABIC LIGATURE SHADDA WITH KASRATAN ISOLATED FORM
fc60		ARABIC LIGATURE SHADDA WITH FATHA ISOLATED FORM
fc61		ARABIC LIGATURE SHADDA WITH DAMMA ISOLATED FORM
fc62		ARABIC LIGATURE SHADDA WITH KASRA ISOLATED FORM
fc63		ARABIC LIGATURE SHADDA WITH SUPERSCRIPT ALEF ISOLATED FORM
fc64		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH REH FINAL FORM
fc65		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ZAIN FINAL FORM
fc66		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM FINAL FORM
fc67		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH NOON FINAL FORM
fc68		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM
fc69		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH FINAL FORM
fc6a		ARABIC LIGATURE BEH WITH REH FINAL FORM
fc6b		ARABIC LIGATURE BEH WITH ZAIN FINAL FORM
fc6c		ARABIC LIGATURE BEH WITH MEEM FINAL FORM
fc6d		ARABIC LIGATURE BEH WITH NOON FINAL FORM
fc6e		ARABIC LIGATURE BEH WITH ALEF MAKSURA FINAL FORM
fc6f		ARABIC LIGATURE BEH WITH YEH FINAL FORM
fc70		ARABIC LIGATURE TEH WITH REH FINAL FORM
fc71		ARABIC LIGATURE TEH WITH ZAIN FINAL FORM
fc72		ARABIC LIGATURE TEH WITH MEEM FINAL FORM
fc73		ARABIC LIGATURE TEH WITH NOON FINAL FORM
fc74		ARABIC LIGATURE TEH WITH ALEF MAKSURA FINAL FORM
fc75		ARABIC LIGATURE TEH WITH YEH FINAL FORM
fc76		ARABIC LIGATURE THEH WITH REH FINAL FORM
fc77		ARABIC LIGATURE THEH WITH ZAIN FINAL FORM
fc78		ARABIC LIGATURE THEH WITH MEEM FINAL FORM
fc79		ARABIC LIGATURE THEH WITH NOON FINAL FORM
fc7a		ARABIC LIGATURE THEH WITH ALEF MAKSURA FINAL FORM
fc7b		ARABIC LIGATURE THEH WITH YEH FINAL FORM
fc7c		ARABIC LIGATURE FEH WITH ALEF MAKSURA FINAL FORM
fc7d		ARABIC LIGATURE FEH WITH YEH FINAL FORM
fc7e		ARABIC LIGATURE QAF WITH ALEF MAKSURA FINAL FORM
fc7f		ARABIC LIGATURE QAF WITH YEH FINAL FORM
fc80		ARABIC LIGATURE KAF WITH ALEF FINAL FORM
fc81		ARABIC LIGATURE KAF WITH LAM FINAL FORM
fc82		ARABIC LIGATURE KAF WITH MEEM FINAL FORM
fc83		ARABIC LIGATURE KAF WITH ALEF MAKSURA FINAL FORM
fc84		ARABIC LIGATURE KAF WITH YEH FINAL FORM
fc85		ARABIC LIGATURE LAM WITH MEEM FINAL FORM
fc86		ARABIC LIGATURE LAM WITH ALEF MAKSURA FINAL FORM
fc87		ARABIC LIGATURE LAM WITH YEH FINAL FORM
fc88		ARABIC LIGATURE MEEM WITH ALEF FINAL FORM
fc89		ARABIC LIGATURE MEEM WITH MEEM FINAL FORM
fc8a		ARABIC LIGATURE NOON WITH REH FINAL FORM
fc8b		ARABIC LIGATURE NOON WITH ZAIN FINAL FORM
fc8c		ARABIC LIGATURE NOON WITH MEEM FINAL FORM
fc8d		ARABIC LIGATURE NOON WITH NOON FINAL FORM
fc8e		ARABIC LIGATURE NOON WITH ALEF MAKSURA FINAL FORM
fc8f		ARABIC LIGATURE NOON WITH YEH FINAL FORM
fc90		ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF FINAL FORM
fc91		ARABIC LIGATURE YEH WITH REH FINAL FORM
fc92		ARABIC LIGATURE YEH WITH ZAIN FINAL FORM
fc93		ARABIC LIGATURE YEH WITH MEEM FINAL FORM
fc94		ARABIC LIGATURE YEH WITH NOON FINAL FORM
fc95		ARABIC LIGATURE YEH WITH ALEF MAKSURA FINAL FORM
fc96		ARABIC LIGATURE YEH WITH YEH FINAL FORM
fc97		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM INITIAL FORM
fc98		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH INITIAL FORM
fc99		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH KHAH INITIAL FORM
fc9a		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM INITIAL FORM
fc9b		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH INITIAL FORM
fc9c		ARABIC LIGATURE BEH WITH JEEM INITIAL FORM
fc9d		ARABIC LIGATURE BEH WITH HAH INITIAL FORM
fc9e		ARABIC LIGATURE BEH WITH KHAH INITIAL FORM
fc9f		ARABIC LIGATURE BEH WITH MEEM INITIAL FORM
fca0		ARABIC LIGATURE BEH WITH HEH INITIAL FORM
fca1		ARABIC LIGATURE TEH WITH JEEM INITIAL FORM
fca2		ARABIC LIGATURE TEH WITH HAH INITIAL FORM
fca3		ARABIC LIGATURE TEH WITH KHAH INITIAL FORM
fca4		ARABIC LIGATURE TEH WITH MEEM INITIAL FORM
fca5		ARABIC LIGATURE TEH WITH HEH INITIAL FORM
fca6		ARABIC LIGATURE THEH WITH MEEM INITIAL FORM
fca7		ARABIC LIGATURE JEEM WITH HAH INITIAL FORM
fca8		ARABIC LIGATURE JEEM WITH MEEM INITIAL FORM
fca9		ARABIC LIGATURE HAH WITH JEEM INITIAL FORM
fcaa		ARABIC LIGATURE HAH WITH MEEM INITIAL FORM
fcab		ARABIC LIGATURE KHAH WITH JEEM INITIAL FORM
fcac		ARABIC LIGATURE KHAH WITH MEEM INITIAL FORM
fcad		ARABIC LIGATURE SEEN WITH JEEM INITIAL FORM
fcae		ARABIC LIGATURE SEEN WITH HAH INITIAL FORM
fcaf		ARABIC LIGATURE SEEN WITH KHAH INITIAL FORM
fcb0		ARABIC LIGATURE SEEN WITH MEEM INITIAL FORM
fcb1		ARABIC LIGATURE SAD WITH HAH INITIAL FORM
fcb2		ARABIC LIGATURE SAD WITH KHAH INITIAL FORM
fcb3		ARABIC LIGATURE SAD WITH MEEM INITIAL FORM
fcb4		ARABIC LIGATURE DAD WITH JEEM INITIAL FORM
fcb5		ARABIC LIGATURE DAD WITH HAH INITIAL FORM
fcb6		ARABIC LIGATURE DAD WITH KHAH INITIAL FORM
fcb7		ARABIC LIGATURE DAD WITH MEEM INITIAL FORM
fcb8		ARABIC LIGATURE TAH WITH HAH INITIAL FORM
fcb9		ARABIC LIGATURE ZAH WITH MEEM INITIAL FORM
fcba		ARABIC LIGATURE AIN WITH JEEM INITIAL FORM
fcbb		ARABIC LIGATURE AIN WITH MEEM INITIAL FORM
fcbc		ARABIC LIGATURE GHAIN WITH JEEM INITIAL FORM
fcbd		ARABIC LIGATURE GHAIN WITH MEEM INITIAL FORM
fcbe		ARABIC LIGATURE FEH WITH JEEM INITIAL FORM
fcbf		ARABIC LIGATURE FEH WITH HAH INITIAL FORM
fcc0		ARABIC LIGATURE FEH WITH KHAH INITIAL FORM
fcc1		ARABIC LIGATURE FEH WITH MEEM INITIAL FORM
fcc2		ARABIC LIGATURE QAF WITH HAH INITIAL FORM
fcc3		ARABIC LIGATURE QAF WITH MEEM INITIAL FORM
fcc4		ARABIC LIGATURE KAF WITH JEEM INITIAL FORM
fcc5		ARABIC LIGATURE KAF WITH HAH INITIAL FORM
fcc6		ARABIC LIGATURE KAF WITH KHAH INITIAL FORM
fcc7		ARABIC LIGATURE KAF WITH LAM INITIAL FORM
fcc8		ARABIC LIGATURE KAF WITH MEEM INITIAL FORM
fcc9		ARABIC LIGATURE LAM WITH JEEM INITIAL FORM
fcca		ARABIC LIGATURE LAM WITH HAH INITIAL FORM
fccb		ARABIC LIGATURE LAM WITH KHAH INITIAL FORM
fccc		ARABIC LIGATURE LAM WITH MEEM INITIAL FORM
fccd		ARABIC LIGATURE LAM WITH HEH INITIAL FORM
fcce		ARABIC LIGATURE MEEM WITH JEEM INITIAL FORM
fccf		ARABIC LIGATURE MEEM WITH HAH INITIAL FORM
fcd0		ARABIC LIGATURE MEEM WITH KHAH INITIAL FORM
fcd1		ARABIC LIGATURE MEEM WITH MEEM INITIAL FORM
fcd2		ARABIC LIGATURE NOON WITH JEEM INITIAL FORM
fcd3		ARABIC LIGATURE NOON WITH HAH INITIAL FORM
fcd4		ARABIC LIGATURE NOON WITH KHAH INITIAL FORM
fcd5		ARABIC LIGATURE NOON WITH MEEM INITIAL FORM
fcd6		ARABIC LIGATURE NOON WITH HEH INITIAL FORM
fcd7		ARABIC LIGATURE HEH WITH JEEM INITIAL FORM
fcd8		ARABIC LIGATURE HEH WITH MEEM INITIAL FORM
fcd9		ARABIC LIGATURE HEH WITH SUPERSCRIPT ALEF INITIAL FORM
fcda		ARABIC LIGATURE YEH WITH JEEM INITIAL FORM
fcdb		ARABIC LIGATURE YEH WITH HAH INITIAL FORM
fcdc		ARABIC LIGATURE YEH WITH KHAH INITIAL FORM
fcdd		ARABIC LIGATURE YEH WITH MEEM INITIAL FORM
fcde		ARABIC LIGATURE YEH WITH HEH INITIAL FORM
fcdf		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM MEDIAL FORM
fce0		ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH MEDIAL FORM
fce1		ARABIC LIGATURE BEH WITH MEEM MEDIAL FORM
fce2		ARABIC LIGATURE BEH WITH HEH MEDIAL FORM
fce3		ARABIC LIGATURE TEH WITH MEEM MEDIAL FORM
fce4		ARABIC LIGATURE TEH WITH HEH MEDIAL FORM
fce5		ARABIC LIGATURE THEH WITH MEEM MEDIAL FORM
fce6		ARABIC LIGATURE THEH WITH HEH MEDIAL FORM
fce7		ARABIC LIGATURE SEEN WITH MEEM MEDIAL FORM
fce8		ARABIC LIGATURE SEEN WITH HEH MEDIAL FORM
fce9		ARABIC LIGATURE SHEEN WITH MEEM MEDIAL FORM
fcea		ARABIC LIGATURE SHEEN WITH HEH MEDIAL FORM
fceb		ARABIC LIGATURE KAF WITH LAM MEDIAL FORM
fcec		ARABIC LIGATURE KAF WITH MEEM MEDIAL FORM
fced		ARABIC LIGATURE LAM WITH MEEM MEDIAL FORM
fcee		ARABIC LIGATURE NOON WITH MEEM MEDIAL FORM
fcef		ARABIC LIGATURE NOON WITH HEH MEDIAL FORM
fcf0		ARABIC LIGATURE YEH WITH MEEM MEDIAL FORM
fcf1		ARABIC LIGATURE YEH WITH HEH MEDIAL FORM
fcf2		ARABIC LIGATURE SHADDA WITH FATHA MEDIAL FORM
fcf3		ARABIC LIGATURE SHADDA WITH DAMMA MEDIAL FORM
fcf4		ARABIC LIGATURE SHADDA WITH KASRA MEDIAL FORM
fcf5		ARABIC LIGATURE TAH WITH ALEF MAKSURA ISOLATED FORM
fcf6		ARABIC LIGATURE TAH WITH YEH ISOLATED FORM
fcf7		ARABIC LIGATURE AIN WITH ALEF MAKSURA ISOLATED FORM
fcf8		ARABIC LIGATURE AIN WITH YEH ISOLATED FORM
fcf9		ARABIC LIGATURE GHAIN WITH ALEF MAKSURA ISOLATED FORM
fcfa		ARABIC LIGATURE GHAIN WITH YEH ISOLATED FORM
fcfb		ARABIC LIGATURE SEEN WITH ALEF MAKSURA ISOLATED FORM
fcfc		ARABIC LIGATURE SEEN WITH YEH ISOLATED FORM
fcfd		ARABIC LIGATURE SHEEN WITH ALEF MAKSURA ISOLATED FORM
fcfe		ARABIC LIGATURE SHEEN WITH YEH ISOLATED FORM
fcff		ARABIC LIGATURE HAH WITH ALEF MAKSURA ISOLATED FORM
fd00		ARABIC LIGATURE HAH WITH YEH ISOLATED FORM
fd01		ARABIC LIGATURE JEEM WITH ALEF MAKSURA ISOLATED FORM
fd02		ARABIC LIGATURE JEEM WITH YEH ISOLATED FORM
fd03		ARABIC LIGATURE KHAH WITH ALEF MAKSURA ISOLATED FORM
fd04		ARABIC LIGATURE KHAH WITH YEH ISOLATED FORM
fd05		ARABIC LIGATURE SAD WITH ALEF MAKSURA ISOLATED FORM
fd06		ARABIC LIGATURE SAD WITH YEH ISOLATED FORM
fd07		ARABIC LIGATURE DAD WITH ALEF MAKSURA ISOLATED FORM
fd08		ARABIC LIGATURE DAD WITH YEH ISOLATED FORM
fd09		ARABIC LIGATURE SHEEN WITH JEEM ISOLATED FORM
fd0a		ARABIC LIGATURE SHEEN WITH HAH ISOLATED FORM
fd0b		ARABIC LIGATURE SHEEN WITH KHAH ISOLATED FORM
fd0c		ARABIC LIGATURE SHEEN WITH MEEM ISOLATED FORM
fd0d		ARABIC LIGATURE SHEEN WITH REH ISOLATED FORM
fd0e		ARABIC LIGATURE SEEN WITH REH ISOLATED FORM
fd0f		ARABIC LIGATURE SAD WITH REH ISOLATED FORM
fd10		ARABIC LIGATURE DAD WITH REH ISOLATED FORM
fd11		ARABIC LIGATURE TAH WITH ALEF MAKSURA FINAL FORM
fd12		ARABIC LIGATURE TAH WITH YEH FINAL FORM
fd13		ARABIC LIGATURE AIN WITH ALEF MAKSURA FINAL FORM
fd14		ARABIC LIGATURE AIN WITH YEH FINAL FORM
fd15		ARABIC LIGATURE GHAIN WITH ALEF MAKSURA FINAL FORM
fd16		ARABIC LIGATURE GHAIN WITH YEH FINAL FORM
fd17		ARABIC LIGATURE SEEN WITH ALEF MAKSURA FINAL FORM
fd18		ARABIC LIGATURE SEEN WITH YEH FINAL FORM
fd19		ARABIC LIGATURE SHEEN WITH ALEF MAKSURA FINAL FORM
fd1a		ARABIC LIGATURE SHEEN WITH YEH FINAL FORM
fd1b		ARABIC LIGATURE HAH WITH ALEF MAKSURA FINAL FORM
fd1c		ARABIC LIGATURE HAH WITH YEH FINAL FORM
fd1d		ARABIC LIGATURE JEEM WITH ALEF MAKSURA FINAL FORM
fd1e		ARABIC LIGATURE JEEM WITH YEH FINAL FORM
fd1f		ARABIC LIGATURE KHAH WITH ALEF MAKSURA FINAL FORM
fd20		ARABIC LIGATURE KHAH WITH YEH FINAL FORM
fd21		ARABIC LIGATURE SAD WITH ALEF MAKSURA FINAL FORM
fd22		ARABIC LIGATURE SAD WITH YEH FINAL FORM
fd23		ARABIC LIGATURE DAD WITH ALEF MAKSURA FINAL FORM
fd24		ARABIC LIGATURE DAD WITH YEH FINAL FORM
fd25		ARABIC LIGATURE SHEEN WITH JEEM FINAL FORM
fd26		ARABIC LIGATURE SHEEN WITH HAH FINAL FORM
fd27		ARABIC LIGATURE SHEEN WITH KHAH FINAL FORM
fd28		ARABIC LIGATURE SHEEN WITH MEEM FINAL FORM
fd29		ARABIC LIGATURE SHEEN WITH REH FINAL FORM
fd2a		ARABIC LIGATURE SEEN WITH REH FINAL FORM
fd2b		ARABIC LIGATURE SAD WITH REH FINAL FORM
fd2c		ARABIC LIGATURE DAD WITH REH FINAL FORM
fd2d		ARABIC LIGATURE SHEEN WITH JEEM INITIAL FORM
fd2e		ARABIC LIGATURE SHEEN WITH HAH INITIAL FORM
fd2f		ARABIC LIGATURE SHEEN WITH KHAH INITIAL FORM
fd30		ARABIC LIGATURE SHEEN WITH MEEM INITIAL FORM
fd31		ARABIC LIGATURE SEEN WITH HEH INITIAL FORM
fd32		ARABIC LIGATURE SHEEN WITH HEH INITIAL FORM
fd33		ARABIC LIGATURE TAH WITH MEEM INITIAL FORM
fd34		ARABIC LIGATURE SEEN WITH JEEM MEDIAL FORM
fd35		ARABIC LIGATURE SEEN WITH HAH MEDIAL FORM
fd36		ARABIC LIGATURE SEEN WITH KHAH MEDIAL FORM
fd37		ARABIC LIGATURE SHEEN WITH JEEM MEDIAL FORM
fd38		ARABIC LIGATURE SHEEN WITH HAH MEDIAL FORM
fd39		ARABIC LIGATURE SHEEN WITH KHAH MEDIAL FORM
fd3a		ARABIC LIGATURE TAH WITH MEEM MEDIAL FORM
fd3b		ARABIC LIGATURE ZAH WITH MEEM MEDIAL FORM
fd3c		ARABIC LIGATURE ALEF WITH FATHATAN FINAL FORM
fd3d		ARABIC LIGATURE ALEF WITH FATHATAN ISOLATED FORM
fd3e		ORNATE LEFT PARENTHESIS
fd3f		ORNATE RIGHT PARENTHESIS
fd50		ARABIC LIGATURE TEH WITH JEEM WITH MEEM INITIAL FORM
fd51		ARABIC LIGATURE TEH WITH HAH WITH JEEM FINAL FORM
fd52		ARABIC LIGATURE TEH WITH HAH WITH JEEM INITIAL FORM
fd53		ARABIC LIGATURE TEH WITH HAH WITH MEEM INITIAL FORM
fd54		ARABIC LIGATURE TEH WITH KHAH WITH MEEM INITIAL FORM
fd55		ARABIC LIGATURE TEH WITH MEEM WITH JEEM INITIAL FORM
fd56		ARABIC LIGATURE TEH WITH MEEM WITH HAH INITIAL FORM
fd57		ARABIC LIGATURE TEH WITH MEEM WITH KHAH INITIAL FORM
fd58		ARABIC LIGATURE JEEM WITH MEEM WITH HAH FINAL FORM
fd59		ARABIC LIGATURE JEEM WITH MEEM WITH HAH INITIAL FORM
fd5a		ARABIC LIGATURE HAH WITH MEEM WITH YEH FINAL FORM
fd5b		ARABIC LIGATURE HAH WITH MEEM WITH ALEF MAKSURA FINAL FORM
fd5c		ARABIC LIGATURE SEEN WITH HAH WITH JEEM INITIAL FORM
fd5d		ARABIC LIGATURE SEEN WITH JEEM WITH HAH INITIAL FORM
fd5e		ARABIC LIGATURE SEEN WITH JEEM WITH ALEF MAKSURA FINAL FORM
fd5f		ARABIC LIGATURE SEEN WITH MEEM WITH HAH FINAL FORM
fd60		ARABIC LIGATURE SEEN WITH MEEM WITH HAH INITIAL FORM
fd61		ARABIC LIGATURE SEEN WITH MEEM WITH JEEM INITIAL FORM
fd62		ARABIC LIGATURE SEEN WITH MEEM WITH MEEM FINAL FORM
fd63		ARABIC LIGATURE SEEN WITH MEEM WITH MEEM INITIAL FORM
fd64		ARABIC LIGATURE SAD WITH HAH WITH HAH FINAL FORM
fd65		ARABIC LIGATURE SAD WITH HAH WITH HAH INITIAL FORM
fd66		ARABIC LIGATURE SAD WITH MEEM WITH MEEM FINAL FORM
fd67		ARABIC LIGATURE SHEEN WITH HAH WITH MEEM FINAL FORM
fd68		ARABIC LIGATURE SHEEN WITH HAH WITH MEEM INITIAL FORM
fd69		ARABIC LIGATURE SHEEN WITH JEEM WITH YEH FINAL FORM
fd6a		ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH FINAL FORM
fd6b		ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH INITIAL FORM
fd6c		ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM FINAL FORM
fd6d		ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM INITIAL FORM
fd6e		ARABIC LIGATURE DAD WITH HAH WITH ALEF MAKSURA FINAL FORM
fd6f		ARABIC LIGATURE DAD WITH KHAH WITH MEEM FINAL FORM
fd70		ARABIC LIGATURE DAD WITH KHAH WITH MEEM INITIAL FORM
fd71		ARABIC LIGATURE TAH WITH MEEM WITH HAH FINAL FORM
fd72		ARABIC LIGATURE TAH WITH MEEM WITH HAH INITIAL FORM
fd73		ARABIC LIGATURE TAH WITH MEEM WITH MEEM INITIAL FORM
fd74		ARABIC LIGATURE TAH WITH MEEM WITH YEH FINAL FORM
fd75		ARABIC LIGATURE AIN WITH JEEM WITH MEEM FINAL FORM
fd76		ARABIC LIGATURE AIN WITH MEEM WITH MEEM FINAL FORM
fd77		ARABIC LIGATURE AIN WITH MEEM WITH MEEM INITIAL FORM
fd78		ARABIC LIGATURE AIN WITH MEEM WITH ALEF MAKSURA FINAL FORM
fd79		ARABIC LIGATURE GHAIN WITH MEEM WITH MEEM FINAL FORM
fd7a		ARABIC LIGATURE GHAIN WITH MEEM WITH YEH FINAL FORM
fd7b		ARABIC LIGATURE GHAIN WITH MEEM WITH ALEF MAKSURA FINAL FORM
fd7c		ARABIC LIGATURE FEH WITH KHAH WITH MEEM FINAL FORM
fd7d		ARABIC LIGATURE FEH WITH KHAH WITH MEEM INITIAL FORM
fd7e		ARABIC LIGATURE QAF WITH MEEM WITH HAH FINAL FORM
fd7f		ARABIC LIGATURE QAF WITH MEEM WITH MEEM FINAL FORM
fd80		ARABIC LIGATURE LAM WITH HAH WITH MEEM FINAL FORM
fd81		ARABIC LIGATURE LAM WITH HAH WITH YEH FINAL FORM
fd82		ARABIC LIGATURE LAM WITH HAH WITH ALEF MAKSURA FINAL FORM
fd83		ARABIC LIGATURE LAM WITH JEEM WITH JEEM INITIAL FORM
fd84		ARABIC LIGATURE LAM WITH JEEM WITH JEEM FINAL FORM
fd85		ARABIC LIGATURE LAM WITH KHAH WITH MEEM FINAL FORM
fd86		ARABIC LIGATURE LAM WITH KHAH WITH MEEM INITIAL FORM
fd87		ARABIC LIGATURE LAM WITH MEEM WITH HAH FINAL FORM
fd88		ARABIC LIGATURE LAM WITH MEEM WITH HAH INITIAL FORM
fd89		ARABIC LIGATURE MEEM WITH HAH WITH JEEM INITIAL FORM
fd8a		ARABIC LIGATURE MEEM WITH HAH WITH MEEM INITIAL FORM
fd8b		ARABIC LIGATURE MEEM WITH HAH WITH YEH FINAL FORM
fd8c		ARABIC LIGATURE MEEM WITH JEEM WITH HAH INITIAL FORM
fd8d		ARABIC LIGATURE MEEM WITH JEEM WITH MEEM INITIAL FORM
fd8e		ARABIC LIGATURE MEEM WITH KHAH WITH JEEM INITIAL FORM
fd8f		ARABIC LIGATURE MEEM WITH KHAH WITH MEEM INITIAL FORM
fd92		ARABIC LIGATURE MEEM WITH JEEM WITH KHAH INITIAL FORM
fd93		ARABIC LIGATURE HEH WITH MEEM WITH JEEM INITIAL FORM
fd94		ARABIC LIGATURE HEH WITH MEEM WITH MEEM INITIAL FORM
fd95		ARABIC LIGATURE NOON WITH HAH WITH MEEM INITIAL FORM
fd96		ARABIC LIGATURE NOON WITH HAH WITH ALEF MAKSURA FINAL FORM
fd97		ARABIC LIGATURE NOON WITH JEEM WITH MEEM FINAL FORM
fd98		ARABIC LIGATURE NOON WITH JEEM WITH MEEM INITIAL FORM
fd99		ARABIC LIGATURE NOON WITH JEEM WITH ALEF MAKSURA FINAL FORM
fd9a		ARABIC LIGATURE NOON WITH MEEM WITH YEH FINAL FORM
fd9b		ARABIC LIGATURE NOON WITH MEEM WITH ALEF MAKSURA FINAL FORM
fd9c		ARABIC LIGATURE YEH WITH MEEM WITH MEEM FINAL FORM
fd9d		ARABIC LIGATURE YEH WITH MEEM WITH MEEM INITIAL FORM
fd9e		ARABIC LIGATURE BEH WITH KHAH WITH YEH FINAL FORM
fd9f		ARABIC LIGATURE TEH WITH JEEM WITH YEH FINAL FORM
fda0		ARABIC LIGATURE TEH WITH JEEM WITH ALEF MAKSURA FINAL FORM
fda1		ARABIC LIGATURE TEH WITH KHAH WITH YEH FINAL FORM
fda2		ARABIC LIGATURE TEH WITH KHAH WITH ALEF MAKSURA FINAL FORM
fda3		ARABIC LIGATURE TEH WITH MEEM WITH YEH FINAL FORM
fda4		ARABIC LIGATURE TEH WITH MEEM WITH ALEF MAKSURA FINAL FORM
fda5		ARABIC LIGATURE JEEM WITH MEEM WITH YEH FINAL FORM
fda6		ARABIC LIGATURE JEEM WITH HAH WITH ALEF MAKSURA FINAL FORM
fda7		ARABIC LIGATURE JEEM WITH MEEM WITH ALEF MAKSURA FINAL FORM
fda8		ARABIC LIGATURE SEEN WITH KHAH WITH ALEF MAKSURA FINAL FORM
fda9		ARABIC LIGATURE SAD WITH HAH WITH YEH FINAL FORM
fdaa		ARABIC LIGATURE SHEEN WITH HAH WITH YEH FINAL FORM
fdab		ARABIC LIGATURE DAD WITH HAH WITH YEH FINAL FORM
fdac		ARABIC LIGATURE LAM WITH JEEM WITH YEH FINAL FORM
fdad		ARABIC LIGATURE LAM WITH MEEM WITH YEH FINAL FORM
fdae		ARABIC LIGATURE YEH WITH HAH WITH YEH FINAL FORM
fdaf		ARABIC LIGATURE YEH WITH JEEM WITH YEH FINAL FORM
fdb0		ARABIC LIGATURE YEH WITH MEEM WITH YEH FINAL FORM
fdb1		ARABIC LIGATURE MEEM WITH MEEM WITH YEH FINAL FORM
fdb2		ARABIC LIGATURE QAF WITH MEEM WITH YEH FINAL FORM
fdb3		ARABIC LIGATURE NOON WITH HAH WITH YEH FINAL FORM
fdb4		ARABIC LIGATURE QAF WITH MEEM WITH HAH INITIAL FORM
fdb5		ARABIC LIGATURE LAM WITH HAH WITH MEEM INITIAL FORM
fdb6		ARABIC LIGATURE AIN WITH MEEM WITH YEH FINAL FORM
fdb7		ARABIC LIGATURE KAF WITH MEEM WITH YEH FINAL FORM
fdb8		ARABIC LIGATURE NOON WITH JEEM WITH HAH INITIAL FORM
fdb9		ARABIC LIGATURE MEEM WITH KHAH WITH YEH FINAL FORM
fdba		ARABIC LIGATURE LAM WITH JEEM WITH MEEM INITIAL FORM
fdbb		ARABIC LIGATURE KAF WITH MEEM WITH MEEM FINAL FORM
fdbc		ARABIC LIGATURE LAM WITH JEEM WITH MEEM FINAL FORM
fdbd		ARABIC LIGATURE NOON WITH JEEM WITH HAH FINAL FORM
fdbe		ARABIC LIGATURE JEEM WITH HAH WITH YEH FINAL FORM
fdbf		ARABIC LIGATURE HAH WITH JEEM WITH YEH FINAL FORM
fdc0		ARABIC LIGATURE MEEM WITH JEEM WITH YEH FINAL FORM
fdc1		ARABIC LIGATURE FEH WITH MEEM WITH YEH FINAL FORM
fdc2		ARABIC LIGATURE BEH WITH HAH WITH YEH FINAL FORM
fdc3		ARABIC LIGATURE KAF WITH MEEM WITH MEEM INITIAL FORM
fdc4		ARABIC LIGATURE AIN WITH JEEM WITH MEEM INITIAL FORM
fdc5		ARABIC LIGATURE SAD WITH MEEM WITH MEEM INITIAL FORM
fdc6		ARABIC LIGATURE SEEN WITH KHAH WITH YEH FINAL FORM
fdc7		ARABIC LIGATURE NOON WITH JEEM WITH YEH FINAL FORM
fdf0		ARABIC LIGATURE SALLA USED AS KORANIC STOP SIGN ISOLATED FORM
fdf1		ARABIC LIGATURE QALA USED AS KORANIC STOP SIGN ISOLATED FORM
fdf2		ARABIC LIGATURE ALLAH ISOLATED FORM
fdf3		ARABIC LIGATURE AKBAR ISOLATED FORM
fdf4		ARABIC LIGATURE MOHAMMAD ISOLATED FORM
fdf5		ARABIC LIGATURE SALAM ISOLATED FORM
fdf6		ARABIC LIGATURE RASOUL ISOLATED FORM
fdf7		ARABIC LIGATURE ALAYHE ISOLATED FORM
fdf8		ARABIC LIGATURE WASALLAM ISOLATED FORM
fdf9		ARABIC LIGATURE SALLA ISOLATED FORM
fdfa		ARABIC LIGATURE SALLALLAHOU ALAYHE WASALLAM
fdfb		ARABIC LIGATURE JALLAJALALOUHOU
fe20		COMBINING LIGATURE LEFT HALF
fe21		COMBINING LIGATURE RIGHT HALF
fe22		COMBINING DOUBLE TILDE LEFT HALF
fe23		COMBINING DOUBLE TILDE RIGHT HALF
fe30		PRESENTATION FORM FOR VERTICAL TWO DOT LEADER
fe31		PRESENTATION FORM FOR VERTICAL EM DASH
fe32		PRESENTATION FORM FOR VERTICAL EN DASH
fe33		PRESENTATION FORM FOR VERTICAL LOW LINE
fe34		PRESENTATION FORM FOR VERTICAL WAVY LOW LINE
fe35		PRESENTATION FORM FOR VERTICAL LEFT PARENTHESIS
fe36		PRESENTATION FORM FOR VERTICAL RIGHT PARENTHESIS
fe37		PRESENTATION FORM FOR VERTICAL LEFT CURLY BRACKET
fe38		PRESENTATION FORM FOR VERTICAL RIGHT CURLY BRACKET
fe39		PRESENTATION FORM FOR VERTICAL LEFT TORTOISE SHELL BRACKET
fe3a		PRESENTATION FORM FOR VERTICAL RIGHT TORTOISE SHELL BRACKET
fe3b		PRESENTATION FORM FOR VERTICAL LEFT BLACK LENTICULAR BRACKET
fe3c		PRESENTATION FORM FOR VERTICAL RIGHT BLACK LENTICULAR BRACKET
fe3d		PRESENTATION FORM FOR VERTICAL LEFT DOUBLE ANGLE BRACKET
fe3e		PRESENTATION FORM FOR VERTICAL RIGHT DOUBLE ANGLE BRACKET
fe3f		PRESENTATION FORM FOR VERTICAL LEFT ANGLE BRACKET
fe40		PRESENTATION FORM FOR VERTICAL RIGHT ANGLE BRACKET
fe41		PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET
fe42		PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET
fe43		PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET
fe44		PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET
fe49		DASHED OVERLINE
fe4a		CENTRELINE OVERLINE
fe4b		WAVY OVERLINE
fe4c		DOUBLE WAVY OVERLINE
fe4d		DASHED LOW LINE
fe4e		CENTRELINE LOW LINE
fe4f		WAVY LOW LINE
fe50		SMALL COMMA
fe51		SMALL IDEOGRAPHIC COMMA
fe52		SMALL FULL STOP
fe54		SMALL SEMICOLON
fe55		SMALL COLON
fe56		SMALL QUESTION MARK
fe57		SMALL EXCLAMATION MARK
fe58		SMALL EM DASH
fe59		SMALL LEFT PARENTHESIS
fe5a		SMALL RIGHT PARENTHESIS
fe5b		SMALL LEFT CURLY BRACKET
fe5c		SMALL RIGHT CURLY BRACKET
fe5d		SMALL LEFT TORTOISE SHELL BRACKET
fe5e		SMALL RIGHT TORTOISE SHELL BRACKET
fe5f		SMALL NUMBER SIGN
fe60		SMALL AMPERSAND
fe61		SMALL ASTERISK
fe62		SMALL PLUS SIGN
fe63		SMALL HYPHEN-MINUS
fe64		SMALL LESS-THAN SIGN
fe65		SMALL GREATER-THAN SIGN
fe66		SMALL EQUALS SIGN
fe68		SMALL REVERSE SOLIDUS
fe69		SMALL DOLLAR SIGN
fe6a		SMALL PERCENT SIGN
fe6b		SMALL COMMERCIAL AT
fe70		ARABIC FATHATAN ISOLATED FORM
fe71		ARABIC TATWEEL WITH FATHATAN ABOVE
fe72		ARABIC DAMMATAN ISOLATED FORM
fe74		ARABIC KASRATAN ISOLATED FORM
fe76		ARABIC FATHA ISOLATED FORM
fe77		ARABIC FATHA MEDIAL FORM
fe78		ARABIC DAMMA ISOLATED FORM
fe79		ARABIC DAMMA MEDIAL FORM
fe7a		ARABIC KASRA ISOLATED FORM
fe7b		ARABIC KASRA MEDIAL FORM
fe7c		ARABIC SHADDA ISOLATED FORM
fe7d		ARABIC SHADDA MEDIAL FORM
fe7e		ARABIC SUKUN ISOLATED FORM
fe7f		ARABIC SUKUN MEDIAL FORM
fe80		ARABIC LETTER HAMZA ISOLATED FORM
fe81		ARABIC LETTER ALEF WITH MADDA ABOVE ISOLATED FORM
fe82		ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM
fe83		ARABIC LETTER ALEF WITH HAMZA ABOVE ISOLATED FORM
fe84		ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM
fe85		ARABIC LETTER WAW WITH HAMZA ABOVE ISOLATED FORM
fe86		ARABIC LETTER WAW WITH HAMZA ABOVE FINAL FORM
fe87		ARABIC LETTER ALEF WITH HAMZA BELOW ISOLATED FORM
fe88		ARABIC LETTER ALEF WITH HAMZA BELOW FINAL FORM
fe89		ARABIC LETTER YEH WITH HAMZA ABOVE ISOLATED FORM
fe8a		ARABIC LETTER YEH WITH HAMZA ABOVE FINAL FORM
fe8b		ARABIC LETTER YEH WITH HAMZA ABOVE INITIAL FORM
fe8c		ARABIC LETTER YEH WITH HAMZA ABOVE MEDIAL FORM
fe8d		ARABIC LETTER ALEF ISOLATED FORM
fe8e		ARABIC LETTER ALEF FINAL FORM
fe8f		ARABIC LETTER BEH ISOLATED FORM
fe90		ARABIC LETTER BEH FINAL FORM
fe91		ARABIC LETTER BEH INITIAL FORM
fe92		ARABIC LETTER BEH MEDIAL FORM
fe93		ARABIC LETTER TEH MARBUTA ISOLATED FORM
fe94		ARABIC LETTER TEH MARBUTA FINAL FORM
fe95		ARABIC LETTER TEH ISOLATED FORM
fe96		ARABIC LETTER TEH FINAL FORM
fe97		ARABIC LETTER TEH INITIAL FORM
fe98		ARABIC LETTER TEH MEDIAL FORM
fe99		ARABIC LETTER THEH ISOLATED FORM
fe9a		ARABIC LETTER THEH FINAL FORM
fe9b		ARABIC LETTER THEH INITIAL FORM
fe9c		ARABIC LETTER THEH MEDIAL FORM
fe9d		ARABIC LETTER JEEM ISOLATED FORM
fe9e		ARABIC LETTER JEEM FINAL FORM
fe9f		ARABIC LETTER JEEM INITIAL FORM
fea0		ARABIC LETTER JEEM MEDIAL FORM
fea1		ARABIC LETTER HAH ISOLATED FORM
fea2		ARABIC LETTER HAH FINAL FORM
fea3		ARABIC LETTER HAH INITIAL FORM
fea4		ARABIC LETTER HAH MEDIAL FORM
fea5		ARABIC LETTER KHAH ISOLATED FORM
fea6		ARABIC LETTER KHAH FINAL FORM
fea7		ARABIC LETTER KHAH INITIAL FORM
fea8		ARABIC LETTER KHAH MEDIAL FORM
fea9		ARABIC LETTER DAL ISOLATED FORM
feaa		ARABIC LETTER DAL FINAL FORM
feab		ARABIC LETTER THAL ISOLATED FORM
feac		ARABIC LETTER THAL FINAL FORM
fead		ARABIC LETTER REH ISOLATED FORM
feae		ARABIC LETTER REH FINAL FORM
feaf		ARABIC LETTER ZAIN ISOLATED FORM
feb0		ARABIC LETTER ZAIN FINAL FORM
feb1		ARABIC LETTER SEEN ISOLATED FORM
feb2		ARABIC LETTER SEEN FINAL FORM
feb3		ARABIC LETTER SEEN INITIAL FORM
feb4		ARABIC LETTER SEEN MEDIAL FORM
feb5		ARABIC LETTER SHEEN ISOLATED FORM
feb6		ARABIC LETTER SHEEN FINAL FORM
feb7		ARABIC LETTER SHEEN INITIAL FORM
feb8		ARABIC LETTER SHEEN MEDIAL FORM
feb9		ARABIC LETTER SAD ISOLATED FORM
feba		ARABIC LETTER SAD FINAL FORM
febb		ARABIC LETTER SAD INITIAL FORM
febc		ARABIC LETTER SAD MEDIAL FORM
febd		ARABIC LETTER DAD ISOLATED FORM
febe		ARABIC LETTER DAD FINAL FORM
febf		ARABIC LETTER DAD INITIAL FORM
fec0		ARABIC LETTER DAD MEDIAL FORM
fec1		ARABIC LETTER TAH ISOLATED FORM
fec2		ARABIC LETTER TAH FINAL FORM
fec3		ARABIC LETTER TAH INITIAL FORM
fec4		ARABIC LETTER TAH MEDIAL FORM
fec5		ARABIC LETTER ZAH ISOLATED FORM
fec6		ARABIC LETTER ZAH FINAL FORM
fec7		ARABIC LETTER ZAH INITIAL FORM
fec8		ARABIC LETTER ZAH MEDIAL FORM
fec9		ARABIC LETTER AIN ISOLATED FORM
feca		ARABIC LETTER AIN FINAL FORM
fecb		ARABIC LETTER AIN INITIAL FORM
fecc		ARABIC LETTER AIN MEDIAL FORM
fecd		ARABIC LETTER GHAIN ISOLATED FORM
fece		ARABIC LETTER GHAIN FINAL FORM
fecf		ARABIC LETTER GHAIN INITIAL FORM
fed0		ARABIC LETTER GHAIN MEDIAL FORM
fed1		ARABIC LETTER FEH ISOLATED FORM
fed2		ARABIC LETTER FEH FINAL FORM
fed3		ARABIC LETTER FEH INITIAL FORM
fed4		ARABIC LETTER FEH MEDIAL FORM
fed5		ARABIC LETTER QAF ISOLATED FORM
fed6		ARABIC LETTER QAF FINAL FORM
fed7		ARABIC LETTER QAF INITIAL FORM
fed8		ARABIC LETTER QAF MEDIAL FORM
fed9		ARABIC LETTER KAF ISOLATED FORM
feda		ARABIC LETTER KAF FINAL FORM
fedb		ARABIC LETTER KAF INITIAL FORM
fedc		ARABIC LETTER KAF MEDIAL FORM
fedd		ARABIC LETTER LAM ISOLATED FORM
fede		ARABIC LETTER LAM FINAL FORM
fedf		ARABIC LETTER LAM INITIAL FORM
fee0		ARABIC LETTER LAM MEDIAL FORM
fee1		ARABIC LETTER MEEM ISOLATED FORM
fee2		ARABIC LETTER MEEM FINAL FORM
fee3		ARABIC LETTER MEEM INITIAL FORM
fee4		ARABIC LETTER MEEM MEDIAL FORM
fee5		ARABIC LETTER NOON ISOLATED FORM
fee6		ARABIC LETTER NOON FINAL FORM
fee7		ARABIC LETTER NOON INITIAL FORM
fee8		ARABIC LETTER NOON MEDIAL FORM
fee9		ARABIC LETTER HEH ISOLATED FORM
feea		ARABIC LETTER HEH FINAL FORM
feeb		ARABIC LETTER HEH INITIAL FORM
feec		ARABIC LETTER HEH MEDIAL FORM
feed		ARABIC LETTER WAW ISOLATED FORM
feee		ARABIC LETTER WAW FINAL FORM
feef		ARABIC LETTER ALEF MAKSURA ISOLATED FORM
fef0		ARABIC LETTER ALEF MAKSURA FINAL FORM
fef1		ARABIC LETTER YEH ISOLATED FORM
fef2		ARABIC LETTER YEH FINAL FORM
fef3		ARABIC LETTER YEH INITIAL FORM
fef4		ARABIC LETTER YEH MEDIAL FORM
fef5		ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE ISOLATED FORM
fef6		ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE FINAL FORM
fef7		ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE ISOLATED FORM
fef8		ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE FINAL FORM
fef9		ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW ISOLATED FORM
fefa		ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW FINAL FORM
fefb		ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM
fefc		ARABIC LIGATURE LAM WITH ALEF FINAL FORM
feff		ZERO WIDTH NO-BREAK SPACE
ff01		FULLWIDTH EXCLAMATION MARK
ff02		FULLWIDTH QUOTATION MARK
ff03		FULLWIDTH NUMBER SIGN
ff04		FULLWIDTH DOLLAR SIGN
ff05		FULLWIDTH PERCENT SIGN
ff06		FULLWIDTH AMPERSAND
ff07		FULLWIDTH APOSTROPHE
ff08		FULLWIDTH LEFT PARENTHESIS
ff09		FULLWIDTH RIGHT PARENTHESIS
ff0a		FULLWIDTH ASTERISK
ff0b		FULLWIDTH PLUS SIGN
ff0c		FULLWIDTH COMMA
ff0d		FULLWIDTH HYPHEN-MINUS
ff0e		FULLWIDTH FULL STOP
ff0f		FULLWIDTH SOLIDUS
ff10		FULLWIDTH DIGIT ZERO
ff11		FULLWIDTH DIGIT ONE
ff12		FULLWIDTH DIGIT TWO
ff13		FULLWIDTH DIGIT THREE
ff14		FULLWIDTH DIGIT FOUR
ff15		FULLWIDTH DIGIT FIVE
ff16		FULLWIDTH DIGIT SIX
ff17		FULLWIDTH DIGIT SEVEN
ff18		FULLWIDTH DIGIT EIGHT
ff19		FULLWIDTH DIGIT NINE
ff1a		FULLWIDTH COLON
ff1b		FULLWIDTH SEMICOLON
ff1c		FULLWIDTH LESS-THAN SIGN
ff1d		FULLWIDTH EQUALS SIGN
ff1e		FULLWIDTH GREATER-THAN SIGN
ff1f		FULLWIDTH QUESTION MARK
ff20		FULLWIDTH COMMERCIAL AT
ff21		FULLWIDTH LATIN CAPITAL LETTER A
ff22		FULLWIDTH LATIN CAPITAL LETTER B
ff23		FULLWIDTH LATIN CAPITAL LETTER C
ff24		FULLWIDTH LATIN CAPITAL LETTER D
ff25		FULLWIDTH LATIN CAPITAL LETTER E
ff26		FULLWIDTH LATIN CAPITAL LETTER F
ff27		FULLWIDTH LATIN CAPITAL LETTER G
ff28		FULLWIDTH LATIN CAPITAL LETTER H
ff29		FULLWIDTH LATIN CAPITAL LETTER I
ff2a		FULLWIDTH LATIN CAPITAL LETTER J
ff2b		FULLWIDTH LATIN CAPITAL LETTER K
ff2c		FULLWIDTH LATIN CAPITAL LETTER L
ff2d		FULLWIDTH LATIN CAPITAL LETTER M
ff2e		FULLWIDTH LATIN CAPITAL LETTER N
ff2f		FULLWIDTH LATIN CAPITAL LETTER O
ff30		FULLWIDTH LATIN CAPITAL LETTER P
ff31		FULLWIDTH LATIN CAPITAL LETTER Q
ff32		FULLWIDTH LATIN CAPITAL LETTER R
ff33		FULLWIDTH LATIN CAPITAL LETTER S
ff34		FULLWIDTH LATIN CAPITAL LETTER T
ff35		FULLWIDTH LATIN CAPITAL LETTER U
ff36		FULLWIDTH LATIN CAPITAL LETTER V
ff37		FULLWIDTH LATIN CAPITAL LETTER W
ff38		FULLWIDTH LATIN CAPITAL LETTER X
ff39		FULLWIDTH LATIN CAPITAL LETTER Y
ff3a		FULLWIDTH LATIN CAPITAL LETTER Z
ff3b		FULLWIDTH LEFT SQUARE BRACKET
ff3c		FULLWIDTH REVERSE SOLIDUS
ff3d		FULLWIDTH RIGHT SQUARE BRACKET
ff3e		FULLWIDTH CIRCUMFLEX ACCENT
ff3f		FULLWIDTH LOW LINE
ff40		FULLWIDTH GRAVE ACCENT
ff41		FULLWIDTH LATIN SMALL LETTER A
ff42		FULLWIDTH LATIN SMALL LETTER B
ff43		FULLWIDTH LATIN SMALL LETTER C
ff44		FULLWIDTH LATIN SMALL LETTER D
ff45		FULLWIDTH LATIN SMALL LETTER E
ff46		FULLWIDTH LATIN SMALL LETTER F
ff47		FULLWIDTH LATIN SMALL LETTER G
ff48		FULLWIDTH LATIN SMALL LETTER H
ff49		FULLWIDTH LATIN SMALL LETTER I
ff4a		FULLWIDTH LATIN SMALL LETTER J
ff4b		FULLWIDTH LATIN SMALL LETTER K
ff4c		FULLWIDTH LATIN SMALL LETTER L
ff4d		FULLWIDTH LATIN SMALL LETTER M
ff4e		FULLWIDTH LATIN SMALL LETTER N
ff4f		FULLWIDTH LATIN SMALL LETTER O
ff50		FULLWIDTH LATIN SMALL LETTER P
ff51		FULLWIDTH LATIN SMALL LETTER Q
ff52		FULLWIDTH LATIN SMALL LETTER R
ff53		FULLWIDTH LATIN SMALL LETTER S
ff54		FULLWIDTH LATIN SMALL LETTER T
ff55		FULLWIDTH LATIN SMALL LETTER U
ff56		FULLWIDTH LATIN SMALL LETTER V
ff57		FULLWIDTH LATIN SMALL LETTER W
ff58		FULLWIDTH LATIN SMALL LETTER X
ff59		FULLWIDTH LATIN SMALL LETTER Y
ff5a		FULLWIDTH LATIN SMALL LETTER Z
ff5b		FULLWIDTH LEFT CURLY BRACKET
ff5c		FULLWIDTH VERTICAL LINE
ff5d		FULLWIDTH RIGHT CURLY BRACKET
ff5e		FULLWIDTH TILDE
ff61		HALFWIDTH IDEOGRAPHIC FULL STOP
ff62		HALFWIDTH LEFT CORNER BRACKET
ff63		HALFWIDTH RIGHT CORNER BRACKET
ff64		HALFWIDTH IDEOGRAPHIC COMMA
ff65		HALFWIDTH KATAKANA MIDDLE DOT
ff66		HALFWIDTH KATAKANA LETTER WO
ff67		HALFWIDTH KATAKANA LETTER SMALL A
ff68		HALFWIDTH KATAKANA LETTER SMALL I
ff69		HALFWIDTH KATAKANA LETTER SMALL U
ff6a		HALFWIDTH KATAKANA LETTER SMALL E
ff6b		HALFWIDTH KATAKANA LETTER SMALL O
ff6c		HALFWIDTH KATAKANA LETTER SMALL YA
ff6d		HALFWIDTH KATAKANA LETTER SMALL YU
ff6e		HALFWIDTH KATAKANA LETTER SMALL YO
ff6f		HALFWIDTH KATAKANA LETTER SMALL TU
ff70		HALFWIDTH KATAKANA-HIRAGANA PROLONGED SOUND MARK
ff71		HALFWIDTH KATAKANA LETTER A
ff72		HALFWIDTH KATAKANA LETTER I
ff73		HALFWIDTH KATAKANA LETTER U
ff74		HALFWIDTH KATAKANA LETTER E
ff75		HALFWIDTH KATAKANA LETTER O
ff76		HALFWIDTH KATAKANA LETTER KA
ff77		HALFWIDTH KATAKANA LETTER KI
ff78		HALFWIDTH KATAKANA LETTER KU
ff79		HALFWIDTH KATAKANA LETTER KE
ff7a		HALFWIDTH KATAKANA LETTER KO
ff7b		HALFWIDTH KATAKANA LETTER SA
ff7c		HALFWIDTH KATAKANA LETTER SI
ff7d		HALFWIDTH KATAKANA LETTER SU
ff7e		HALFWIDTH KATAKANA LETTER SE
ff7f		HALFWIDTH KATAKANA LETTER SO
ff80		HALFWIDTH KATAKANA LETTER TA
ff81		HALFWIDTH KATAKANA LETTER TI
ff82		HALFWIDTH KATAKANA LETTER TU
ff83		HALFWIDTH KATAKANA LETTER TE
ff84		HALFWIDTH KATAKANA LETTER TO
ff85		HALFWIDTH KATAKANA LETTER NA
ff86		HALFWIDTH KATAKANA LETTER NI
ff87		HALFWIDTH KATAKANA LETTER NU
ff88		HALFWIDTH KATAKANA LETTER NE
ff89		HALFWIDTH KATAKANA LETTER NO
ff8a		HALFWIDTH KATAKANA LETTER HA
ff8b		HALFWIDTH KATAKANA LETTER HI
ff8c		HALFWIDTH KATAKANA LETTER HU
ff8d		HALFWIDTH KATAKANA LETTER HE
ff8e		HALFWIDTH KATAKANA LETTER HO
ff8f		HALFWIDTH KATAKANA LETTER MA
ff90		HALFWIDTH KATAKANA LETTER MI
ff91		HALFWIDTH KATAKANA LETTER MU
ff92		HALFWIDTH KATAKANA LETTER ME
ff93		HALFWIDTH KATAKANA LETTER MO
ff94		HALFWIDTH KATAKANA LETTER YA
ff95		HALFWIDTH KATAKANA LETTER YU
ff96		HALFWIDTH KATAKANA LETTER YO
ff97		HALFWIDTH KATAKANA LETTER RA
ff98		HALFWIDTH KATAKANA LETTER RI
ff99		HALFWIDTH KATAKANA LETTER RU
ff9a		HALFWIDTH KATAKANA LETTER RE
ff9b		HALFWIDTH KATAKANA LETTER RO
ff9c		HALFWIDTH KATAKANA LETTER WA
ff9d		HALFWIDTH KATAKANA LETTER N
ff9e		HALFWIDTH KATAKANA VOICED SOUND MARK
ff9f		HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK
ffa0		HALFWIDTH HANGUL FILLER
ffa1		HALFWIDTH HANGUL LETTER KIYEOK
ffa2		HALFWIDTH HANGUL LETTER SSANGKIYEOK
ffa3		HALFWIDTH HANGUL LETTER KIYEOK-SIOS
ffa4		HALFWIDTH HANGUL LETTER NIEUN
ffa5		HALFWIDTH HANGUL LETTER NIEUN-CIEUC
ffa6		HALFWIDTH HANGUL LETTER NIEUN-HIEUH
ffa7		HALFWIDTH HANGUL LETTER TIKEUT
ffa8		HALFWIDTH HANGUL LETTER SSANGTIKEUT
ffa9		HALFWIDTH HANGUL LETTER RIEUL
ffaa		HALFWIDTH HANGUL LETTER RIEUL-KIYEOK
ffab		HALFWIDTH HANGUL LETTER RIEUL-MIEUM
ffac		HALFWIDTH HANGUL LETTER RIEUL-PIEUP
ffad		HALFWIDTH HANGUL LETTER RIEUL-SIOS
ffae		HALFWIDTH HANGUL LETTER RIEUL-THIEUTH
ffaf		HALFWIDTH HANGUL LETTER RIEUL-PHIEUPH
ffb0		HALFWIDTH HANGUL LETTER RIEUL-HIEUH
ffb1		HALFWIDTH HANGUL LETTER MIEUM
ffb2		HALFWIDTH HANGUL LETTER PIEUP
ffb3		HALFWIDTH HANGUL LETTER SSANGPIEUP
ffb4		HALFWIDTH HANGUL LETTER PIEUP-SIOS
ffb5		HALFWIDTH HANGUL LETTER SIOS
ffb6		HALFWIDTH HANGUL LETTER SSANGSIOS
ffb7		HALFWIDTH HANGUL LETTER IEUNG
ffb8		HALFWIDTH HANGUL LETTER CIEUC
ffb9		HALFWIDTH HANGUL LETTER SSANGCIEUC
ffba		HALFWIDTH HANGUL LETTER CHIEUCH
ffbb		HALFWIDTH HANGUL LETTER KHIEUKH
ffbc		HALFWIDTH HANGUL LETTER THIEUTH
ffbd		HALFWIDTH HANGUL LETTER PHIEUPH
ffbe		HALFWIDTH HANGUL LETTER HIEUH
ffc2		HALFWIDTH HANGUL LETTER A
ffc3		HALFWIDTH HANGUL LETTER AE
ffc4		HALFWIDTH HANGUL LETTER YA
ffc5		HALFWIDTH HANGUL LETTER YAE
ffc6		HALFWIDTH HANGUL LETTER EO
ffc7		HALFWIDTH HANGUL LETTER E
ffca		HALFWIDTH HANGUL LETTER YEO
ffcb		HALFWIDTH HANGUL LETTER YE
ffcc		HALFWIDTH HANGUL LETTER O
ffcd		HALFWIDTH HANGUL LETTER WA
ffce		HALFWIDTH HANGUL LETTER WAE
ffcf		HALFWIDTH HANGUL LETTER OE
ffd2		HALFWIDTH HANGUL LETTER YO
ffd3		HALFWIDTH HANGUL LETTER U
ffd4		HALFWIDTH HANGUL LETTER WEO
ffd5		HALFWIDTH HANGUL LETTER WE
ffd6		HALFWIDTH HANGUL LETTER WI
ffd7		HALFWIDTH HANGUL LETTER YU
ffda		HALFWIDTH HANGUL LETTER EU
ffdb		HALFWIDTH HANGUL LETTER YI
ffdc		HALFWIDTH HANGUL LETTER I
ffe0		FULLWIDTH CENT SIGN
ffe1		FULLWIDTH POUND SIGN
ffe2		FULLWIDTH NOT SIGN
ffe3		FULLWIDTH MACRON
ffe4		FULLWIDTH BROKEN BAR
ffe5		FULLWIDTH YEN SIGN
ffe6		FULLWIDTH WON SIGN
ffe8		HALFWIDTH FORMS LIGHT VERTICAL
ffe9		HALFWIDTH LEFTWARDS ARROW
ffea		HALFWIDTH UPWARDS ARROW
ffeb		HALFWIDTH RIGHTWARDS ARROW
ffec		HALFWIDTH DOWNWARDS ARROW
ffed		HALFWIDTH BLACK SQUARE
ffee		HALFWIDTH WHITE CIRCLE
fffc		OBJECT REPLACEMENT CHARACTER
fffd		REPLACEMENT CHARACTER
END
